clear 
set more off
capture log close 

global outputdata = "Q:\Team\Tefera\Food_assessment\Final\"

global logfile = "Q:\Team\Tefera\Food_assessment\Final\coicop.log"
log using "$logfile", replace

* To generate representation of food items by COICOP Division, Group and Class breakdown, we should use corrected Master Food List
use "$outputdata\Corrections to MFL_FBS.dta", clear
**************************************************
* Calculate percent of food item in Classification of Individual Consumption according to Purpose (COICOP) Class
**************************************************

* The following countries 1)Georgia, 2)Montenegro, and 3)Russia, are dropped from analysis as
* they do not have/ missing food list information in the assessment 

recode Q6_3 Q6_4 Q6_5 Q6_11 Q6_17 Q6_20 Q6_25 Q6_28 Q6_31 Q6_35 Q6_39 Q6_40 Q6_43 Q6_44 (.=0)
recode Q6_6 Q6_7 Q6_8 Q6_9 Q6_10 Q6_12 Q6_13 Q6_14 Q6_15 Q6_16 Q6_18 Q6_19 Q6_21 Q6_22 Q6_23 Q6_24 ///
	Q6_26 Q6_27 Q6_29 Q6_30 Q6_32 Q6_33 Q6_34 Q6_36 Q6_37 Q6_38 Q6_39a Q6_39b Q6_39c Q6_39g ///
	Q6_41 Q6_42 Q6_45 Q6_46 Q6_47 Q6_48 (.=0)
	
gen coicopfg1=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg1=1 if (Q6_5 + Q6_6 + Q6_7 + Q6_8 + Q6_9 + Q6_10) >0  & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg2=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg2=1 if (Q6_11 + Q6_12 + Q6_13 + Q6_14 + Q6_15 + Q6_16) >0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg3=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg3=1 if (Q6_17 + Q6_18 + Q6_19) >0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg4=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg4=1 if (Q6_20 + Q6_21 + Q6_22 + Q6_23 + Q6_24)>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg5=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg5=1 if (Q6_25 + Q6_26 + Q6_27) >0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg6=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg6=1 if (Q6_28 + Q6_29 + Q6_30) >0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg7=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg7=1 if (Q6_31 + Q6_32 + Q6_33 + Q6_34) >0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg8=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg8=1 if (Q6_35 + Q6_36 + Q6_37 + Q6_38) >0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg9=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg9=1 if Q6_39>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg10=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg10=1 if (Q6_40 + Q6_41 + Q6_42) >0 & !inlist(country,"Georgia","Montenegro","Russia")
*gen coicopfg11=0 if !inlist(country,"Georgia","Montenegro","Russia")
*replace coicopfg11=1 if Q6_43>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen coicopfg12=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace coicopfg12=1 if (Q6_44 + Q6_45 + Q6_46 + Q6_47 + Q6_48)>0 & !inlist(country,"Georgia","Montenegro","Russia")

* meat with out pork
gen xcoicopfg2=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace xcoicopfg2=1 if (Q6_11 + Q6_12 + Q6_14 + Q6_15 + Q6_16) >0 & !inlist(country,"Georgia","Montenegro","Russia")

egen numcoicopfg=rsum(coicopfg1-coicopfg10 coicopfg12) if !inlist(country,"Georgia","Montenegro","Russia")
tab numcoicopfg, missing

* without alcoholic beverages
egen xnumcoicopfg=rsum(coicopfg1 xcoicopfg2 coicopfg3-coicopfg10) if !inlist(country,"Georgia","Montenegro","Russia")

gen all_coicopfg=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var all_coicopfg "All COICOP Food Class are presented"
replace all_coicopfg=1 if numcoicopfg==11 & !inlist(country,"Georgia","Montenegro","Russia")

gen xall_coicopfg=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var xall_coicopfg "All COICOP Food Class (w) are presented without"
replace xall_coicopfg=1 if xnumcoicopfg==10 & !inlist(country,"Georgia","Montenegro","Russia")

la var coicopfg1 "Bread and cereals"
la var coicopfg2 "Meat"
la var coicopfg3 "Fish and seafood"
la var coicopfg4 "Milk, cheese and eggs"
la var coicopfg5 "Oils and fats"
la var coicopfg6 "Fruits"
la var coicopfg7 "Vegetables"
la var coicopfg8 "Sugar, jam, honey, chocolate and confectionery"
la var coicopfg9 "Food products n.e.c"
la var coicopfg10 "Non-alcoholic beverages"
*la var coicopfg11 "Alcoholic beverages, tobacco and narcotics"
la var coicopfg12 "Alcoholic beverages"

*Percent of surveys listing food items in COICOP food groups
tab1 coicopfg1-coicopfg12 all_coicopfg  

recode coicopfg1-coicopfg12 all_coicopfg xall_coicopfg (1=100)
sum coicopfg1-coicopfg12 all_coicopfg xall_coicopfg if !inlist(country,"Georgia","Montenegro","Russia")

*** Calculat information regarding spanning food items in COICOP Division and Class breakdown
if !inlist(country,"Georgia","Montenegro","Russia"){
 gen cspan_1=0
 replace cspan_1=1 if Q6_3 >0
 la var cspan_1 "Food and beverages"
 
 gen cspan_2=0
 replace cspan_2=1 if Q6_4 >0
 la var cspan_2 "Food"
 
 gen cspan_3=0
 replace cspan_3=1 if Q6_5>0
 la var cspan_3 "Bread and cereals"
 
 gen cspan_4=0
 replace cspan_4=1 if Q6_11>0
 la var cspan_4 "Meat"
 
 gen cspan_5=0
 replace cspan_5=1 if Q6_17>0
 la var cspan_5 "Fish and seafood"

 gen cspan_6=0
 replace cspan_6=1 if Q6_20>0
 la var cspan_6 "Milk, cheese and eggs"

 gen cspan_7=0
 replace cspan_7=1 if Q6_25 >0
 la var cspan_7 "Oils and fats"

 gen cspan_8=0
 replace cspan_8=1 if Q6_28 >0
 la var cspan_8 "Fruits"
 
 gen cspan_9=0
 replace cspan_9=1 if Q6_31 >0
 la var cspan_9 "Vegetables"
 
 gen cspan_10=0
 replace cspan_10=1 if Q6_35 >0
 la var cspan_10 "Sugar, jam, honey, chocolate and confectionery"
 
 gen cspan_11=0
 replace cspan_11=1 if Q6_39 > (Q6_39a + Q6_39b + Q6_39c + Q6_39g)
 la var cspan_11 "Food products n.e.c"

 gen cspan_12=0
 replace cspan_12=1 if Q6_40 >0
 la var cspan_12 "Non-alcoholic beverages"

 gen cspan_13=0
 replace cspan_13=1 if Q6_43 >0
 la var cspan_13 "Alcoholic beverages, tobacco and narcotics"
 
 gen cspan_14=0
 replace cspan_14=1 if Q6_44 >0
 la var cspan_14 "Alcoholic beverages"
 }

 
*egen numcspan=rsum(cspan_3-cspan_12 cspan_14) if !inlist(country,"Georgia","Montenegro","Russia")
*tab numcspan, missing

*gen all_cspan=0 if !inlist(country,"Georgia","Montenegro","Russia")
*la var all_cspan "All COICOP Class are presented"
*replace all_cspan=1 if numcspan==11 & !inlist(country,"Georgia","Montenegro","Russia")
 
*tab1 cspan_1-cspan_14 all_cspan
tab1 cspan_1-cspan_14

recode cspan_1-cspan_14(1=100)
* by COICOP class
summ cspan_3-cspan_12 cspan_14 if !inlist(country,"Georgia","Montenegro","Russia")
* by COICOP divison
summ cspan_1 cspan_2 cspan_13 if !inlist(country,"Georgia","Montenegro","Russia")

** List of food items by COICOP individual item level and class
*gen coicop_Q6_5=0
gen coicop_Q6_6=0
replace coicop_Q6_6=1 if Q6_6 > 0
gen coicop_Q6_7=0
replace coicop_Q6_7=1 if Q6_7 > 0 
gen coicop_Q6_8=0
replace coicop_Q6_8=1 if Q6_8 > 0 
gen coicop_Q6_9=0
replace coicop_Q6_9=1 if Q6_9 > 0 
gen coicop_Q6_10=0
replace coicop_Q6_10=1 if Q6_10 > 0

*gen coicop_Q6_11=0
gen coicop_Q6_12=0
replace coicop_Q6_12=1 if Q6_12 > 0 
gen coicop_Q6_13=0
replace coicop_Q6_13=1 if Q6_13 > 0
gen coicop_Q6_14=0
replace coicop_Q6_14=1 if  Q6_14 > 0
gen coicop_Q6_15=0
replace coicop_Q6_15=1 if Q6_15 > 0
gen coicop_Q6_16=0
replace coicop_Q6_16=1 if Q6_16 > 0

*gen coicop_Q6_17=0
gen coicop_Q6_18=0
replace coicop_Q6_18=1 if Q6_18 > 0 
gen coicop_Q6_19=0
replace coicop_Q6_19=1 if Q6_19 > 0

*gen coicop_Q6_20=0
gen coicop_Q6_21=0
replace coicop_Q6_21=1 if Q6_21 > 0
gen coicop_Q6_22=0
replace coicop_Q6_22=1 if Q6_22 > 0
gen coicop_Q6_23=0
replace coicop_Q6_23=1 if Q6_23 > 0 
gen coicop_Q6_24=0
replace coicop_Q6_24=1 if Q6_24 > 0

*gen coicop_Q6_25=0
gen coicop_Q6_26=0
replace coicop_Q6_26=1 if Q6_26 > 0
gen coicop_Q6_27=0
replace coicop_Q6_27=1 if Q6_27 > 0

*gen coicop_Q6_28=0
gen coicop_Q6_29=0
replace coicop_Q6_29=1 if Q6_29 > 0
gen coicop_Q6_30=0
replace coicop_Q6_30=1 if Q6_30 > 0

*gen coicop_Q6_31=0
gen coicop_Q6_32=0
replace coicop_Q6_32=1 if Q6_32 > 0
gen coicop_Q6_33=0
replace coicop_Q6_33=1 if Q6_33 > 0
gen coicop_Q6_34=0
replace coicop_Q6_34=1 if Q6_34 > 0

*gen coicop_Q6_35=0
gen coicop_Q6_36=0
replace coicop_Q6_36=1 if Q6_36 > 0

gen coicop_Q6_37=0
replace coicop_Q6_37=1 if Q6_37 > 0

gen coicop_Q6_38=0
replace coicop_Q6_38=1 if Q6_38 > 0

gen coicop_Q6_39=0
replace coicop_Q6_39=1 if Q6_39 > 0

*gen coicop_Q6_40=0
gen coicop_Q6_41=0
replace coicop_Q6_41=1 if Q6_41 > 0

gen coicop_Q6_42=0
replace coicop_Q6_42=1 if Q6_42 > 0

gen coicop_Q6_43=0
replace coicop_Q6_43=1 if Q6_43 > 0

*gen coicop_Q6_44=0
gen coicop_Q6_45=0
replace coicop_Q6_45=1 if Q6_45 > 0

gen coicop_Q6_46=0
replace coicop_Q6_46=1 if Q6_46 > 0

gen coicop_Q6_47=0
replace coicop_Q6_47=1 if Q6_47 > 0

gen coicop_Q6_48=0
replace coicop_Q6_48=1 if Q6_48 > 0

*********
egen scoicop_Q6_5=rsum(coicop_Q6_6 coicop_Q6_7 coicop_Q6_8 coicop_Q6_9 coicop_Q6_10)
gen coicop_Q6_5=0
replace coicop_Q6_5=1 if scoicop_Q6_5 > 0

egen scoicop_Q6_11=rsum(coicop_Q6_12 coicop_Q6_13 coicop_Q6_14 coicop_Q6_15 coicop_Q6_16)
gen coicop_Q6_11=0
replace coicop_Q6_11=1 if scoicop_Q6_11 > 0

egen scoicop_Q6_17=rsum(coicop_Q6_18 coicop_Q6_19)
gen coicop_Q6_17=0
replace coicop_Q6_17=1 if scoicop_Q6_17 > 0

egen scoicop_Q6_20=rsum(coicop_Q6_21 coicop_Q6_22 coicop_Q6_23 coicop_Q6_24)
gen coicop_Q6_20=0
replace coicop_Q6_20=1 if scoicop_Q6_20 > 0

egen scoicop_Q6_25=rsum(coicop_Q6_26 coicop_Q6_27)
gen coicop_Q6_25=0
replace coicop_Q6_25=1 if scoicop_Q6_25 > 0

egen scoicop_Q6_28=rsum(coicop_Q6_29 coicop_Q6_30)
gen coicop_Q6_28=0
replace coicop_Q6_28=1 if scoicop_Q6_28 > 0

egen scoicop_Q6_31=rsum(coicop_Q6_32 coicop_Q6_33 coicop_Q6_34)
gen coicop_Q6_31=0
replace coicop_Q6_31=1 if scoicop_Q6_31 > 0

egen scoicop_Q6_35=rsum(coicop_Q6_36 coicop_Q6_37 coicop_Q6_38)
gen coicop_Q6_35=0
replace coicop_Q6_35=1 if scoicop_Q6_35 > 0

egen scoicop_Q6_40=rsum(coicop_Q6_41 coicop_Q6_42)
gen coicop_Q6_40=0
replace coicop_Q6_40=1 if scoicop_Q6_40 > 0

egen scoicop_Q6_44=rsum(coicop_Q6_45 coicop_Q6_46 coicop_Q6_47 coicop_Q6_48)
gen coicop_Q6_44=0
replace coicop_Q6_44=1 if scoicop_Q6_44 > 0


**************
la var coicop_Q6_5 "Bread and cereals"
la var coicop_Q6_6 "Rice"
la var coicop_Q6_7 "Other cereals, flour and other products"
la var coicop_Q6_8 "Bread"
la var coicop_Q6_9 "Other bakery products"
la var coicop_Q6_10 "Pasta products"
la var coicop_Q6_11 "Meat"
la var coicop_Q6_12 "Beef and veal"
la var coicop_Q6_13 "Pork"
la var coicop_Q6_14 "Lamb, mutton and goat"
la var coicop_Q6_15 "Poultry"
la var coicop_Q6_16 "Other meats and meat preparations"
la var coicop_Q6_17 "Fish and seafood"
la var coicop_Q6_18 "Fresh, chilled or frozen fish and seafood"
la var coicop_Q6_19 "Preserved or processed fish and seafood"
la var coicop_Q6_20 "Milk, cheese and eggs"
la var coicop_Q6_21 "Fresh milk"
la var coicop_Q6_22 "Preserved milk and other milk products"
la var coicop_Q6_23 "Cheese"
la var coicop_Q6_24 "Eggs and egg-based products"
la var coicop_Q6_25 "Oils and fats"
la var coicop_Q6_26 "Butter and margarine"
la var coicop_Q6_27 "Other edible oils and fats"
la var coicop_Q6_28 "Fruits"
la var coicop_Q6_29 "Fresh or chilled fruits"
la var coicop_Q6_30 "Frozen, preserved or processed fruit and fruit-based products"
la var coicop_Q6_31 "Vegetables"
la var coicop_Q6_32 "Fresh or chilled vegetables other than potatoes"
la var coicop_Q6_33 "Fresh or chilled potatoes, and other tuber vegetables"
la var coicop_Q6_34 "Frozen, preserved or processed vegetables and vegetable-based products"
la var coicop_Q6_35 "Sugar, jam, honey, chocolate and confectionery"
la var coicop_Q6_36 "Sugar"
la var coicop_Q6_37 "Jams, marmalades and honey"
la var coicop_Q6_38 "Confectionery, chocolate and ice cream"
la var coicop_Q6_39 "Food products n.e.c"
la var coicop_Q6_40 "Non-alcoholic beverages"
la var coicop_Q6_41 "Coffee, tea and cocoa"
la var coicop_Q6_42 "Mineral waters, soft drinks, fruit and vegetable"
la var coicop_Q6_43 "Alcoholic beverages, tobacco and narcotic"
la var coicop_Q6_44 "Alcoholic beverages"
la var coicop_Q6_45 "Spirits"
la var coicop_Q6_46 "Wine"
la var coicop_Q6_47 "Beer"
la var coicop_Q6_48 "Stimulants"

order coicop_Q6_5 coicop_Q6_6 coicop_Q6_7 coicop_Q6_8 coicop_Q6_9 coicop_Q6_10 coicop_Q6_11 coicop_Q6_12 ///
coicop_Q6_13 coicop_Q6_14 coicop_Q6_15 coicop_Q6_16 coicop_Q6_17 coicop_Q6_18 coicop_Q6_19 coicop_Q6_20 ///
coicop_Q6_21 coicop_Q6_22 coicop_Q6_23 coicop_Q6_24 coicop_Q6_25 coicop_Q6_26 coicop_Q6_27 coicop_Q6_28 ///
coicop_Q6_29 coicop_Q6_30 coicop_Q6_31 coicop_Q6_32 coicop_Q6_33 coicop_Q6_34 coicop_Q6_35 coicop_Q6_36 ///
coicop_Q6_37 coicop_Q6_38 coicop_Q6_39 coicop_Q6_40 coicop_Q6_41 coicop_Q6_42 coicop_Q6_43 coicop_Q6_44 ///
coicop_Q6_45 coicop_Q6_46 coicop_Q6_47 coicop_Q6_48


gen c_Q6_5=0
replace c_Q6_5=1 if scoicop_Q6_5==5

gen c_Q6_11=0
replace c_Q6_11=1 if scoicop_Q6_11==5 
 
gen c_Q6_17=0
replace c_Q6_17=1 if scoicop_Q6_17==2 

gen c_Q6_20=0
replace c_Q6_20=1 if scoicop_Q6_20==4 

gen c_Q6_25=0
replace c_Q6_25=1 if scoicop_Q6_25==2 

gen c_Q6_28=0
replace c_Q6_28=1 if scoicop_Q6_28==2

gen c_Q6_31=0
replace c_Q6_31=1 if scoicop_Q6_31==3 

gen c_Q6_35=0
replace c_Q6_35=1 if scoicop_Q6_35==3 

gen c_Q6_40=0
replace c_Q6_40=1 if scoicop_Q6_40==2 

gen c_Q6_44=0
replace c_Q6_44=1 if scoicop_Q6_44==4 


recode coicop_Q6_5-coicop_Q6_48 (1=100)
recode c_Q6_5 c_Q6_11 c_Q6_17 c_Q6_20 c_Q6_25 c_Q6_28 c_Q6_31 c_Q6_35 c_Q6_40 c_Q6_44 (1=100)

summ coicop_Q6_5-coicop_Q6_48  
summ c_Q6_5 c_Q6_11 c_Q6_17 c_Q6_20 c_Q6_25 c_Q6_28 c_Q6_31 c_Q6_35 coicop_Q6_39 c_Q6_40 c_Q6_44

log close 
