clear 
set more off
capture log close 

global outputdata = "Q:\Team\Tefera\Food_assessment\Final\"

global logfile = "Q:\Team\Tefera\Food_assessment\Final\tables.log"
log using "$logfile", replace


use "$outputdata\HCES_food_assessment_edited.dta", clear
*********************** Figure 1 ******************************
* Regional and time distribution of the assessment surveys
tab region
tab ref_year

*********************** Figure 2 ******************************
* Recall period for at-home food data collection
tab recallp_g, missing
* histogram recallpa_g, discrete percent


*Make dummy variable for reliablity criteria;
la var rc_1_recallp "Reliablity criteria for recall period"
tab rc_1_recallp

*********************** Figure 3 ******************************
* Modes of acquisition for which food data are collected

*This is the reliablity criteria;
tab m_purch, missing
tab m_hp, missing
tab m_ik, missing
tab rc_2_3modes, missing

use "$outputdata\compfl.dta", clear
*********************** Figure 4 ******************************
* Comprehensiveness of the at-home food list: Food groups represented
tab1 fg1-fg14 all_14fg 

*********************** Figure 5 ******************************
* Percent of surveys meeting the food list comprehensiveness criteria
tab1 all_14fg min_proc food_exc rc_4_compfl if !inlist(country,"Georgia","Montenegro","Russia"), missing 

use "$outputdata\specfl.dta", clear
*********************** Figure 6 ******************************
* Percent of surveys meeting the food list specificity criteria
tab crit_1 if !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* Atleast 10 of the basic food groups have the minimum number of food items  */
tab crit_2 if !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* Less than 5% of food items span more than one food group */
tab rc_5_specfl if !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* Both */

use "$outputdata\HCES_food_assessment_edited.dta", clear
*********************** Figure 8 ******************************
* Quality of food consumed away from home data collection
*tab fafh_g if int_diarya==1, missing
*tab fafh_g if int_diarya==2, missing
*tab fafh_g, missing
tab fafh_yes /* Data explicitely collected on food consumed away from home */
tab recallpa_le_2w,m /* Recall period two weeks or less */
tab fafh_inkind /* Data collected on both puchases and inlind receips */
tab rc_6_fcafh, missing /* All criteria */

*********************** Figure 9 ******************************
* Seasonality taken into account
tab seasonality 
*Make variable for minimum reliabilty criterion
tab rc_7_season

*********************** Figure 10  ******************************
*Percent of assessment surveys meeting minimum reliability criteria
tab1 rc_2_3modes rc_3_cenum rc_4_compfl rc_1_recallp rc_5_specfl rc_7_season rc_6_fcafh all_7

*********************** Figure 11  ******************************
* Percent of surveys for which absolute poverty can be measured
tab cc_fb /* First-best, Food Energy Intake method */
tab cc_sb /* Second-best, Food Energy Intake method */
tab cc_tb /* Third-best, Food Energy Intake method */
* two more tables will be added on Cost of Basic Needs method

*********************** Figure 12  ******************************
* Percent of surveys for which various food security indicators can be measured
tab dd_fb /* First-best, Dietary diversity */
tab dd_sb /* Second-best, Dietary diversity */
tab cc_fb_3 /* Quantities consumed of foods - At-home and away */
tab cc_sb_2,m /* Quantities consumed of foods - At-home only */
tab cc_fb /* First-best, calorie consumption and undernourishment */
tab cc_sb /* Second-best, calorie consumption and undernourishment */
tab cc_tb /* Third-best, calorie consumption and undernourishment */
* two more tables will be added on percent of calories from staples
tab cc_fb /* Micronutrient consumption and insufficiencies */

*********************** Figure 13  ******************************
* Percent of surveys for which indicators informing Food Balance Sheets can be measured
tab cc_fb_3 /* Estimating production using consumption quantities - At-home and away */
tab cc_sb_2,m /* Estimating production using consumption quantities - At-home only */
tab est_prd /* Estimating subsistance production */

use "$outputdata\Corrections to MFL_FBS", clear
tab all_three /* surveys that meet all three FBS conditions can be used for Consistency checks of FBS consumption patterns */

use "$outputdata\HCES_food_assessment_edited.dta", clear
tab cc_fb /* First-best, Estimating calorie consumption and undernourishment */
tab cc_sb /* Second-best, Estimating calorie consumption and undernourishment */
tab cc_tb /* Third-best, Estimating calorie consumption and undernourishment */

*********************** Figure 14  ******************************
* Precent of surveys for which indicators informing food-based nutritional interventions
tab consumption /* First-best, precent consuming potentially fortifiable foods */

tab Q5_1 /* Percent purchasing potentially fortifiable foods */
tab cc_fb_3 /* At-home and away, quantities of consumed of foods */ 
tab cc_sb_2,m /* At-home, quantities of consumed of foods */ 
tab cc_fb /* Micronutrient consumption and insufficiencies */


use "$outputdata\HCES_food_assessment_edited.dta", clear
*********************** Table 1 ******************************
*Completeness of enumeration of food acquisition and/ or food consumption 
tab acqu_cons 
tab acqu_cons if int_diary==1
tab acqu_cons if int_diary==2

tab1 problem_1 problem_2 problem_3 problem_4 problem_5 problem_6 rc_3_cenum

tab1 problem_1 problem_2 problem_3 problem_4 problem_5 problem_6 rc_3_cenum if int_diary==1
tab1 problem_1 problem_2 problem_3 problem_4 problem_5 problem_6 rc_3_cenum if int_diary==2

use "$outputdata\specfl.dta", clear
*********************** Table 2 ******************************
* Comprehensivness and specificity of at-home food list
** Mean number of food items
sum num_items if int_diary==1 /* Table 2 --- mean number of food items */
sum num_items if int_diary==2 /* Table 2 --- mean number of food items */
sum num_items /* Table 2 --- mean number of food items */

use "$outputdata\compfl.dta", clear
** Comprehensiveness of the food list
tab1 all_14fg min_proc food_exc if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia"), missing
tab1 all_14fg min_proc food_exc if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia"), missing
tab1 all_14fg min_proc food_exc if !inlist(country,"Georgia","Montenegro","Russia"), missing

use "$outputdata\specfl.dta", clear
** (A) Specificity of the food list
tab1 min_g1-min_g14 if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia")
tab1 min_g1-min_g14 if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia")
tab1 min_g1-min_g14 if !inlist(country,"Georgia","Montenegro","Russia")

** (B) Minimum number of food items in at least  ...
tab1 min_numfg10-min_numfg14 if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") 
tab1 min_numfg10-min_numfg14 if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia") 
tab1 min_numfg10-min_numfg14 if !inlist(country,"Georgia","Montenegro","Russia") 

** (C) Less than 5% of food items span the basic food groups
tab crit_2 if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Less than 5% of food items span the basic food groups (C) */
tab crit_2 if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Less than 5% of food items span the basic food groups (C) */
tab crit_2 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")


use "$outputdata\HCES_food_assessment_edited.dta", clear
*********************** Table 3 ******************************
* Food away from home data collection
tab fafh_yes if int_diarya==1
tab fafh_yes if int_diarya==2
tab fafh_yes
tab recallpa_g if int_diarya==1 & fafh_g==1
tab recallpa_g if int_diarya==2 & fafh_g==1
tab recallpa_g if fafh_g==1

*************************** Table 5 **************************
* Percent of surveys for which it is possible to calculate metric quantities fo foods acquired or consumed (at home)
tab method1_p
tab method1_hp if method1_hp~=7777  
tab method1_ik if method1_ik~=7777
tab all_m1

tab method2_p
tab method2_hp if method2_hp~=7777   
tab method2_ik if method2_ik~=7777
tab all_m2

tab method3_p  
tab method3_hp if method3_hp~=7777   
tab method3_ik if method3_ik~=7777
tab all_m3

tab method4_p  
tab method4_hp if method4_hp~=7777   
tab method4_ik if method4_ik~=7777
tab all_m4

tab method5_p
tab method5_hp if method5_hp~=7777 
tab method5_ik if method5_ik~=7777
tab all_m5

tab p_convert
tab hp_convert
tab ik_convert
tab all_convert

*************************** Table 6 **************************
* Perecent of surveys for which it is possible to calculate calorie consumption

/* First-best method */
tab cc_fb_1
tab cc_fb_2
tab cc_fb_3
tab cc_fb

/* Second-best method */
tab cc_sb_1
tab cc_sb_2
tab cc_sb_3
tab cc_sb

/* Third-best method */
tab cc_tb_1,m
tab cc_tb_2,m
tab cc_tb_3,m
tab cc_tb,m

*********************** Table 7 ******************************
* Collection of data on food given to non-household members
tab Q9_8,m 
tab Q9_9,m
tab Q9_10,m
tab Q9_11,m
tab Q9_12,m
tab Q9_13,m
tab Q9_14,m

*********************** Table 8 ******************************
* Comprehensiveness and specificity of survey food lists in relation to the Food Balance Sheet food groups
use "$outputdata\Corrections to MFL_FBS", clear
** Percent of surveys listing food items in groups
tab1 fg1_FBS-fg19_FBS 
** Percent of surveys with minimum number of food items in food group
tab1 min_g1_FBS-min_g19_FBS
** All food groups
tab all_fg
** Minimum number of food items
tab1 min_numfg15-min_numfg19

* additional tables information are available in the report
tab perc_span_lt5pc
tab all_three


log close 
