
clear 
set more off
capture log close 

global inputdata = "Q:\Team\Tefera\Food_assessment\Final\"
global outputdata = "Q:\Team\Tefera\Food_assessment\Final\"

global logfile = "Q:\Team\Tefera\Food_assessment\Final\food_assesement.log"
log using "$logfile", replace

use "$outputdata\HCES_food_assessment_edited.dta", clear

*********************************************************************
*********************************************************************
**     DATE:       August 2012
**     PROGRAM:    HCES Assessment_Reliability_Recall period
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    IHSN project\Analysis\Data\outfiles\recallp.dta 
**     PURPOSE:    Analyze reliability of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Recall period for at-home food data collection
*********************************************************************
*********************************************************************
/*
 (A) Determine:  Interview, diary or both? -- DONE in Cleaning program
 (B) Transform Q4_1h_spec (where "other" recall periods are specified) into numeric format  -- DONE in Cleaning program
 (C) Determine recall period that will be used for the assessment
 (D) Classify recall periods into groups
 (E) Generate additional information needed
*/

**************************************************
* (C) Determine recall period that will be used for the assessment
**************************************************
gen flag_norecallp=0
replace flag_norecallp=1 if Q4_1a==2 & Q4_1b==2 & Q4_1c==2 & Q4_1d==2 & Q4_1e==2 & Q4_1f==2 & Q4_1g==2 & Q4_1h==2 & (Q2_1==1 | Q2_1==3)
tab flag_norecallp,m
** Calculate total number of recall periods 
*Note:  treating multiple "Other" recall periods as just one, per Section (B) analysis.

* Interview surveys
replace Q2_1=1 if country=="Tunisia"
gen dummys=0
foreach var of varlist Q4_1a Q4_1b Q4_1c Q4_1d Q4_1e Q4_1f Q4_1g Q4_1h {
	replace dummys=dummys + 1 if `var'==1 & inlist(Q2_1,1,3)	
}
	
gen numrecallp=dummys if dummy > 0
la var numrecallp "Number of different recall period employed in the surveys"
    *  Diary-only surveys (set number of recall periods to 1);
replace numrecallp=1 if Q2_1==2
	 *  Special for interview AND diary surveys (add another recall period if interview recall period is not equal to one);
list Q4_1h_spec_num if Q2_1==3
     *None equal to 1
replace numrecallp=numrecallp + 1 if Q2_1==3
replace numrecallp=2 if country=="Belize" /* Belize: diary used for purchases and interview for home production) */
	 
tab numrecallp, missing
/*
numrecallp is missing for the following countries
Honduras
Montenegro
Nicaragua
Niger
*/

/* Note:  For Honduras, Bolivia, Peru and Nicaragua respondents are first asked to report on how often they acquired each food item, 
with the options being "Daily, Weekly, Monthly, Yearly", etc.  They are then asked to report the quantity and expenditures for the time option chosen.  
No recall period is specified (e.g., how often in the last year).  Thus the recall period is undefined for these surveys*/
replace numrecallp=. if inlist(country,"Honduras","Bolivia","Peru","Nicaragua")

*Set number of recall periods to zero for Maldives and Thailand, for which the recall period is also undefined;
replace numrecallp=0 if country=="Maldives" | country=="Thailand"

*Turkmenistan is a special case where both the usual month and usual week methods were used with 365-day recall periods so
*2 recall periods are specified, but there really is only one;
* Bosnia and Herzegovina only has one 365-day recall period, but two are specified because one is in the context of "usual
* month" and one not;
replace numrecallp=1 if country=="Turkmenistan" | country=="Bosnia and Herzegovina"


gen mult_recallp=0 if numrecallp~=.
replace mult_recallp=1 if inlist(numrecallp,2,3,4)
tab mult_recallp, m
/*
there are missing information for two surveys

mult_recall |
          p |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |         66       66.00       66.00
          1 |         32       32.00       98.00
          . |          2        2.00      100.00
------------+-----------------------------------
      Total |        100      100.00
*/
la var mult_recallp "Multiple recall periods employed for food consumed at home - interview method"

******************** 
* Specify recall period for diary-only surveys (recall period is 1 day)
********************;
gen recallp=1 if Q2_1==2
la var recallp "Recall period for at-home food data collection in number of days"

******************** 
* Determine recall period for interview-only surveys with one recall period
********************;

replace recallp=7  if             Q4_1a==1           & Q2_1==1 & numrecallp==1
replace recallp=14 if             Q4_1b==1           & Q2_1==1 & numrecallp==1
replace recallp=15 if             Q4_1c==1           & Q2_1==1 & numrecallp==1
replace recallp=30 if            (Q4_1d==1|Q4_1e==1) & Q2_1==1 & numrecallp==1
replace recallp=Q4_1f1 if         Q4_1f==1           & Q2_1==1 & numrecallp==1
replace recallp=Q4_1g1 if         Q4_1g==1           & Q2_1==1 & numrecallp==1
replace recallp=Q4_1h_spec_num if Q4_1h==1           & Q2_1==1 & numrecallp==1

*The recall period is undefined for Peru, Ecuador, Bolivia and Djibouti;
replace recallp=999 if country=="Peru" | country=="Bolivia" | country=="Ecuador" | country=="Djibouti"

******************** 
* Determine recall period for interview-only surveys with multiple recall periods, 
*          and different recall periods are used for ALL food items
********************; 

* We will use the minimum recall period for the purposes of this assessment;

*For info:  Number of interview-only surveys with multiple recall periods;
gen flag_1a=1 if Q2_1==1 & numrecallp>1 & numrecallp~=.
tab flag_1a, missing

*list country numrecallp Q4_2 if numrecallp>1 & numrecallp~=. & Q2_1==1;
*Only data for Bolivia is missing;
gen flag_1=1 if Q2_1==1 & (numrecallp>1 & numrecallp~=.) & Q4_2==1
tab flag_1, missing
list country Q4_1a-Q4_1e Q4_1f Q4_1f1 Q4_1g Q4_1g1 Q4_1h Q4_1h_spec_num if flag_1==1

replace recallp=30 if country=="Bulgaria" | country=="Togo"
replace recallp=7  if inlist(country,"Bhutan","Cte d'Ivoire","Dominica","Jamaica","Madagascar","Nepal","Panama","Paraguay")
replace recallp=14 if country=="Union des Comores"

******************** 
* Determine recall period for interview-only surveys with multiple recall periods, 
*          and different recall periods used for different groups of foods 
*          (or different sources e.g., home-produced versus purchased)  
******************** ;

* We will use the maximum recall period for the purposes of this assessment;
gen flag_2=1 if Q2_1==1 & (numrecallp>1 & numrecallp~=.) & Q4_2==2
tab flag_2, missing
list country Q4_1a-Q4_1e Q4_1f Q4_1f1 Q4_1g Q4_1g1 Q4_1h Q4_1h_spec_num if flag_2==1

replace recallp=365 if inlist(country,"Guatemala","Kosovo","Myanmar","Mauritania","Senegal","Vietnam")
replace recallp=30 if inlist(country,"Pakistan","Zambia")
replace recallp=7 if country=="Bangladesh"

******************** 
* Determine recall period for surveys that used both diaries AND interviews
********************;

* When both are used for ALL foods for all households we will assess based on a 1 day recall period;
* When they are used for different foods/sources or different sets of households, we will use the maximum interview recall period; 

gen flag_3=1 if Q2_1==3
list country Q4_1a-Q4_1e Q4_1f Q4_1f1 Q4_1g Q4_1g1 Q4_1h Q4_1h_spec_num Q4_5 if flag_3==1

*Belize:  Diary for purchases and interview with 12 month recall period for HP;
replace recallp=365 if country=="Belize"

*Belarus:  According to a special note from the NSC of Belarus after inquiry by Mathew Welch, the diary is filled out
* by the large majority of households.  Households are also administered a "Quarterly expenditure and income questionnaire"; 
* So both are used for all foods;
replace recallp=1 if country=="Belarus"

*Congo, Dem Rep: Diary filled out but also an interview form for "exceptional food expenses" and expenses at ceremonies;
* We will use the diary recall period since if the exceptional expenses occur during the diary period they should be picked up;
replace recallp=1 if country=="Congo, Dem. Rep."

*Republic of Congo: Diary form filled out but also an interview to collect data on "Depenses Retrospectives".  Using same logic
* as above, we will use the diary recall period (Note: powerpoint presentation confirms that diary was for all sources (purchases,
* own-produced and in-kind);
replace recallp=1 if country=="Republic of Congo"

*Ghana:  Used interview for one population and diary for another;
replace recallp=2 if country=="Ghana"

*Iraq:  We will base on diary recall period since only a few foods were asked about using the interview method
*and then, only for "rations received" of these food items;
replace recallp=1 if country=="Iraq"

*Kenya:  Both diary and interview were used for all foods. We will use the diary recall period (even though the
* diary data have not actually been entered and analyzed);
replace recallp=1 if country=="Kenya"

*St. Lucia:  Diary for purchases, interview for other;
replace recallp=30 if country=="St. Lucia"

* Morocco: The questionnaire and interviewer manual are not very clear, but it appears that the daily diary is used to
* collect data on all food sources and for all populations;
replace recallp=1 if country=="Morocco"

*Montenegro: A diary was used for at-home data collection and interview for away from home;
replace recallp=1 if country=="Montenegro"

*Mongolia:  Food acquisition data collected using a 30-day recall period.  Food consumption data collected using
*a diary for urban areas and 7-day recall interview for rural areas.  We will use 7 days for the assessment;
replace recallp=7 if country=="Mongolia"

*Niger:  The main collection of food acquisition data is through a daily diary; 
replace recallp=1 if country=="Niger"

*Chad: Diary is used to collect data on purchases, own production and gifts.  Interview is used for own production and gifts plus
*special events expenditures and consumption from own businesses;
replace recallp=1 if country=="Chad"

*Vanuatu:  Interview used for alcoholic beverages and meals on travel with 7-day recall period.  All rest diary;
replace recallp=7 if country=="Vanuatu"

*Set recall period as undefined for Maldives, Thailand, Honduras and Nicaragua;
replace recallp=999 if inlist(country,"Maldives","Thailand","Honduras","Nicaragua")

tab recallp, missing

**************************************************
**************************************************
* (D) Classify recall periods into groups
**************************************************
**************************************************;

gen recallp_g=1 if recallp<7 & recallp~=. & recallp~=999
replace recallp_g=2 if recallp==7
replace recallp_g=3 if recallp==14|recallp==15
replace recallp_g=4 if recallp==30
replace recallp_g=5 if recallp>30 & recallp~=. & recallp~=999

*Classify surveys with undefined recall periods as having a recall period greater than one month;
replace recallp_g=5 if inlist(country,"Thailand","Maldives","Honduras","Nicaragua","Bolivia","Peru","Ecuador","Djibouti") 

label define rclabel 1 "Less than one week" 2 "One week" 3 "Two weeks" 4 "One month" 5 "More than one month"
label values recallp_g rclabel
la var recallp_g "Recall period for at-home food data collection"
tab recallp_g
tab recallp_g, missing

*Make dummy variable for reliablity criteria;
gen rc_1_recallp=0 if recallp~=.
la var rc_1_recallp "Reliablity criteria for recall period"
replace rc_1_recallp=1 if recallp<=15 & recallp~=.
tab rc_1_recallp

tab recallp if recallp_g==1, missing

**************************************************
**************************************************
* (E) Generate additional information needed
**************************************************
**************************************************;

********** Calculate percent of surveys with "usual month" type of data collection;
gen usual_m=0
replace usual_m=1 if Q4_1f==1
la var usual_m "Surveys with 'usual month' type data collection"
tab usual_m, missing

tab usual_m if recallp_g==5
tab usual_m if recallp==365

tab usual_m if rc_1_recallp==0

********** Calculate percent of surveys with "usual week" type of data collection;
gen usual_w=0 if Q2_1==1
la var usual_w "Surveys with 'usual week' type of data collection"
replace usual_w=1 if Q2_1==1 & Q4_1g==1
tab usual_w

********** Calculate percent of surveys for which the recall period is bounded
recode Q4_3 99=.
tab Q4_3 if Q2_1~=2, missing

drop dummys flag_1a flag_1 flag_2 flag_3 flag_norecallp

save "$outputdata\HCES_food_assessment_edited.dta", replace

*********************************************************************
*********************************************************************
**     DATE:       September 2012
**     PROGRAM:    HCES Assessment_Reliability_Modes of acquisition
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012_100 country dataset.dta 
**     OUTFILE:    IHSN project\Analysis\Data\outfiles\sources.dta
**     PURPOSE:    Analyze reliability of the food data in Household Consumption 
**			       and expenditure surveys:  Modes of acquisition for which 
**				   at-home food data are collected
*********************************************************************
*********************************************************************

********************************
*  Determine whether data are collected on the three modes at all
********************************;
recode Q7_1 Q7_2 Q7_6 Q7_7 Q7_11 Q7_12 (99=.)
gen m_purch=0 if Q7_1~=. & Q7_2~=.
la var m_purch "Mode of at-home food data - food purchases"
replace m_purch=1 if Q7_1==1 | Q7_2==1

tab m_purch, missing
/* Data missing for Sao Tome and Principe.  The three sources are:
1. products consumed and stocked (in stock) the last 15 days?
2. offerings received and consumed in the last 15 days?
3. self-produced foods consumed in the last 15 days?
There is no mention of food purchases, but we assume that they are included in "produced consumed and stocked".
*/
replace m_purch=1 if country=="Sao Tome e Principe"

gen m_hp=0 if Q7_6~=. & Q7_7~=.
la var m_hp "Mode of at-home food data - home produced"
replace m_hp=1 if Q7_6==1 | Q7_7==1

gen m_ik=0 if Q7_11~=. & Q7_12~=.
la var m_ik "Mode of at-home food data - inkind receipts of food" 
replace m_ik=1 if Q7_11==1 | Q7_12==1

*This is the reliablity criteria;
gen rc_2_3modes=0 if Q7_1~=. & Q7_2~=. & Q7_6~=. & Q7_7~=. & Q7_11~=. & Q7_12~=.
la var rc_2_3modes "Mode of acquisition for at-home food data - All three sources"
replace rc_2_3modes=1 if m_purch==1 & m_hp==1 & m_ik==1

tab m_purch, missing
tab m_hp, missing
tab m_ik, missing
tab rc_2_3modes, missing

tab m_purch
tab m_hp
tab m_ik
tab rc_2_3modes

recode Q7_1 Q7_2 Q7_6 Q7_7 Q7_11 Q7_12 (.=99)

********************************
*  Determine whether data are collected individually on the three sources
********************************;

*We will do this for surveys for which data were collected for all three sources; 
gen mi_purch=0 if !inlist(Q5_1,99,.) & rc_2_3modes==1
la var mi_purch "Food purchases individually, if all three sources were collected"
replace mi_purch=1 if Q5_1==1 & rc_2_3modes==1

gen mi_hp=0 if !inlist(Q5_2,99,.) & rc_2_3modes==1
la var mi_hp "Food consumed from own production individually, if all three sources were collected"
replace mi_hp=1 if Q5_2==1 & rc_2_3modes==1

gen mi_ik=0 if !inlist(Q5_3,99,.) & rc_2_3modes==1
la var mi_ik "Food received in kind individually, if all three sources were collected"
replace mi_ik=1 if Q5_3==1 & rc_2_3modes==1

tab mi_purch if rc_2_3modes==1, missing
tab mi_hp if rc_2_3modes==1, missing
tab mi_ik if rc_2_3modes==1, missing

list country mi* if (mi_purch==0 | mi_hp==0 | mi_ik==0) & rc_2_3modes==1

********************************
*  For info:  The in-kind sources for which data were collected individually
********************************;
gen gifts=0 if mi_ik==1
la var gifts "In-kind food received as gifts"
replace gifts=1 if Q5_4a==1 & mi_ik==1
gen emp=0 if mi_ik==1
la var emp "In-kind food received as payment from an employer"
replace emp=1 if Q5_4b==1 & mi_ik==1
gen assist=0 if mi_ik==1
la var assist "In-kind food received as food assistance"
replace assist=1 if Q5_4c==1 & mi_ik==1
gen oth=0 if mi_ik==1
la var oth "In-kind food received as other, incuding grouped items"
replace oth=1 if Q5_4d==1 & mi_ik==1
gen notspec=0 if mi_ik==1
la var notspec "In-kind food received with unspecified source"
replace notspec=1 if Q5_4e==1 & mi_ik==1

tab gifts if mi_ik==1, missing
tab emp if mi_ik==1, missing
tab assist if mi_ik==1, missing
tab oth if mi_ik==1, missing

list country Q5_4d Q5_4d_spec if oth==1 & mi_ik==1
tab notspec if mi_ik==1, missing

******************************************************************************************
*  Percent of surveys for which purchases data are collected separately from other sources
******************************************************************************************

******************************************************************
*  Determine whether data are collected individually on purchases;
******************************************************************

tab Q5_1

gen mi_purch_ind=0 if !inlist(Q5_1,99,.)
la var mi_purch_ind "Data are collected individually on food purchases"
replace mi_purch_ind=1 if Q5_1==1
tab mi_purch_ind, missing

************************************************************************************
*  Determine whether data are collected individually on home-produced food consumed;
************************************************************************************

gen mi_hp_ind=0 if (!inlist(Q5_2,99,.) | country=="Thailand")
la var mi_hp_ind "Data are collected individually on home-produced food consumed"
replace mi_hp_ind=1 if Q5_2==1
tab mi_hp_ind, missing
tab mi_hp_ind

save "$outputdata\HCES_food_assessment_edited.dta", replace

*********************************************************************
*********************************************************************
**     DATE:       September 2012
**     PROGRAM:    HCES Assessment_Reliability_Completeness of enumeration
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset 
**     OUTFILE:    outfiles\complete_enum.dta, outfiles\int_diary.dta
**     PURPOSE:    Analyze data for analysis of Chapter 4 of the 
**                 assessment report:  "Assessment of the reliability 
**				   of the food data"
*********************************************************************
*********************************************************************;
/* 
  (A) Determine whether interview, diary or both data will be used to assess this criterion -- DONE in cleaning part
  (B) For info:  Percent of surveys collecting acquisition data, consumption data, and both 
  (C) Identify surveys with incomplete enumeration due to rule-out leading question on consumption
  (D) Identify surveys with incomplete enumeration due to rule-out leading question on acquisition
  (E) Identify surveys with rule-out leading question on food purchases
  (F) Identify surveys with incomplete enumeration due to asking about harvest of home-produced foods instead of consumption 
  (G) Identify surveys for which there is ambiguity about whether to report on acquisition or consumption
  (H) Identify surveys for which there is ambiguity about whether to report on consumption in any month or months with positive consumption
  (I) Identify surveys meeting the assessment criterion (those without any of the problems)
*/

*******************************************************************************************
* (B) For info:  Percent of surveys collecting acquisition data, consumption data, and both 
*******************************************************************************************
* Food purchases
gen purch_acqu_cons=.
la var purch_acqu_cons "Food purchase - whether acquisition or consumption or both"
la def source 1 "Acquisition" 2 "Consumption" 3 "Both"
la val purch_acqu_cons source

************ Surveys for which data are collected individually on food purchases (Q5_1 is "yes");
*Note: We can only get this information directly from the assessment questionnaires for these surveys; 
tab Q5_1, missing
*90/100 surveys;

list country Q5_1 Q5_1a Q5_1b Q5_1c Q5_1d if Q5_1==1
*"Not specified" is not checked for any country;

*Check that all are no when Q5_1 is checked "no";
list country Q5_1 Q5_1a Q5_1b Q5_1c Q5_1d if Q5_1==2
*OK;

*Acquisition data are collected;
replace purch_acqu_cons=1 if Q5_1==1 & Q5_1a==1

*Consumption data are collected;
replace purch_acqu_cons=2 if Q5_1==1 & Q5_1b==1

*Both;
replace purch_acqu_cons=3 if Q5_1==1 & Q5_1c==1

tab purch_acqu_cons, missing
* 90/100 countries covered;

*For the 10 remaining countries (most of whom for which data were not collected individually), getting information from the questionnaire;
list country Q7_1 Q7_2 if Q5_1==2
*Purchases data were indeed collected (Q7_1 or Q7_2, or both, were checked "yes");

replace purch_acqu_cons=2 if inlist(country,"Afghanistan","Bangladesh","India","Timor-Leste","Angola","Lao PDR","St. Lucia","Maldives")
replace purch_acqu_cons=1 if inlist(country,"Togo","Djibouti")

tab purch_acqu_cons, missing
*la def source 1 "Acquisition" 2 "Consumption" 3 "Both"
la val purch_acqu_cons source

* Food received inkind
*Note:  All own-production data collected are for consumption;

gen ik_acqu_cons=.
la var ik_acqu_cons "Food received inkind - whether acquisition or consumption or both"
la def ik_acqu_cons 1 "Acquisition" 2 "Consumption" 3 "Both" 999 "No inkind data collected"
la val ik_acqu_cons ik_acqu_cons

*Identify surveys for which no inkind data collected at all;
replace ik_acqu_con=999 if Q7_11==2 & Q7_12==2
* 13 countries;
*@@ check these it shoud be 14

**** Surveys for which data are collected individually on food received inkind (Q5_3 is "yes");
*Note: We can only get this information directly from the assessment questionnaires for these surveys; 

tab Q5_3 if ik_acqu_con~=999, missing
*75/87 surveys;
*@@ check these result 74/86

list country Q5_3 Q5_3a Q5_3b Q5_3c Q5_3d if Q5_3==1
*Note: There are two countries for which "not specified" is checked (Congo DR and Thailand);
*They will get a missing value;

*Check that all are no when Q5_3 is checked "no";
list Q5_3 Q5_3a Q5_3b Q5_3c Q5_3d if Q5_3==2
*OK;

*Acquisition data are collected;
replace ik_acqu_cons=1 if Q5_3==1 & Q5_3a==1

*Consumption data are collected;
replace ik_acqu_cons=2 if Q5_3==1 & Q5_3b==1

*Both;
replace ik_acqu_cons=3 if Q5_3==1 & Q5_3c==1

*Missing data;
replace ik_acqu_cons=99999 if Q5_3==1 & Q5_3d==1

tab ik_acqu_cons, missing
* (73+13+2)=88 countries covered;

*For the 12 remaining countries, getting information from the questionnaire;
list country Q7_11 Q7_12 if Q5_3==2 & ik_acqu_con==.

*Acquisition;
replace ik_acqu_cons=1 if inlist(country,"Angola","Lao PDR","Maldives")
*3 countries;

*Consumption;
replace ik_acqu_cons=2 if inlist(country,"Afghanistan","Bangladesh","India","Timor-Leste")
replace ik_acqu_cons=2 if inlist(country,"Liberia","Sri Lanka","Vietnam","Kazakhstan","Seychelles")
*9 countries;

tab ik_acqu_con, missing
list country if ik_acqu_con==99999

******************** 
* Whether data are collected on acquisition, consumption or both: overall categorization
********************; 

********** Surveys for which no in-kind data are collected or acquisition/consumption not specified for in-kind data
*          collection (base only on purchases);
tab ik_acqu_cons, missing
*15 surveys;

gen     acqu_cons=1 if purch_acqu_cons==1 & ik_acqu_cons==999 | ik_acqu_cons==99999
replace acqu_cons=2 if purch_acqu_cons==2 & ik_acqu_cons==999 | ik_acqu_cons==99999
replace acqu_cons=3 if purch_acqu_cons==3 & ik_acqu_cons==999 | ik_acqu_cons==99999
tab acqu_cons, missing

********** Surveys for which both purchases and in-kind data are collected (base on both);
replace acqu_cons=1 if (purch_acqu_cons==1 & ik_acqu_cons==1) & ik_acqu_cons~=999 & ik_acqu_cons~=99999
replace acqu_cons=2 if (purch_acqu_cons==2 & ik_acqu_cons==2) & ik_acqu_cons~=999 & ik_acqu_cons~=99999

* If either purchases or inkind are for "both", then "both";
replace acqu_cons=3 if (purch_acqu_cons==3 | ik_acqu_cons==3) & ik_acqu_cons~=999 & ik_acqu_cons~=99999

********** "Mixed" cases;
list country purch_acqu_cons ik_acqu_cons if acqu_cons==.

replace acqu_cons=3 if (purch_acqu_cons==2 & ik_acqu_cons==1) & ik_acqu_cons~=99999
replace acqu_cons=3 if (purch_acqu_cons==1 & ik_acqu_cons==2) & ik_acqu_cons~=99999	
													   
tab acqu_cons, mi
tab acqu_cons
tab acqu_cons if int_diary==1
tab acqu_cons if int_diary==2
la var acqu_cons "Whether acquisition or consumption or both"
la val acqu_cons source
/*
*For info: Look at change over time in collection of consumption data;
merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\year.dta";
tab _merge; drop _merge;

gen a_dum=0 if acqu_cons~=.; gen c_dum=0 if acqu_cons~=.; gen tot_dum=1 if acqu_cons~=.;

replace a_dum=1  if acqu_cons==1;
replace c_dum=1 if acqu_cons==2;
tab a_dum, missing;
tab c_dum, missing;
tab tot_dum, missing;

/*
collapse (sum) a_dum c_dum tot_dum, by(year);
gen perc_cons=c_dum*100/tot_dum;
list year perc_cons;
*/
*/
**************************************
* (C) Identify surveys with incomplete enumeration due to rule-out leading question on consumption
**************************************
*These are interview surveys that have a filter question asking whether each food was consumed over a 
*certain time period and then questions are asked about acquisition for the same (or near the same) time period;

tab Q5_7, missing
recode Q5_7 (99=.)
tab Q5_7


*Look at diary-only surveys;
list country Q2_1 Q5_7 if Q2_1==2
*As should, all have no or missing for Q5_7;
recode Q5_7 (.=99)
********** Identify surveys with incomplete enumeration due to filter question on consumption;
/*
*Only keep surveys with leading questions;
*Check; 
list country Q5_7 Q5_8;
keep if Q5_7==1;

list country Q5_7 Q5_8 acqu_cons;
* 28 surveys have a leading question on consumption;

*Note:  Incomplete enumeration due to rule-out leading question not an issue for surveys collecting data only on consumption;
*Drop them;
drop if purch_acqu_cons==2;
*17 surveys remaining;

*Check the recall period for the leading question in relation to the recall period for at-home food data collection;
merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\recallp.dta";
tab _merge; keep if _merge==3; drop _merge;

gen recallp_LQ=Q5_8;

sort numrecallp;
list country recallp_LQ numrecallp recallp purch_acqu_cons ik_acqu_cons;
*/

********** Surveys with one recall period;
gen problem_1=0
la var problem_1 "Rule-out leading question on consumption"
replace problem_1=1 if inlist(country,"Burundi","Nigeria","Tajikistan","Benin","El Salvador")

*Burundi:  Leading question recall period and overall recall period both 15 days, and data collected on acquisition; 

*El Salvador:  Leading question recall period and overall recall period both 7 days, and data collected on acquisition; 

*Benin:  Same as Burundi, but the question asked on purchases is "Si achat, combien avez-vous paye", which means respondents
*would likely report on acquisition rather than consumption;

*Nigeria and Tajikistan: they do have total consumed but then they are not able to properly enumerate
*the purchases, etc. for households that didn't consume but acquired;

********** Surveys with multiple recall periods;
replace problem_1=1 if inlist(country,"Jamaica","Cte d'Ivoire","Paraguay")

*Jamaica:  The leading question is unclear (states purchases, but then consumption).  The recall period is 30 days for the leading
*question, those for the expenditures/consumption recall period are 7 days and 30 days.  If item wasn't consumed in the last 30
*days then no purchases will be recorded for either of those recall periods;

*Cote d'Ivoire:  Leading question recall period is 3 months, recall periods for purchases are 7 days and 30 days.  If household did not
*consume in last 3 months but purchased (for example in last month for later use) then will not be recorded;

*Paraguay:  Leading question recall period is 30 days, recall periods for purchases are 7 days and 30 days;

tab problem_1, missing

**************************************
* (D) Identify surveys with incomplete enumeration due to rule-out leading question on acquisition
**************************************
*Note:  For the rest of the problems the countries were identified by examining each questionnaire individually
*(see excel file "Checking for accounting issues");

gen problem_2=0
la var problem_2 "Rule-out, short-recall-period leading question on acquisition"
replace problem_2=1 if inlist(country,"Ecuador","Honduras")
tab problem_2, missing

**************************************
**************************************
* (E) Identify surveys with rule-out leading question on food purchases
**************************************
**************************************;

gen problem_3=0
la var problem_3 "Rule-out leading question on food purchases"
replace problem_3=1 if country=="Turkmenistan"
tab problem_3, missing

**************************************
**************************************
* (F) Identify surveys with incomplete enumeration due to asking about harvest of home-produced foods instead of consumption 
**************************************
**************************************;

gen problem_4=0
la var problem_4 "Own production question refers to food harvested rather than consumed"
replace problem_4=1 if country=="Burundi" | country=="Mongolia"
tab problem_4, missing

**************************************
**************************************
* (G) Identify surveys for which there is ambiguity about whether to report on acquisition or consumption
**************************************
**************************************;

gen problem_5=0
la var problem_5 "Ambiguity whether to report on acquisition or consumption"
replace problem_5=1 if inlist(country,"Malawi","Benin","Burkina Faso","Congo, Dem. Rep.","Mali","Thailand")
tab problem_5, missing


**************************************
**************************************
* (H) Identify surveys for which there is ambiguity about whether to report on consumption in any month or months with positive consumption
*     (usual month surveys)
**************************************
**************************************;

gen problem_6=0
la var problem_6 " 'Usual month' surveys: Ambiguity whether to report consumption on any moth or months with positive consumption"
replace problem_6=1 if inlist(country,"Gabon","Guatemala","Guinea","Madagascar","Mauritania","Nicaragua","Panama","Togo")
tab problem_6, missing


**************************************
**************************************
* (I) Identify surveys meeting the assessment criterion (those without any of the problems)
**************************************
**************************************;

*This is the reliability criterion;

gen rc_3_cenum=0
la var rc_3_cenum "Reliability criterion - Completeness of enumeration of foods acquired or consumed"
replace rc_3_cenum=1 if problem_1==0 & problem_2==0 & problem_3==0 & problem_4==0 & problem_5==0 & problem_6==0
tab rc_3_cenum, missing
/* table 3.1 */
tab problem_1
tab problem_2
tab problem_3
tab problem_4
tab problem_5
tab problem_6
tab rc_3_cenum

tab problem_1 if int_diary==1
tab problem_2 if int_diary==1
tab problem_3 if int_diary==1
tab problem_4 if int_diary==1
tab problem_5 if int_diary==1
tab problem_6 if int_diary==1
tab rc_3_cenum if int_diary==1

tab problem_1 if int_diary==2 
tab problem_2 if int_diary==2
tab problem_3 if int_diary==2
tab problem_4 if int_diary==2
tab problem_5 if int_diary==2
tab problem_6 if int_diary==2
tab rc_3_cenum  if int_diary==2
sort country
save "$outputdata\HCES_food_assessment_edited.dta", replace

*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
*********************************************************************
*********************************************************************
**     DATE:       September 2012
**     PROGRAM:    HCES Assessment_Reliability_Comprehensiveness of food list
**     AUTHOR:     LSmith
**     INFILE:     HCES Assessment 2012__100-country dataset.dta 
**     OUTFILE:    Data\outfiles\Corrections to MFL
**     PURPOSE:    Analyze reliability of the food data in Household Consumption 
**			       and expenditure surveys:  Comprehensiveness of the at-home food list
*********************************************************************;
/* 
 (A) Determine whether interview, diary or both data will be used to assess this criterion
 (B) Check Master Food List and make corrections
 (C) Add foods that could not be classified into specific food groups in the Master Food List but can be 
     for the Basic Food List to the BFL food group counts 
 (D) Classify into the Basic Food List:  Foods classified under 6 other "major headings" (in tan on the assessment form) that should
     be under a specific BFL food group but are not;
 (E) Calculate the number of Basic Food List food groups represented 
 (F) Calculate the percent of processed foods 
 (G) Check the food-exclusivity of the food list
 (H) Determine whether all three "Comprehensiveness" criteria are met
*/

use "$inputdata\HCES assessment 2012__100-country dataset_with_labels.dta", clear
keep C1 country Q2_1 Q2_1a Q2_2 Q6*
**************************************************
* (A) Determine whether interview, diary or both data will be used to assess this criterion
**************************************************
replace Q2_1=1 if country=="Tunisia"
gen int_diary=1 if Q2_1==1
la var int_diary "Data collection method for food consumed at home  - interview or diary"
replace int_diary=2 if Q2_1==2
list country if Q2_1==3

* Belarus:  According to a special note from the NSC of Belarus after inquiry by Mathew Welch, the diary is filled out
* by the large majority of households.  Households are also administered a "Quarterly expenditure and income questionnaire"; 
* We will base this analysis on the diary data;

* Congo, Dem Rep: Diary filled out but also an interview form for "exceptional food expenses" and expenses at ceremonies;
* We will use the diary since if the exceptional expenses occur during the diary period they should be picked up;

* Republic of Congo: Diary form filled out but also an interview to collect data on "Depenses Retrospectives".  Using same logic
* as above, we will use the diary data;

* Ghana (Interview method is used for rural households and diary for urban);
* Both diary and interview methods using food acquisition approach so it doesn't matter;
* We will base on the interview method, for which we have more information and a bigger population;

* Iraq:  Diary, since only a few foods were asked about using the interview method
* and then, only for "rations received" of these food items;

* Kenya:  Both interview and diary were used for all households, foods and sources.  According to 6/24/12 email from 
* Samuel Kipruto of the Kenya National Bureau of Statistics the diary data were not analyzed so we will use the
* interview data;

* St. Lucia:  Diary for purchases, interview for other.  Since acquisitions data are the ones with the problems we are
* looking into below and they were used for part of the data collection, we will base on interview method;

* Morocco: The questionnaire and interviewer manual are not very clear, but it appears that the daily diary is used to
* collect data on all food sources and for all populations.  We will base on diary data;

* Montenegro: A diary was used for at-home data collection and interview for away from home;
* Since the majority of the food acquired/consumed was likely to be "at home", we will use the diary data;

* Mongolia (Interview and diary methods used for urban households and interview-only for rural households);
* We will base on interview method since used for both urban and rural households;

* Niger:  The main collection of food acquisition data is through a daily diary.  We will base on the diary data; 

* Chad: Diary is used to collect data on purchases, own production and gifts.  Interview is used for own production and gifts plus
* special events expenditures and consumption from own businesses. Since complete data are collected using the diary method, we will base
* on diary data;

* Vanuatu:  Interview used for alcoholic beverages and meals on travel with 7-day recall period.  All rest diary;
* Since most based on data diary data, we will rely on this;
*** This survey collects FCAFH data using both methods but since most likely to be picked up using diary method, will rely on that;


* Belize:  The diary method is used to collect purchases data and interview for home production;
* We will base on diary data;

*Interview surveys;
replace int_diary=1 if inlist(country,"Ghana","Kenya","St. Lucia","Mongolia")

*Diary surveys;
replace int_diary=2 if inlist(country,"Belarus","Congo, Dem. Rep.","Republic of Congo")
replace int_diary=2 if inlist(country,"Iraq","Morocco","Montenegro","Niger","Chad","Vanuatu","Belize")

replace int_diary=2 if country=="St. Lucia"

tab int_diary, m

**************************************************
* (B) Check Master Food List and make corrections
**************************************************
**************************************************;

recode Q6_3-Q6_48 (.=0)

************** Make sure sub-totals in green boxes are less than or equal to totals;
gen check1=1 if  (Q6_9a) > Q6_9
gen check2=1 if  (Q6_26a + Q6_26b + Q6_26c) > Q6_26
gen check3=1 if  (Q6_27a + Q6_27b + Q6_27c) > Q6_27
gen check4=1 if  (Q6_29a) > Q6_29
gen check5=1 if  (Q6_30b) > Q6_30a
gen check6=1 if  (Q6_30a + Q6_30c)> Q6_30
gen check7=1 if  (Q6_32b + Q6_32c) > Q6_32a
gen check8=1 if  (Q6_32a + Q6_32d + Q6_32e) > Q6_32
gen check9=1 if  (Q6_34a + Q6_34b) > Q6_34
gen check10=1 if (Q6_38a + Q6_38b) > Q6_38
gen check11=1 if (Q6_39d + Q6_39e + Q6_39f) > Q6_39c
gen check12=1 if (Q6_39a + Q6_39b + Q6_39c + Q6_39g) > Q6_39
gen check13=1 if (Q6_42a + Q6_42b + Q6_42c) > Q6_42
tab check1
tab check2
tab check3
tab check4
tab check5
tab check6
tab check7
tab check8
tab check9
tab check10
tab check11
tab check12
tab check13

*Corrections (assume the components sum to the total)
replace Q6_27=67  if country=="Brazil"
replace Q6_39c=52 if country=="Brazil"
replace Q6_39c=1 if country=="Turkmenistan"

************** Check that the difference between the number of at-home food items in the 
*              survey and the total from sub-groups is zero;
tab Q6_50, missing
list country if Q6_50~=0 & Q6_50~=.
*Turkmenistan is now 2 off from correction above--will leave as is;

*************** Check foods classified into "Food and beverages" and "Food";
gen Q6_3_orig=Q6_3
gen Q6_4_orig=Q6_4

*These are specified in Q6_52;
*keep country Q6_51 Q6_52;
*Sort by Q6_51 in excel for viewing;
replace Q6_51=Q6_51-1 if country=="Mexico";
replace Q6_51=Q6_51-2 if country=="Panama";
replace Q6_51=Q6_51-3 if country=="Belize" | country=="Guatemala" | country=="Morocco" | country=="Nicaragua"
*list country Q6_3 Q6_4 if country=="Panama" | country=="Mexico" | country=="Belize" | country=="Guatemala" | country=="Morocco" | country=="Nicaragua";
replace Q6_4=Q6_4-1 if country=="Mexico"
replace Q6_4=Q6_4-2 if country=="Panama"
replace Q6_4=Q6_4-3 if country=="Belize" | country=="Guatemala" | country=="Morocco" | country=="Nicaragua"

replace Q6_39 = Q6_39+2 if country=="Panama"
replace Q6_39a= Q6_39a+1 if country=="Panama"
replace Q6_16 = Q6_16+1 if country=="Mexico"
replace Q6_40 = Q6_40+2 if country=="Belize"
replace Q6_39 = Q6_39+3 if country=="Belize"
replace Q6_39g= Q6_39g+3 if country=="Belize"
replace Q6_39 = Q6_39+3 if country=="Guatemala"
replace Q6_39c= Q6_39c+1 if country=="Guatemala"
replace Q6_11 = Q6_11+2 if country=="Morocco"
replace Q6_15 = Q6_15+1 if country=="Morocco"
replace Q6_39 = Q6_39+3 if country=="Nicaragua"
replace Q6_39c= Q6_39c+1 if country=="Nicaragua"
replace Q6_39g= Q6_39g+1 if country=="Nicaragua"

*************** Check foods classified into "Non-specific food products";
gen Q6_39g_orig=Q6_39g

list country Q6_54 if Q6_53~=0
*keep country Q6_54 Q6_53;
*keep if Q6_53~=0;

replace Q6_4  = Q6_4+1 if country=="Angola"
replace Q6_42 = Q6_42+1 if country=="Angola"
replace Q6_39g= Q6_39g-1 if country=="Angola"
replace Q6_39 = Q6_39-1 if country=="Angola"

*Note:  Albania:  Edited Q6_54 on form--there was no problem with listed foods after edit;

replace Q6_39g= Q6_39g-1 if country=="Bhutan" | country=="Cameroun" | country=="Republic of Congo" |country=="Egypt"
replace Q6_39 = Q6_39-1 if  country=="Republic of Congo" |country=="Egypt"
replace Q6_39g= Q6_39g-3 if country=="Congo, Dem. Rep."
replace Q6_39c= Q6_39c+1 if country=="Congo, Dem. Rep."
replace Q6_9  = Q6_9+1 if      country=="Republic of Congo" | country=="Egypt"

replace Q6_4  = Q6_4+1 if country=="Ethiopia"
replace Q6_39g= Q6_39g-1 if country=="Ethiopia"
replace Q6_39 = Q6_39-1 if country=="Ethiopia"

replace Q6_9  = Q6_9+1 if country=="Myanmar"
replace Q6_39g= Q6_39g-1 if country=="Myanmar"
replace Q6_39 = Q6_39-1 if country=="Myanmar"

replace Q6_4  = Q6_4+1   if country=="Myanmar" | country=="Mauritania" | country=="Romania" | country=="Togo" | country=="Vanuatu"
replace Q6_39g= Q6_39g-1 if country=="Myanmar" | country=="Mauritania" | country=="Romania" | country=="Togo" | country=="Vanuatu"
replace Q6_39 = Q6_39-1  if country=="Myanmar" | country=="Mauritania" | country=="Romania" | country=="Togo" | country=="Vanuatu"

*Niger:  Not sure about the three food items (from internet they seem like spices), but will leave as is;

replace Q6_4  = Q6_4+8   if country=="Tunisia"
replace Q6_39g= Q6_39g-8 if country=="Tunisia"
replace Q6_39 = Q6_39-8  if country=="Tunisia"

*************** Other corrections (from doing analysis of next section);
replace Q6_25=Q6_25-1 if country=="Honduras" | country=="Maldives"
replace Q6_27=Q6_27+1 if country=="Honduras"
replace Q6_27a=Q6_27a+1 if country=="Honduras"
replace Q6_26=Q6_26+1 if country=="Maldives"

replace Q6_4=Q6_4+1 if country=="Jamaica"|country=="Niger"
replace Q6_28=Q6_28-1 if country=="Jamaica"|country=="Niger"|country=="Nicaragua"
replace Q6_29a=Q6_29a+1 if country=="Nicaragua"

replace Q6_4=Q6_4+2 if country=="Armenia"
replace Q6_28=Q6_28-2 if country=="Armenia"

replace Q6_31=Q6_31-1 if country=="Ecuador" | country=="Senegal" | country=="Zambia" | country=="El Salvador" | country=="Armenia"
replace Q6_39=Q6_39+1 if country=="Ecuador"
replace Q6_4=Q6_4+1 if country=="Ecuador" | country=="Senegal" | country=="Zambia" | country=="El Salvador" | country=="Armenia"

replace Q6_35=Q6_35-1 if country=="Nicaragua" | country=="Honduras" | country=="Mexico" | country=="Guatemala"
replace Q6_37=Q6_37+1 if country=="Nicaragua" | country=="Honduras" | country=="Mexico" | country=="Guatemala"

replace Q6_44=Q6_44-1 if country=="Mexico"
replace Q6_45=Q6_45+1 if country=="Mexico"

replace Q6_39=Q6_39-1 if country=="Indonesia" | country=="Latvia"
replace Q6_39=Q6_39-2 if country=="Dominica" | country=="Myanmar"
replace Q6_4=Q6_4+1 if country=="Indonesia" | country=="Latvia" | country=="Myanmar"
replace Q6_35=Q6_35+1 if country=="Dominica"
replace Q6_67=Q6_67+1 if country=="Dominica"
replace Q6_39g=Q6_39g+1 if country=="Dominica"
*replace Q6_43=Q6_43+1 if country=="Dominica";
*Above not needed because already classified in Q6_43;
replace Q6_41=Q6_41+1 if country=="Dominica"
replace Q6_39b=Q6_39b+1 if country=="St. Lucia"

****** Angola (see note in Section D);
*There are 19 foods in Q6_39 (but not in Q6_39 sub-sections) that need to remain or be reclassified;

***15 will be reclassified;
replace Q6_39=Q6_39-15 if country=="Angola"

***Diary products; *LEITE CREME;
replace Q6_22=Q6_22+1 if country=="Angola"
***Fruits; *GOIABADA; 
replace Q6_29=Q6_29+1 if country=="Angola"
***Vegetables; *HORTICULAS PARA BEBE, LEGUMES PARA BEBE*; 
replace Q6_32=Q6_32+2 if country=="Angola"
***Classify also into Q6_39g; *SOPAS INSTANTNEAS;
replace Q6_39g=Q6_39g+1 if country=="Angola"
***Classify into "Food" (Q6_4); 
/* SOBREMESAS PARA BEBE A BASE DE FRUTOS (Fruit-based baby desserts)
   FLAN 
   REFEICOES PREPARADAS PARA O BEBE
   PIPOCAS (popcorn)
   TIRAS DE MILHO (Strips of corn)
   MIOLO DE FRUTOS SECOS SALGADOS OU COM PICANTE
   CHEETOS */
*Can't identify so will also classify in Q6_4;
/* BOLA DE BERLIM ;
   ROLAO 
   TCHICUANGA */
replace Q6_4=Q6_4+10 if country=="Angola"

***Stay in Q6_39;
/* GELATINA PARA USO CULINARIO 
   GELATINAS PREPARADAS 
   MOUSSES INSTANTNEOS 
   PUDIM EM PO */

***** Morocco;
*There are 10 food items that were classified into Q6_39 (and not the sub-categories in the green box below it)
*that need to be reclassified;

*** Reclassify to Q6_4;
/*Plats  base de poisson achets et consomms  domicile	
  Autres produits et assimils n.c.a	
*/
replace Q6_4=Q6_4+2 if country=="Morocco"

** Reclassify to Q6_9 & Q6_9a; * Pizza;
replace Q6_9=Q6_9+1 if country=="Morocco"
replace Q6_9a=Q6_9a+1 if country=="Morocco"
	
** Reclassify to Q6_9;  
/*Crpes;
  Chebbakia et produits assimils (briouats, bastilla,mehhancha...)	(translation:  cookies)
  Rghaf, baghrir et assimils (translation:  crepes, pancakes)
  Autres produits  base de crales (sfouf, zemita, sellou...)	 	*/
replace Q6_9=Q6_9+4 if country=="Morocco"

*** Reclassify to Q6_39g; 
  *Soupe (Harira), bouillon, bissara	
  *Potages dshydrates  (translation: Dehydrated soups)
replace Q6_39g=Q6_39g+2 if country=="Morocco"

* Keep in Q6_39; *Prparation pour flans, crmes,...;

replace Q6_39=Q6_39-9 if country=="Morocco"

drop check*
*Save for later use
sort country

save "$outputdata\Corrections to MFL", replace


**************************************************
**************************************************
*  (C) Add foods that could not be classified into specific food groups in the Master Food List but can be 
*      for the Basic Food List to the BFL food group counts 
**************************************************
**************************************************;

recode Q6_75-Q6_88 (.=0)

******************** Foods classified under "Food and beverages" or "Food";
*list country Q6_51 Q6_52;

*Armenia:  Other nuts (hazelnut, chestnut, peanut)
*Azerbaijan	Croats and leguminous bought for house
*Bulgaria: Nuts and seeds
*Bosnia and Herzegovina:  Nuts, almonds, chestnuts, peanuts
*Bolivia: Peanuts, lentils, beans
*Gambia	Other pulses, nuts & seeds
*Ghana: Other pulses and nuts 
*Jamaica	Nuts (peanuts, cashew, coconut, ...)
*Nigeria: Other nuts/seeds/pulses
*Papua New Guinea: Other nuts (e.g., peanut, galip, okari)
*St. Lucia	Nuts (peanuts, cashew nuts, mixed nut)
*Timor-Leste: Other legumes/nuts
*Togo: Autres noix et lgumineuses
*Vietnam: Peanut, sesame seeds
*Pakistan: Other (under dry fruits and nuts) (almond, walnut, chilghoza, cashew, pistachio, peanuts, sesame seeds, coconut, etc.) */;

replace Q6_77=Q6_77+1 if inlist(country,"Armenia","Azerbaijan","Bulgaria","Bosnia and Herzegovina","Bolivia")
replace Q6_77=Q6_77+1 if inlist(country,"Gambia","Ghana","Jamaica","Nigeria","Papua New Guinea","St. Lucia")
replace Q6_77=Q6_77+1 if inlist(country,"Timor-Leste","Togo","Vietnam","Pakistan")
* 15 countries;

*Papua New Guinea: Other dairy products (e.g., cheese, ice cream);
replace Q6_82=Q6_82+1 if country=="Papua New Guinea"

*Cameroon: Other salt, spices, sauces and seasonings;
replace Q6_86=Q6_86+1 if country=="Cameroun"

******************** Foods classified under "Non-specific food products";
replace Q6_87 = Q6_87+1 if country=="Angola"
replace Q6_86 = Q6_86+1 if country=="Bhutan" | country=="Cameroun"
replace Q6_75=Q6_75+1 if country=="Republic of Congo" | country=="Egypt" | country=="Myanmar"


**************************************************
**************************************************
* (D) Classify into the Basic Food List:  Foods classified under 6 other "major headings" (in tan on the assessment form) 
*     that should be under a specific BFL food group but are not
**************************************************
**************************************************;

*Note:  In some cases these are already classified into the correct BFL food list, but in others
*the people filling in the forms did not correctly number them into Q6_57, etc.
*Correcting for that here;

********** Foods classified under "Milk, cheese and eggs" that are only milk and milk products;
*keep country Q6_55 Q6_56 Q6_57;
*sort Q6_55;
replace Q6_82=Q6_82+1 if inlist(country,"Pakistan","Benin","Chad","Papua New Guinea","Burundi","Djibouti","Paraguay")
replace Q6_82=Q6_82+1 if inlist(country,"Madagascar","Angola","Lao PDR","Guatemala","Senegal","Nicaragua","Togo","Honduras")
*15 countries;

********** Foods classified under "Oils and fats" that are only oils and fats;
*keep country Q6_58 Q6_59 Q6_60;
*sort Q6_58;
replace Q6_84=Q6_84+1 if inlist(country,"Kosovo","Honduras","Cambodia","Colombia","Paraguay","Latvia","Ethiopia","Togo")
replace Q6_84=Q6_84+1 if inlist(country,"Guinea-Bissau","Sao Tome e Principe","Maldives","Belize","Sierra Leone")
replace Q6_84=Q6_84+1 if inlist(country,"Papua New Guinea","Kazakhstan","Mexico","Mongolia","Swaziland","Fiji","Mozambique","Yemen","Lithuania")
*22 countries;
replace Q6_84=Q6_84+2 if inlist(country,"Lesotho","Bangladesh","Brazil")
*3 countries;

********** Foods classified under "Fruits" that are only fruits;
*keep country Q6_61 Q6_62 Q6_63;
*sort Q6_61;
replace Q6_79=Q6_79+1 if inlist(country,"Djibouti","Guatemala","Afghanistan","Bolivia","Uganda","Liberia","Timor-Leste")
replace Q6_79=Q6_79+1 if inlist(country,"Vietnam","Nepal","Bangladesh","Kenya","Sierra Leone","Burundi","Nigeria")
replace Q6_79=Q6_79+1 if inlist(country,"Ghana","Cambodia","Azerbaijan","Papua New Guinea","Bosnia and Herzegovina","Kosovo")
replace Q6_79=Q6_79+1 if inlist(country,"Latvia","Ethiopia","Dominica","Mongolia","Zambia","Malawi","Cape Verde","Gambia")
replace Q6_79=Q6_79+1 if inlist(country,"Honduras","Indonesia","Iraq","Kazakhstan","Lao PDR","Lesotho","Mexico")
replace Q6_79=Q6_79+1 if inlist(country,"South Africa","Sri Lanka","St. Lucia","Swaziland")
*40 countries;
replace Q6_79=Q6_79+2 if country=="Armenia" | country=="Seychelles" | country=="Sri Lanka"
replace Q6_79=Q6_79+3 if country=="Iraq"
replace Q6_79=Q6_79+4 if country=="Nicaragua"
replace Q6_79=Q6_79+4 if country=="Honduras"
replace Q6_79=Q6_79+8 if country=="Mexico"

********** Foods classified under "Vegetables" that are only vegetables;
*keep country Q6_64 Q6_65 Q6_66a Q6_66b Q6_66c;
*sort Q6_64;
replace Q6_78=Q6_78+1 if inlist(country,"Burundi","Kosovo","Philippines","Bosnia and Herzegovina","Sierra Leone","Togo")
replace Q6_78=Q6_78+1 if inlist(country,"Afghanistan","Bulgaria","Ethiopia","Uganda","Papua New Guinea","Timor-Leste")
replace Q6_78=Q6_78+1 if inlist(country,"Benin","Mongolia","Nigeria","India","Kenya","Uzbekistan","Vietnam","Bangladesh")
replace Q6_78=Q6_78+1 if inlist(country,"Fiji","Ghana","Liberia","Zambia","El Salvador","Nepal","Bolivia","Malawi")
replace Q6_78=Q6_78+1 if inlist(country,"Sri Lanka","Maldives","South Africa","Swaziland","Indonesia","Gambia","Armenia")
replace Q6_78=Q6_78+1 if inlist(country,"Morocco","Djibouti","Mexico")
*37 countries;
replace Q6_78=Q6_78+2 if country=="Kazakhstan" | country=="Tajikistan"
*3 countries;
replace Q6_78=Q6_78+3 if country=="Cameroun" | country=="Seychelles"
*2 countries;
replace Q6_78=Q6_78+4 if country=="Nicaragua"
replace Q6_78=Q6_78+7 if country=="Honduras"

*Other correction to BFL classification;
replace Q6_78=Q6_78-1 if country=="Ecuador" | country=="Senegal" | country=="Zambia" | country=="El Salvador"
replace Q6_86=Q6_86+1 if country=="Ecuador" | country=="Senegal" | country=="Zambia" | country=="El Salvador"

********** Foods classified under "Vegetables" that are only Pulses, nuts and seeds;
replace Q6_77=Q6_77+1 if inlist(country,"Cambodia","Djibouti","Tajikistan","Malawi","Ghana","Pakistan")
*7 countries;
replace Q6_77=Q6_77+3 if country=="Sri Lanka"

********** Foods classified under "Vegetables" that are only Roots and tubers (including potatoes), and plantains;
*Note:  Morocco already had a "1" for Q6_66b;
replace Q6_76=Q6_76+1 if inlist(country,"Liberia","Bolivia","Malawi","Lesotho")
*4 countries;

********** Foods classified under "Sugar, jam, honey, chocolate and confectionery" that are in Q6_35 
*(For the basic food list all can be included unless they are icecream); 
*keep country Q6_67 Q6_68 Q6_69a Q6_69b;
*sort Q6_67;
replace Q6_85=Q6_85+1 if inlist(country,"Iraq","Bangladesh","Mongolia","Kenya","Cameroun","Bolivia","Sri Lanka")
replace Q6_85=Q6_85+1 if inlist(country,"Republic of Marshal Islands","Lao PDR","Indonesia","Kazakhstan","Maldives")
replace Q6_85=Q6_85+1 if inlist(country,"Gambia","Jamaica","Tunisia","Seychelles","Honduras")
*18 countries;
replace Q6_85=Q6_85+2 if inlist(country,"Malawi","Panama","Dominica")
*2 countries;
replace Q6_85=Q6_85+3 if country=="Mexico"
replace Q6_85=Q6_85+4 if country=="Guatemala"

********** Foods classified under "Alcoholic beverages" that are only alcoholic beverages (not stimulants);
*keep country Q6_72 Q6_73 Q6_74;
*sort Q6_72;
replace Q6_88=Q6_88+1 if inlist(country,"Bolivia","Vanuatu","Ghana","Niger","Sierra Leone","Papua New Guinea")
replace Q6_88=Q6_88+1 if inlist(country,"Panama","Benin","Iraq","Vietnam","Guatemala","Zambia","Madagascar")
replace Q6_88=Q6_88+1 if inlist(country,"Uzbekistan","Burundi","Timor-Leste","Uganda","Togo","Chad","Armenia")
replace Q6_88=Q6_88+1 if inlist(country,"Nepal","Tajikistan","Mongolia","Honduras","Colombia","Malawi","Senegal")
replace Q6_88=Q6_88+1 if inlist(country,"Sri Lanka","Guinea","Brazil","Seychelles","Mozambique","Jamaica","Lao PDR")
replace Q6_88=Q6_88+1 if inlist(country,"Indonesia","Swaziland","Nigeria","Thailand")
*38 countries;
replace Q6_88=Q6_88+2 if inlist(country,"Gabon","Fiji","India","Cte d'Ivoire","Kazakhstan","Angola","Mexico")
*7 countries;
replace Q6_88=Q6_88+3 if country=="Liberia"

********** Foods that are included in Q6_92 (and specified in Q6_93);
*These are foods that were not classified into the Basic Food List food groups
*automatically but that are still not identified.  Here if they do fall into a BFL
*food group they are classified there;
tab Q6_92, missing
*keep country Q6_90 Q6_91 Q6_92 Q6_93;
*sort Q6_92;

*Condiments, spices, baking agents, and vegetable-based stimulants;
replace Q6_86=Q6_86+1 if inlist(country,"Sierra Leone","Nigeria","Papua New Guinea","Uzbekistan","Republic of Congo")
replace Q6_86=Q6_86+1 if inlist(country,"Sri Lanka","Gabon","Bangladesh","Latvia","Kazakhstan","Bhutan","Turkmenistan")
replace Q6_86=Q6_86+1 if inlist(country,"Ukraine","El Salvador","Senegal","Mexico","Thailand","Lao PDR","Myanmar")
*19 countries;
replace Q6_86=Q6_86+2 if inlist(country,"Lesotho","Swaziland","Jamaica")
*3 countries;
replace Q6_86=Q6_86+3 if inlist(country,"Mali","Tunisia","St. Lucia")
*3 countries;
replace Q6_86=Q6_86+3 if country=="South Africa"
replace Q6_86=Q6_86+5 if country=="Burkina Faso"

********* Make corrections for Angola;
*Angola has many food items (in Q6_92) that should have been classified elsewhere; 

/*  
  1) BOLA DE BERLIM ; 2) HORTICULAS PARA BEBE ; 3) LEGUMES PARA BEBE ; 4) ROLAO ; 5) SOBREMESAS PARA BEBE A BASE DE FRUTOS ; 
  6) FLAN ; 7) GELATINA PARA USO CULINARIO ; 8) GELATINAS PREPARADAS ;9) GOIABADA  ; 10) LEITE CREME ; 11) MOUSSES INSTANTNEOS ; 
  12) PUDIM EM PO ; 13) SOPAS INSTANTNEAS ; 14) REFEICOES PREPARADAS PARA O BEBE ; 15) PIPOCAS ; 16) TIRAS DE MILHO ; 
  17) MIOLO DE FRUTOS SECOS SALGADOS OU COM PICANTE ; 18) TCHICUANGA ; 19) CHEETOS
*/

** Reclassify to Sugar, jam, etc.;
*GELATINA PARA USO CULINARIO, GELATINAS PREPARADAS, MOUSSES INSTANTNEOS, PUDIM EM PO;
replace Q6_85=Q6_85+4 if country=="Angola"

** Diary products;  *LEITE CREME;
replace Q6_82=Q6_82+1 if country=="Angola"

** Fruits; *GOIABADA; 
replace Q6_79=Q6_79+1 if country=="Angola"

** Vegetables; *HORTICULAS PARA BEBE, LEGUMES PARA BEBE; 
replace Q6_78=Q6_78+2 if country=="Angola"

**All the rest will remain unclassified in the BFL;

********** Make corrections for Morocco;
*There are 10 food items that were classified into Q6_39 (and not the sub-categories in the green box below it)
*that need to be reclassified;

*** Classify into cereals; 
/* Chebbakia et produits assimils (briouats, bastilla,mehhancha...)	
   Rghaf, baghrir et assimils	
   Autres produits  base de crales (sfouf, zemita, sellou...)	
   Pizza	
   Crpes	
*/
replace Q6_75=Q6_75+5 if country=="Morocco"

*** Reclassify to Sugar, jam, etc.; * Prparation pour flans, crmes, ...:	
replace Q6_85=Q6_85+1 if country=="Morocco"

/***The rest will remain unclassified in the BFL.  
  Plats  base de poisson achets et consomms  domicile	
  Soupe (Harira), bouillon, bissara	
  Autres produits et assimils n.c.a	
  Potages dshydrates	
*/
 
********* Brazil:  52 food items are in this category, and they are not listed individually in Q6_93;
*Not doing anything here.  Food list is so large that it won't make a difference to the
*assessment for Brazil or overall;

**************************************************
**************************************************
* (E) Calculate the number of Basic Food List food groups represented 
**************************************************
**************************************************;

*There are three countries for which the food list information is missing because it was
*not available at the time of the assessment.  Drop these countries from the analysis; 
*@@@ drop if inlist(country,"Georgia","Montenegro","Russia");

/*Check for missings;
tab Q6_75, missing;
tab Q6_76, missing;
tab Q6_77, missing;
tab Q6_78, missing;
tab Q6_79, missing;
tab Q6_80, missing;
tab Q6_81, missing;
tab Q6_82, missing;
tab Q6_83, missing;
tab Q6_84, missing;
tab Q6_85, missing;
tab Q6_86, missing;
tab Q6_87, missing;
tab Q6_88, missing; */
*No missings;

gen fg1=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg1=1 if Q6_75>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg2=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg2=1 if Q6_76>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg3=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg3=1 if Q6_77>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg4=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg4=1 if Q6_78>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg5=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg5=1 if Q6_79>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg6=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg6=1 if Q6_80>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg7=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg7=1 if Q6_81>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg8=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg8=1 if Q6_82>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg9=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg9=1 if Q6_83>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg10=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg10=1 if Q6_84>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg11=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg11=1 if Q6_85>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg12=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg12=1 if Q6_86>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg13=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg13=1 if Q6_87>0 & !inlist(country,"Georgia","Montenegro","Russia")
gen fg14=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace fg14=1 if Q6_88>0 & !inlist(country,"Georgia","Montenegro","Russia")
*recode fg1-fg14 (1=100) 

list country if fg14==0 & !inlist(country,"Georgia","Montenegro","Russia")

*recode fg1-fg14 (100=1) /* could also be done this way */
egen numfg=rsum(fg1-fg14) if !inlist(country,"Georgia","Montenegro","Russia")
tab numfg, missing

gen all_14fg=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var all_14fg "All 14 Basic Food Groups are presented"
replace all_14fg=1 if numfg==14 & !inlist(country,"Georgia","Montenegro","Russia")

tab all_14fg if !inlist(country,"Georgia","Montenegro","Russia"), missing
tab all_14fg if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") 
tab all_14fg if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia") 

la var fg1 "Cereals"
la var fg2 "Roots, tubers and plantains"
la var fg3 "Pulses, nuts and seeds"
la var fg4 "Vegetables"
la var fg5 "Fruits"
la var fg6 "Meat, poultry, and offal"
la var fg7 "Fish and seafood"
la var fg8 "Milk and milk products"
la var fg9 "Eggs"
la var fg10 "Oils and fats"
la var fg11 "Sugar, jam, honey, chocolate & sweets"
la var fg12 "Condiments, spices and baking agents"
la var fg13 "Non-alcoholic beverages"
la var fg14 "Alcoholic beverages"

*sum fg1-fg14 all_fg if !inlist(country,"Georgia","Montenegro","Russia") /* figure 3.3 */
tab1 fg1-fg14 all_14fg  

*recode all_fg (100=1)
preserve
* Save for later use; 
sort country
keep country Q6* fg* all_14fg int_diary
save "$outputdata\food list.dta", replace

**************************************************
**************************************************
* (F) Calculate the percent of processed foods 
**************************************************
**************************************************;

*Note:  The percent processed includes those referring to food consumed away from home
*so we are actually getting the percent for the whole food list, not just the at-home list;

*Data are missing for Brazil and Jamaica.  From browsing the food list it is clear that Brazil meets the "40%" criteria;
*Jamaica: Can easily fill in from interview questionnaire;
replace Q6_2b=44 if country=="Jamaica"
*Added correct number to Jamaica form;

list country Q6_1 Q6_2a Q6_2b

gen perc_proc=Q6_2b*100/Q6_1 if !inlist(country,"Georgia","Montenegro","Russia")
tab perc_proc if !inlist(country,"Georgia","Montenegro","Russia")

gen min_proc=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var min_proc "At least 40% of food items are processed"
replace min_proc=1 if perc_proc>=40 & perc_proc~=. & !inlist(country,"Georgia","Montenegro","Russia")
replace min_proc=1 if country=="Brazil"

tab min_proc if !inlist(country,"Georgia","Montenegro","Russia"), missing
tab min_proc if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia"), missing
tab min_proc if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia"), missing

drop perc_proc
**************************************************
**************************************************
*(G) Check the food-exclusivity of food list
**************************************************
**************************************************;

tab Q6_43 if !inlist(country,"Georgia","Montenegro","Russia"), missing
list country Q6_43 Q6_71 if Q6_43>0 & !inlist(country,"Georgia","Montenegro","Russia")

*Only three of these mix a food item with a non-food item(tobacco product);
*Dominica and Kazakhstan--Tobacco and alcohol;
*Mauritania--Tobacco and kola nuts, a vegetable-based stimulant;

gen food_exc=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var food_exc "Food items are all food-exclusive"
replace food_exc=1 if (country~="Dominica" & country~="Kazakhstan" & country~="Mauritania") & !inlist(country,"Georgia","Montenegro","Russia")

tab food_exc if !inlist(country,"Georgia","Montenegro","Russia"), missing
tab food_exc if int_diar==1 & !inlist(country,"Georgia","Montenegro","Russia"), missing
tab food_exc if int_diar==2 & !inlist(country,"Georgia","Montenegro","Russia"), missing

**************************************************
**************************************************
*(H) Determine whether all three "Comprehensiveness" criteria are met
**************************************************
**************************************************;
/* figure 3.4 */
tab all_14fg if !inlist(country,"Georgia","Montenegro","Russia"), missing
tab min_proc if !inlist(country,"Georgia","Montenegro","Russia"), missing
tab food_exc if !inlist(country,"Georgia","Montenegro","Russia"), missing

gen rc_4_compfl=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var rc_4_compfl "Surveys meeting the food list comprehensiveness criteria"
replace rc_4_compfl=1 if (all_14fg==1 & min_proc==1 & food_exc==1) & !inlist(country,"Georgia","Montenegro","Russia")

tab rc_4_compfl if !inlist(country,"Georgia","Montenegro","Russia"), missing /* figure 3.4 */
tab rc_4_compfl if int_diar==1 & !inlist(country,"Georgia","Montenegro","Russia"), missing
tab rc_4_compfl if int_diar==2 & !inlist(country,"Georgia","Montenegro","Russia"), missing

*Save for later use;
saveold "$outputdata\compfl.dta", replace
keep country rc_4_compfl
sort country
merge 1:1 country using "$outputdata\HCES_food_assessment_edited.dta"
drop _merge
save "$outputdata\HCES_food_assessment_edited.dta", replace

restore
*********************************************************************
*********************************************************************
**     DATE:       September 2012
**     PROGRAM:    HCES Assessment_Reliability_Specificity of food list
**     AUTHOR:     LSmith
**     INFILE:     
**     OUTFILE:    None 
**     PURPOSE:    Analyze reliability of the food data in Household Consumption 
**			       and Expenditure surveys:  Specificity of the at-home food list
*********************************************************************

*The minimum reliability criteria for specificity of the food list are:
*  (1) At least 10 of the Basic Food List (BFL) food groups have the minimum number of food items;
*  (2) Less than five percent of food items (that are not prepared dishes) span more than one of the BFL food groups;

/*
 (A) Determine whether interview, diary or both data will be used to assess this criterion -- DONE 
 (B) Calculate total number of at-home food items 
 (C) Calculate percent of countries with minimum number of at-home food items in BFL food groups
 (D) Determine percent of at-home food items that span more than one BFL food group
 (E) Make variable for calculating percent of countries meeting minimum reliability criterion
*/

**************************************************
**************************************************
*  (B) Calculate total number of at-home food items 
**************************************************
**************************************************;
/*
merge 1:1 country using "C:\Users\wb308892\Desktop\Food_Assessment\done\food list.dta"
tab _merge
keep if _merge==3
drop _merge
*/
if !inlist(country,"Georgia","Montenegro","Russia") {

gen num_items=Q6_1-Q6_2a
la var num_items "Number of food items"
tab num_items

*Drop three countries with no food list data;
*drop if country=="Georgia" | country=="Montenegro" | country=="Russia";

sum num_items if int_diary==1 /* Table 3.2 --- mean number of food items */
sum num_items if int_diary==2 /* Table 3.2 --- mean number of food items */
sum num_items /* Table 3.2 --- mean number of food items */

sum num_items if country~="Brazil"
sum num_items if country~="Brazil" & int_diary==2

}

*Cereals;
gen num_group1=Q6_75 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group1 "Number of food items in cereals food group" 
*Roots, tubers and plantains;
gen num_group2=Q6_76 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group2 "Number of food items in roots, tubers and plantains food group"
*Pulses, nuts and seeds;
gen num_group3=Q6_77 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group3 "Number of food items in pulses, nuts and seeds food group"
*Vegetables;
gen num_group4=Q6_78 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group3 "Number of food items in vegetables food group"
*Fruits;
gen num_group5=Q6_79 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group5 "Number of food items in fruits food group"
*Meat, poultry, and offal
gen num_group6=Q6_80 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group6 "Number of food items in meat, poultry, and offal food group"
*Fish and seafood;
gen num_group7=Q6_81 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group7 "Number of food items in fish and seafood food group"
*Milk and milk products;
gen num_group8=Q6_82 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group8 "Number of food items in milk and milk products food group"
*Eggs;
gen num_group9=Q6_83 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group9 "Number of food items in eggs food group"
*Oils and fats;
gen num_group10=Q6_84 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group10 "Number of food items in oils and fats food group"
*Sugar, jam, honey, chocolate and sweets;
gen num_group11=Q6_85 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group11 "Number of food items in sugar, jam, honey, chocolate and sweets food group"
*Condiments, spices, baking agents, and vegetable-based stimulants;
gen num_group12=Q6_86 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group12 "Number of food items in condiments, spices, baking agents, and vegetable-based stimulants food group"
*Non-alcoholic beverages; 
gen num_group13=Q6_87 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group13 "Number of food items in non-alcoholic beverages food group"
*Alcoholic beverages; 
gen num_group14=Q6_88 if !inlist(country,"Georgia","Montenegro","Russia")
la var num_group14 "Number of food items in alcoholic beverages food group"

sum num_group* if !inlist(country,"Georgia","Montenegro","Russia")
*No missings;

*For info for Comprehensiveness analysis;
*Average percent of food items in groups 8, and 10-14 (mostly processed foods);
gen perc_proc_g=(num_group8+num_group10+num_group11+num_group12+num_group13+num_group14)*100/(Q6_1-Q6_2a) if !inlist(country,"Georgia","Montenegro","Russia")
sum perc_proc_g if !inlist(country,"Georgia","Montenegro","Russia")

********** Make variables identifying whether minimum number of food items is reached
*          for each food group;
gen min_g1=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g1=1 if num_group1>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g2=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g2=1 if num_group2>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g3=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g3=1 if num_group3>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g4=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g4=1 if num_group4>=10 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g5=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g5=1 if num_group5>=10 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g6=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g6=1 if num_group6>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g7=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g7=1 if num_group7>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g8=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g8=1 if num_group8>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g9=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g9=1 if num_group9>=1 &  !inlist(country,"Georgia","Montenegro","Russia")
gen min_g10=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g10=1 if num_group10>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g11=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g11=1 if num_group11>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g12=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g12=1 if num_group12>=10 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g13=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g13=1 if num_group13>=5 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_g14=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_g14=1 if num_group14>=5 & !inlist(country,"Georgia","Montenegro","Russia")

la var min_g1 "Cereals (5) - Minimum number of food items in BFGs"
la var min_g2 "Roots, tubers and plantains (5) - Minimum number of food items in BFGs"
la var min_g3 "Pulses, nuts and seeds (5) - Minimum number of food items in BFGs"
la var min_g4 "Vegetables (10)  - Minimum number of food items in BFGs"
la var min_g5 "Fruits (10) - Minimum number of food items in BFGs"
la var min_g6 "Meat, poultry, and offal (5) - Minimum number of food items in BFGs"
la var min_g7 "Fish and seafood (5) - Minimum number of food items in BFGs"
la var min_g8 "Milk and milk products (5) - Minimum number of food items in BFGs"
la var min_g9 "Eggs (1) - Minimum number of food items in BFGs"
la var min_g10 "Oils and fats (5) - Minimum number of food items in BFGs"
la var min_g11 "Sugar, jam, honey, chocolate & sweets (5) - Minimum number of food items in BFGs"
la var min_g12 "Condiments, spices and baking agents (10) - Minimum number of food items in BFGs"
la var min_g13 "Non-alcoholic beverages (5) - Minimum number of food items in BFGs"
la var min_g14 "Alcoholic beverages (5) - Minimum number of food items in BFGs"

tab1 min_g* if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (A) */
tab1 min_g* if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (A) */
tab1 min_g* if !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (A) */
*sum min_g* if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (A) */
*sum min_g* if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (A) */
*sum min_g* if !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (A) */


********** Make variable identifying whether minimum number of food items is reached for
*          at least 10, 11, 12, 13 and 14 (all) food groups;

*recode min_g1-min_g14 (100=1)
egen num_fg_min=rsum(min_g1-min_g14) if !inlist(country,"Georgia","Montenegro","Russia")
tab num_fg_min if !inlist(country,"Georgia","Montenegro","Russia")
*No missings;

gen min_numfg10=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_numfg10=1 if num_fg_min>=10 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_numfg11=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_numfg11=1 if num_fg_min>=11 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_numfg12=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_numfg12=1 if num_fg_min>=12 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_numfg13=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_numfg13=1 if num_fg_min>=13 & !inlist(country,"Georgia","Montenegro","Russia")
gen min_numfg14=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace min_numfg14=1 if num_fg_min>=14 & !inlist(country,"Georgia","Montenegro","Russia")

la var min_numfg10 "Minimum number of food items in at least 10 Basic Food Group(BFGs)"
la var min_numfg11 "Minimum number of food items in at least 11 Basic Food Group(BFGs)"
la var min_numfg12 "Minimum number of food items in at least 12 Basic Food Group(BFGs)"
la var min_numfg13 "Minimum number of food items in at least 10 Basic Food Group(BFGs)"
la var min_numfg14 "Minimum number of food items in at least 14 (all) Basic Food Group(BFGs)"

tab1 min_numfg10-min_numfg14 if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") 
tab1 min_numfg10-min_numfg14 if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia") 
tab1 min_numfg10-min_numfg14 if !inlist(country,"Georgia","Montenegro","Russia") 

*sum min_numfg10-min_numfg14 if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (B) */ 
*sum min_numfg10-min_numfg14 if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia") /* Table 3.2 Specificity if the food list (B) */
*sum min_numfg10-min_numfg14 if !inlist(country,"Georgia","Montenegro","Russia")

gen crit_1=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var crit_1 "At least 10 of the Basic Food Groups have the minimum number of food items"
*replace crit_1=1 if min_numfg10==100 & !inlist(country,"Georgia","Montenegro","Russia")
replace crit_1=1 if min_numfg10==1 & !inlist(country,"Georgia","Montenegro","Russia")
tab crit_1 if !inlist(country,"Georgia","Montenegro","Russia"), missing

**************************************************
**************************************************
* (D) Determine percent of at-home food items that span more than one BFL food group
**************************************************
**************************************************;

***************************************
* Calculate total number of food items in the BFL
***************************************;

egen sum_BFL=rsum(num_group1-num_group14) if !inlist(country,"Georgia","Montenegro","Russia")
tab sum_BFL if !inlist(country,"Georgia","Montenegro","Russia"), missing

gen diff=num_items-sum_BFL if !inlist(country,"Georgia","Montenegro","Russia")
tab diff if !inlist(country,"Georgia","Montenegro","Russia"), missing

***************************************
* Identify items that span more than one food group 
***************************************;

recode Q6_57 Q6_60 Q6_63 Q6_66* Q6_69a Q6_69b Q6_74 (.=0)

*See excel file "Spreadsheet for analyzing specificity of food list" for lists of foods and
*their classifications;

******************** Q6_3 & Q6_4:  Foods in the MFL that do not fall into any specific food group:
   
*In the "Comprehensiveness" program we made corrections to Q6_3 and Q6_4.  Can we rely on the original written list
*of foods for understanding what kinds of foods are in these categories?;
gen sum_Q634=Q6_3+Q6_4 
sort sum_Q634
list country sum_Q634 Q6_3_orig Q6_3 Q6_4_orig Q6_4
*Note:  No difference between Q6_4 and Q6_4_orig;
gen diffn=Q6_4_orig - Q6_4
sort diffn
list country sum_Q634 diffn Q6_4_orig Q6_4 if sum_Q634>0
*Yes:  most countries have no differences and for the ones with any difference, they are mostly very small; 

/*
*Determine which food items span the groups, keeping track of which are specific prepared foods;
keep country Q6_3 Q6_4 Q6_4_orig Q6_52 sum_Q634 diffn;
order country Q6_3 Q6_4 Q6_4_orig diffn Q6_52 sum_Q634;
keep if sum_Q634>0;
sort diffn;
*/

*Food items that span the groups but are not prepared foods;
gen span_g=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var span_g "Food items that span the groups but are not prepared foods"
replace span_g=	1	if country=="Armenia"
replace span_g=	1	if country=="Romania"
replace span_g=	1	if country=="Latvia"
replace span_g=	1	if country=="Ethiopia"
replace span_g=	1	if country=="Senegal"
replace span_g=	1	if country=="Vanuatu"
replace span_g=	1	if country=="Egypt"
replace span_g=	1	if country=="Cape Verde"
replace span_g=	1	if country=="Lao PDR"
replace span_g=	1	if country=="Burkina Faso"
replace span_g=	1	if country=="Burundi"
replace span_g=	1	if country=="Sudan"
replace span_g=	1	if country=="Guinea"
replace span_g=	1	if country=="Bangladesh"
replace span_g=	1	if country=="Guinea-Bissau"
replace span_g=	1	if country=="Benin"
replace span_g=	1	if country=="Rwanda"
replace span_g=	1	if country=="Gambia"
replace span_g=	1	if country=="Bulgaria"
replace span_g=	1	if country=="Paraguay"
replace span_g=	1	if country=="Mongolia"
replace span_g=	1	if country=="Belize"
replace span_g=	1	if country=="Guatemala"
replace span_g=	2	if country=="Angola"
replace span_g=	2	if country=="Myanmar"
replace span_g=	2	if country=="Niger"
replace span_g=	2	if country=="Zambia"
replace span_g=	2	if country=="Togo"
replace span_g=	2	if country=="Vietnam"
replace span_g=	2	if country=="South Africa"
replace span_g=	2	if country=="Bolivia"
replace span_g=	2	if country=="Maldives"
replace span_g=	2	if country=="Union des Comores"
replace span_g=	2	if country=="Belarus"
replace span_g=	2	if country=="Cambodia"
replace span_g=	2	if country=="Uganda"
replace span_g=	2	if country=="Lesotho"
replace span_g=	2	if country=="Afghanistan"
replace span_g=	2	if country=="Yemen"
replace span_g=	2	if country=="Honduras"
replace span_g=	2	if country=="Cameroun"
replace span_g=	2	if country=="Panama"
replace span_g=	2	if country=="Nicaragua"
replace span_g=	3	if country=="Tunisia"
replace span_g=	3	if country=="Timor-Leste"
replace span_g=	3	if country=="Madagascar"
replace span_g=	3	if country=="Kosovo"
replace span_g=	3	if country=="Philippines"
replace span_g=	3	if country=="Swaziland"
replace span_g=	3	if country=="Uzbekistan"
replace span_g=	3	if country=="Liberia"
replace span_g=	4	if country=="Gabon"
replace span_g=	4	if country=="Dominica"
replace span_g=	4	if country=="Seychelles"
replace span_g=	4	if country=="Sierra Leone"
replace span_g=	4	if country=="Lithuania"
replace span_g=	4	if country=="Thailand"
replace span_g=	4	if country=="Fiji"
replace span_g=	4	if country=="Chad"
replace span_g=	4	if country=="Mozambique"
replace span_g=	4	if country=="Mali"
replace span_g=	5	if country=="Jamaica"
replace span_g=	5	if country=="Indonesia"
replace span_g=	5	if country=="Pakistan"
replace span_g=	5	if country=="Sao Tome e Principe"
replace span_g=	5	if country=="Azerbaijan"
replace span_g=	5	if country=="Mexico"
replace span_g=	6	if country=="Mauritania"
replace span_g=	6	if country=="El Salvador"
replace span_g=	6	if country=="Malawi"
replace span_g=	6	if country=="India"
replace span_g=	6	if country=="Sri Lanka"
replace span_g=	6	if country=="Colombia"
replace span_g=	7	if country=="Republic of the Marshall Islands"
replace span_g=	8	if country=="Morocco"
replace span_g=	9	if country=="St. Lucia"
replace span_g=	14	if country=="Kazakhstan"

*Food items that span the groups but are prepared foods;
gen prep=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var prep "Food items that span the groups but are prepared foods"
replace prep=	1	if country=="Myanmar"
replace prep=	1	if country=="Niger"
replace prep=	1	if country=="Vanuatu"
replace prep=	1	if country=="Togo"
replace prep=	1	if country=="Kazakhstan"
replace prep=	1	if country=="Peru"
replace prep=	1	if country=="Madagascar"
replace prep=	1	if country=="Albania"
replace prep=	1	if country=="Papua New Guinea"
replace prep=	1	if country=="Maldives"
replace prep=	1	if country=="Fiji"
replace prep=	1	if country=="Mali"
replace prep=	2	if country=="Ethiopia"
replace prep=	2	if country=="South Africa"
replace prep=	2	if country=="Lithuania"
replace prep=	2	if country=="Belarus"
replace prep=	2	if country=="Swaziland"
replace prep=	2	if country=="Honduras"
replace prep=	2	if country=="Belize"
replace prep=	3	if country=="Sri Lanka"
replace prep=	4	if country=="Sierra Leone"
replace prep=	4	if country=="St. Lucia"
replace prep=	4	if country=="Bangladesh"
replace prep=	5	if country=="Republic of the Marshall Islands"
replace prep=	5	if country=="Gambia"
replace prep=	6	if country=="Cape Verde"
replace prep=	7	if country=="Guatemala"
replace prep=	8	if country=="Angola"
replace prep=	9	if country=="Indonesia"
replace prep=	10	if country=="Tunisia"


******************** Q6_39g: Food items containing the following with no specific ingredients: sauces, dessert preparations, soups, 
*                    and homognized baby food (and dietary preparations);
/*
keep country Q6_39g_orig Q6_39g Q6_54;
order country Q6_39g_orig Q6_39g Q6_54;
sort Q6_39g_orig; 
keep if Q6_39g~=0 | Q6_39g_orig~=0;
*/

gen non_spec=0 if !inlist(country,"Georgia","Montenegro","Russia")
la var non_spec "Food items containing non specific ingredients"
replace non_spec=	1	if country=="Honduras"
replace non_spec=	1	if country=="Armenia"
replace non_spec=	1	if country=="Uganda"
replace non_spec=	1	if country=="Uzbekistan"
replace non_spec=	1	if country=="Lesotho"
replace non_spec=	1	if country=="Rwanda"
replace non_spec=	1	if country=="Ghana"
replace non_spec=	1	if country=="Kazakhstan"
replace non_spec=	1	if country=="Liberia"
replace non_spec=	1	if country=="Gabon"
replace non_spec=	1	if country=="Mongolia"
replace non_spec=	1	if country=="Mali"
replace non_spec=	1	if country=="Fiji"
replace non_spec=	1	if country=="Kosovo"
replace non_spec=	1	if country=="Lithuania"
replace non_spec=	1	if country=="Seychelles"
replace non_spec=	1	if country=="Zambia"
replace non_spec=	1	if country=="Sudan"
replace non_spec=	1	if country=="Nicaragua"
replace non_spec=	1	if country=="Maldives"
replace non_spec=	1	if country=="Cameroun"
replace non_spec=	1	if country=="Bhutan"
replace non_spec=	1	if country=="Mauritania"
replace non_spec=	1	if country=="Republic of Congo"
replace non_spec=	1	if country=="Togo"
replace non_spec=	2	if country=="Dominica"
replace non_spec=	2	if country=="Mozambique"
replace non_spec=	2	if country=="Guatemala"
replace non_spec=	2	if country=="Republic of the Marshall Islands"
replace non_spec=	2	if country=="Sri Lanka"
replace non_spec=	2	if country=="Azerbaijan"
replace non_spec=	2	if country=="Jamaica"
replace non_spec=	2	if country=="India"
replace non_spec=	2	if country=="Panama"
replace non_spec=	2	if country=="Bosnia and Herzegovina"
replace non_spec=	3	if country=="Belize"
replace non_spec=	3	if country=="Iraq"
replace non_spec=	3	if country=="Albania"
replace non_spec=	4	if country=="Burkina Faso"
replace non_spec=	4	if country=="Mexico"
replace non_spec=	4	if country=="Kenya"
replace non_spec=	5	if country=="Morocco"
replace non_spec=	6	if country=="Cape Verde"
replace non_spec=	7	if country=="St. Lucia"
replace non_spec=	7	if country=="South Africa"
replace non_spec=	9	if country=="Belarus"

******************** Food items in the Milk, cheese and eggs category that are not dairy products.

*NOTE:  For the rest of these, taking code from "Comprehensiveness" program to identify food items;

*keep country Q6_20 Q6_57 Q6_56;
replace Q6_57=Q6_57+1 if inlist(country,"Pakistan","Benin","Chad","Papua New Guinea","Burundi","Djibouti","Paraguay","Madagascar")
replace Q6_57=Q6_57+1 if inlist(country,"Angola","Lao PDR","Guatemala","Senegal","Nicaragua","Togo","Honduras")
gen iden_1=Q6_20-Q6_57 if !inlist(country,"Georgia","Montenegro","Russia")
la var iden_1 "No of Food items in the Milk, cheese and eggs category that are not dairy products"
tab iden_1 if !inlist(country,"Georgia","Montenegro","Russia"), missing
list country Q6_20 Q6_57 Q6_56 if iden_1>0

******************** Oils and fats (including peanut butter) that are not only oils ands fats (excluding peanut butter);
*keep country Q6_25 Q6_60 Q6_58;
replace Q6_60=Q6_60+1 if inlist(country,"Kosovo","Honduras","Cambodia","Colombia","Paraguay","Latvia","Ethiopia")
replace Q6_60=Q6_60+1 if inlist(country,"Togo","Sierra Leone","Guinea-Bissau","Sao Tome e Principe","Maldives","Belize")
replace Q6_60=Q6_60+1 if inlist(country,"Papua New Guinea","Kazakhstan","Mexico","Mongolia","Swaziland","Fiji","Mozambique")
replace Q6_60=Q6_60+1 if inlist(country,"Yemen","Lithuania")
replace Q6_60=Q6_60+2 if inlist(country,"Lesotho","Bangladesh","Brazil")
gen iden_2=Q6_25-Q6_60
la var iden_2 "No of Oils and fats (including peanut butter) that are not only oils ands fats (excluding peanut butter)"
tab iden_2 if !inlist(country,"Georgia","Montenegro","Russia"), missing
*None;

******************** Fruits (ncluding plantains and "nuts and edible seeds") that are not only fruits;
*keep country Q6_28 Q6_63 Q6_62 Q6_61;
replace Q6_63=Q6_63+1 if inlist(country,"Djibouti","Guatemala","Afghanistan","Bolivia","Uganda","Liberia","Timor-Leste")
replace Q6_63=Q6_63+1 if inlist(country,"Vietnam","Nepal","Bangladesh","Kenya","Sierra Leone","Burundi","Nigeria","Ghana")
replace Q6_63=Q6_63+1 if inlist(country,"Cambodia","Azerbaijan","Papua New Guinea","Bosnia and Herzegovina","Kosovo","Latvia")
replace Q6_63=Q6_63+1 if inlist(country,"Ethiopia","Dominica","Mongolia","Zambia","Malawi","Cape Verde","Gambia","Honduras")
replace Q6_63=Q6_63+1 if inlist(country,"Indonesia","Iraq","Kazakhstan","Lao PDR","Lesotho","Mexico","South Africa","St. Lucia","Swaziland")
replace Q6_63=Q6_63+2 if country=="Armenia" | country=="Seychelles" | country=="Sri Lanka"
replace Q6_63=Q6_63+3 if country=="Iraq"
replace Q6_63=Q6_63+4 if country=="Nicaragua"
replace Q6_63=Q6_63+4 if country=="Honduras"
replace Q6_63=Q6_63+8 if country=="Mexico"

gen iden_3=Q6_28-Q6_63
la var iden_3 "No of fruits (including plantains and 'nuts and edible seeds') that are not only fruits"
tab iden_3 if !inlist(country,"Georgia","Montenegro","Russia"), missing
sort iden_3
*None;

******************** Vegetables (including roots and tubers and pulses) that are not only vegetables, roots and tubers or pulses;

********** Foods classified under "Vegetables" that are only vegetables;
*keep country Q6_31 Q6_66a Q6_66b Q6_66c Q6_65;
replace Q6_66a=Q6_66a+1 if inlist(country,"Burundi","Kosovo","Philippines","Bosnia and Herzegovina","Sierra Leone","Togo","Afghanistan")
replace Q6_66a=Q6_66a+1 if inlist(country,"Bulgaria","Ethiopia","Uganda","Papua New Guinea","Timor-Leste","Benin","Mongolia","Nigeria")
replace Q6_66a=Q6_66a+1 if inlist(country,"India","Kenya","Uzbekistan","Vietnam","Bangladesh","Fiji","Ghana","Liberia")
replace Q6_66a=Q6_66a+1 if inlist(country,"Zambia","El Salvador","Nepal","Bolivia","Malawi","Sri Lanka","Maldives","South Africa")
replace Q6_66a=Q6_66a+1 if inlist(country,"Swaziland","Indonesia","Gambia","Armenia","Morocco","Djibouti","Mexico")
*37 countries;
replace Q6_66a=Q6_66a+2 if country=="Kazakhstan" | country=="Tajikistan"
*3 countries;
replace Q6_66a=Q6_66a+3 if country=="Cameroun" | country=="Seychelles"
*2 countries;
replace Q6_66a=Q6_66a+4 if country=="Nicaragua"
replace Q6_66a=Q6_66a+7 if country=="Honduras"

********** Foods classified under "Vegetables" that are only Roots and tubers (including potatoes), and plantains;
*Note:  Morocco already had a "1" for Q6_66b;
replace Q6_66b=Q6_66b+1 if country=="Liberia" | country=="Bolivia" | country=="Malawi" | country=="Lesotho"
*4 countries;

********** Foods classified under "Vegetables" that are only Pulses, nuts and seeds;
replace Q6_66c=Q6_66c+1 if inlist(country,"Cambodia","Djibouti","Tajikistan","Malawi","Ghana","Pakistan")
*7 countries;
replace Q6_66c=Q6_66c+3 if country=="Sri Lanka"

gen iden_4=Q6_31-Q6_66a-Q6_66b-Q6_66c
la var iden_4 "No of foods classified under 'Vegetables' that are only Pulses, nuts and seeds"
tab iden_4 if !inlist(country,"Georgia","Montenegro","Russia"), missing
*sort iden_4

******************** "Sugar, jam, honey, chocolate and confectionary" that don't fall into the BFL "Sugar, jam, honey, chocolate and sweets" category;
*keep country Q6_35 Q6_68 Q6_69a Q6_69b;
replace Q6_69a=Q6_69a+1 if inlist(country,"Iraq","Bangladesh","Mongolia","Kenya","Cameroun","Bolivia","Sri Lanka","Republic of Marshal Islands")
replace Q6_69a=Q6_69a+1 if inlist(country,"Lao PDR","Indonesia","Kazakhstan","Maldives","Gambia","Jamaica","Tunisia","Seychelles","Honduras")
*18 countries;
replace Q6_69a=Q6_69a+2 if inlist(country,"Malawi","Panama","Dominica")	
*2 countries;
replace Q6_69a=Q6_69a+3 if country=="Mexico"
replace Q6_69a=Q6_69a+4 if country=="Guatemala"

gen iden_5=Q6_35-Q6_69a-Q6_69b
la var iden_5 "No of 'Sugar, jam, honey, chocolate and confectionary' that don't fall into this BFL category"
tab iden_5 if !inlist(country,"Georgia","Montenegro","Russia"), missing
*sort iden_5;
*None;

******************** Alcoholic beverages that are not only alcoholic beverages.
*keep country Q6_44 Q6_72 Q6_73 Q6_74;
replace Q6_74=Q6_74+1 if inlist(country,"Bolivia","Vanuatu","Ghana","Niger","Sierra Leone","Papua New Guinea","Panama","Benin","Iraq")
replace Q6_74=Q6_74+1 if inlist(country,"Vietnam","Guatemala","Zambia","Madagascar","Uzbekistan","Burundi","Timor-Leste","Uganda")
replace Q6_74=Q6_74+1 if inlist(country,"Togo","Chad","Armenia","Nepal","Tajikistan","Mongolia","Honduras","Colombia","Malawi")
replace Q6_74=Q6_74+1 if inlist(country,"Senegal","Sri Lanka","Guinea","Brazil","Seychelles","Mozambique","Jamaica","Lao PDR")
replace Q6_74=Q6_74+1 if inlist(country,"Indonesia","Swaziland","Nigeria","Thailand")
*38 countries;
replace Q6_74=Q6_74+2 if inlist(country,"Gabon","Fiji","India","Cte d'Ivoire","Kazakhstan","Angola","Mexico")
*7 countries;
replace Q6_74=Q6_74+3 if country=="Liberia"

gen iden_6=Q6_44-Q6_74
la var iden_6 "Number of alcoholic beverages that are not only alcoholic beverages"
tab iden_6 if !inlist(country,"Georgia","Montenegro","Russia"), missing
*sort iden_6;
*None;

******************** Foods that are included in Q6_92 (and specified in Q6_93);
*These are foods that were not classified into the BFL food groups automatically but that are still not identified;  
*keep country Q6_90 Q6_91 Q6_92 Q6_93;

*Identify ones to take out of this category (using code from "Comprehensiveness" program);
gen takeout=0 if !inlist(country,"Georgia","Montenegro","Russia")
replace takeout=1 if inlist(country,"Sierra Leone","Nigeria","Papua New Guinea","Uzbekistan","Republic of Congo","Sri Lanka")
replace takeout=1 if inlist(country,"Gabon","Bangladesh","Latvia","Kazakhstan","Bhutan","Turkmenistan","Ukraine","El Salvador")
replace takeout=1 if inlist(country,"Senegal","Mexico","Thailand","Lao PDR","Myanmar")
*19 countries;
replace takeout=2 if country=="Lesotho" | country=="Swaziland" | country=="Jamaica"
*3 countries;
replace takeout=3 if country=="Mali" | country=="Tunisia" | country=="St. Lucia" | country=="South Africa"
replace takeout=5 if country=="Burkina Faso"
replace takeout=8 if country=="Angola"
replace takeout=6 if country=="Morocco"
tab takeout, missing

replace Q6_92=Q6_92-takeout

gen iden_7= Q6_92
la var iden_7 "No of Foods that are included in Q6_92 (and specified in Q6_93)"
tab iden_7, missing

*keep country Q6_92 Q6_93;

*Brazil:  52 food items are in this category, and they are not listed individually in Q6_93;
*Dropping this country for this analysis;
*drop if country=="Brazil";

******************** Calculate the total number of food items (excluding prepared foods) that span the food groups;
tab span_g if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab prep if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab non_spec if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab iden_1 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab iden_2 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab iden_3 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab iden_4 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab iden_5 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab iden_6 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab iden_7 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
*N=96, no missings for any of these variables;

egen sum_all_nspec=rsum(span_g non_spec iden_1-iden_7) if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
tab sum_all_nspec if !inlist(country,"Georgia","Montenegro","Russia","Brazil"), missing 
sum sum_all_nspec if !inlist(country,"Georgia","Montenegro","Russia","Brazil")

gen perc_span=sum_all*100/num_items if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
la var perc_span "Percentage of food items that span food groups (excluding prepared food)"
tab perc_span if !inlist(country,"Georgia","Montenegro","Russia","Brazil"), missing 
sum perc_span if !inlist(country,"Georgia","Montenegro","Russia","Brazil")

gen crit_2=0 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
la var crit_2 "Less than 5% of food items span the basic food groups"
replace crit_2=1 if perc_span<5 & !inlist(country,"Georgia","Montenegro","Russia","Brazil")

tab crit_2 if !inlist(country,"Georgia","Montenegro","Russia","Brazil"),missing


**************************************************
**************************************************
* (E) Make variable for calculating percent of countries meeting minimum reliability criterion
**************************************************
**************************************************;

gen rc_5_specfl=0 if !inlist(country,"Georgia","Montenegro","Russia","Brazil")
la var rc_5_specfl "Surveys meeting both food specificity criteria (BfGs minimum number and food items span)"
replace rc_5_specfl=1 if crit_1==1 & crit_2==1 & !inlist(country,"Georgia","Montenegro","Russia","Brazil")

tab crit_1 if !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* figure 3.5 percent of surveys meeting the food list specificity criteria */
tab crit_1 if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* figure 3.5 percent of surveys meeting the food list specificity criteria */
tab crit_1 if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* figure 3.5 percent of surveys meeting the food list specificity criteria */

tab crit_2 if !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* Table 3.2 Specificity if the food list (C) */
tab crit_2 if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* Table 3.2 Specificity if the food list (C) */
tab crit_2 if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* Table 3.2 Specificity if the food list (C) */

tab rc_5_specfl if !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* figure 3.5 percent of surveys meeting the food list specificity criteria */
tab rc_5_specfl if int_diary==1 & !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* figure 3.5 percent of surveys meeting the food list specificity criteria */
tab rc_5_specfl if int_diary==2 & !inlist(country,"Georgia","Montenegro","Russia","Brazil") /* figure 3.5 percent of surveys meeting the food list specificity criteria */

*Save for later use;
sort country
keep country int_diary crit_1 crit_2 rc_5_specfl sum_all_ns span_g prep non_spec iden_1-iden_7 ///
perc_span num_items min_g* min_numfg* fg1-fg14 
*keep country int_diary crit_1 crit_2 rc_5_specfl sum_all_ns span_g prep non_spec iden_1-iden_7 ///
*perc_span num_items min_g* min_numfg* fg1-fg14 all_14fg min_proc food_exc rc_4_compfl
saveold "$outputdata\specfl.dta", replace

*********************************************************************
*********************************************************************
**     DATE:       September-October 2012
**     PROGRAM:    HCES Assessment_Reliability_Food consumed away from home
**     AUTHOR:     LSmith
**     INFILE:     HCES Assessment 2012__100-country dataset 
**     OUTFILE:    IHSN project\Analysis\Data\outfiles\fafh_yesno.dta 
**                 IHSN project\Analysis\Data\outfiles\fafh_recallp.dta
**     PURPOSE:    Analyze reliability of the food data in Household Consumption 
**			       and Expenditure surveys:  Quality of data collected on food consumed away from home
*********************************************************************;
use "$outputdata\HCES_food_assessment_edited.dta", clear
/*
 (A) Determine whether FCAFH data are collected using the interview or diary method --- DONE in cleaning 
 (B) Determine whether data are collected on food consumed away from home at all -- DONE in cleaning 
 (C) Recall period for collection of FCAFH data
 (D) Detail with which data are collected 
 (E) Whether data collected on in-kind as well as purchases
 (F) Reliability criteria
*/

*list fafh_g Q6_2a Q8_17 if int_diarya==2;
/* figure 3.7 the first bar -- 90% */
tab fafh_g if int_diarya==1, missing
tab fafh_g if int_diarya==2, missing
tab fafh_g, missing
tab fafh_g

*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_yesno.dta", replace;

********************************
*  For info:  type of data collected (expenditures, quantities, both)
********************************;

* We only collected this information for the interview surveys;
recode Q8_7 (99=.)
tab Q8_7 if int_diarya==1, missing
tab Q8_7 if int_diarya==1
recode Q8_7 (99=.)

********************************
* For info: Are data collected on the number of meals consumed away from home? 
********************************;
tab Q9_5 if fafh_g==1
tab Q9_5 if fafh_g==0

*Only collected for the countries that already collect acqusition/consumption data on food consumed away from home;

**************************************************
* (C)  Recall period for collection of FCAFH data
**************************************************

*Only calculate for surveys for which acquisition/consumption data were collected on food consumed away from home;
*keep if fafh_g==1
*90 countries

********************************
* Determine recall period that will be used for the assessment
********************************;

********** Check interview surveys for missing recall period;
gen flag_norecallpa=0 if fafh_g==1
replace flag_norecallpa=1 if Q8_5a==0 & Q8_5b==0 & Q8_5c==0 & Q8_5d==0 & Q8_5e==0 & Q8_5f==0 & Q8_5g==0 & Q8_5h==0 & int_diarya==1 & fafh_g==1
tab flag_norecallpa if int_diarya==1 & fafh_g==1, missing
*None missing;

********** Calculate total number of recall periods;

     *  Interview surveys;
     recode Q8_5a-Q8_5e Q8_5f Q8_5g Q8_5h (2=0)
     egen numrecallpa=rsum(Q8_5a-Q8_5e Q8_5f Q8_5g Q8_5h) if int_diarya==1 & fafh_g==1
	 recode Q8_5a-Q8_5e Q8_5f Q8_5g Q8_5h (0=2)
     *  Diary surveys (set number of recall periods to 1);
	 replace numrecallpa=1 if int_diarya==2 & fafh_g==1

tab numrecallpa if fafh_g==1, missing

********** Specify recall period for diary surveys (recall period is 1 day);
gen recallpa=1 if int_diarya==2 & fafh_g==1
la var recallpa "Recall period food consumed away from home in number of days"

********** Determine recall period for surveys with "zero" recall periods;
*list country if numrecallpa==0;
*The recall period is undefined for Nicaragua;
replace recallpa=999 if country=="Nicaragua"

********** Determine recall period for interview surveys with one recall period;
replace recallpa=7  if             Q8_5a==1           & int_diarya==1 & numrecallpa==1 & fafh_g==1 
replace recallpa=14 if             Q8_5b==1           & int_diarya==1 & numrecallpa==1 & fafh_g==1 
replace recallpa=15 if             Q8_5c==1           & int_diarya==1 & numrecallpa==1 & fafh_g==1 
replace recallpa=30 if            (Q8_5d==1|Q8_5e==1) & int_diarya==1 & numrecallpa==1 & fafh_g==1 
replace recallpa=Q8_5f1 if         Q8_5f==1           & int_diarya==1 & numrecallpa==1 & fafh_g==1 
replace recallpa=Q8_5g1 if         Q8_5g==1           & int_diarya==1 & numrecallpa==1 & fafh_g==1 
replace recallpa=Q8_5h_spec_num if Q8_5h==1           & int_diarya==1 & numrecallpa==1 & fafh_g==1

********** Determine recall period for interview surveys with multiple recall periods; 
gen flag_1=1 if int_diarya==1 & (numrecallpa>1 & numrecallpa~=.) & fafh_g==1
list country Q8_5a-Q8_5e Q8_5f Q8_5g Q8_5h Q8_5h_spec if flag_1==1 & fafh_g==1

* For Comoros, see above note;
replace recallpa=14 if country=="Union des Comores"

/* For Dominica two recall periods are given:  7 days and 30 days.  For at-home food data collection
these recall periods are used for all food items.  We will assume this is the same for away from home
food data collection and use 7 days (the minimum recall period) */
replace recallpa=7 if country=="Dominica"

* For Mauritania two recall periods are given:  15 days and 365 days. We will use 15 days, the minimum recall period;
replace recallpa=15 if country=="Mauritania"

/* For Nepal two recall periods are given:  7 days and 365 days.  These are used for all food items,
including those refering to food consumed away from home.  We will thus use the minimum recall period of 7 days */
replace recallpa=7 if country=="Nepal"

/* For Mongolia two recall periods are given:  one month and 365 days.  These are used for all line items referring
to food consumed away from home.  We will thus use the minimum recall period of 30 days */
replace recallpa=30 if country=="Mongolia"

* Cote d'Ivoire: Minimum recall period is 7 days;
replace recallpa=7 if country=="Cte d'Ivoire"

*  Maldives:  Recall period is undefined, as for food consumed at home;
replace recallpa=999 if country=="Maldives"

* Togo:  Two recall periods used for all items: 30 days and 12 months.  We will use 30 days, the minimum recall period;
replace recallpa=30 if country=="Togo"

tab recallpa if fafh_g==1, missing

********** Classify recall periods and calculate percentages in each group;
recode recallpa (999=.)
gen recallpa_g=1 if recallpa<7 & recallpa~=. & fafh_g==1
la var recallpa_g "Recall period for food consumed away from home"
replace recallpa_g=2 if recallpa==7 & fafh_g==1
replace recallpa_g=3 if recallpa==14 | recallpa==15 & fafh_g==1
replace recallpa_g=4 if recallpa==30 & fafh_g==1
replace recallpa_g=5 if recallpa>30 & recallpa~=. & fafh_g==1
*label define rclabel 1 "Less than one week" 2 "One week" 3 "Two weeks" 4 "One month" 5 "More than one month"
label values recallpa_g rclabel

*Classify surveys with undefined recall periods as having a recall period greater than one month;
replace recallpa_g=5 if country=="Maldives"| country=="Nicaragua"

* All surveys;
/* Table 3.3 Recall period */
tab recallpa_g if fafh_g==1
tab recallpa_g if fafh_g==1, missing

* Interview surveys;
tab recallpa_g if int_diarya==1 & fafh_g==1

* Diary surveys;
tab recallpa_g if int_diarya==2 & fafh_g==1

sum recallpa 

*drop flag_norecallpa numrecallpa flag_1 
*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_recallp.dta", replace;

**************************************************
**************************************************
*  (D) Detail with which data are collected 
**************************************************
**************************************************;

****************************************
* Data collected at the individual level?
****************************************;

tab Q8_26 if fafh_g==1, missing
recode Q8_26 (99=.)

tab Q8_26, missing

tab Q8_26 if fafh_g==1
tab Q8_26 if int_diarya==1 & fafh_g==1
tab Q8_26 if int_diarya==2 & fafh_g==1
tab Q6_2a if int_diarya==1 & fafh_g==1, missing
*18 interview surveys with one line item;

*Check on line items;
list country Q8_8 if int_diarya==1 & fafh_g==1

gen one_item=0 if Q6_2a~=. & fafh_g==1
la var one_item "Data collected at the individual level, only one line item (food consumed away)"
replace one_item=1 if Q6_2a==1 & fafh_g==1
tab one_item if fafh_g==1, missing
*Note:  Georgia and Russia are missing (no food list data for these countries);

tab one_item if int_diarya==1 & fafh_g==1,m
tab one_item if int_diarya==2 & fafh_g==1,m
tab one_item if fafh_g==1,m

recode Q8_26 (.=99)
****************************************
* Places of consumption for which FAFH is enumerated individually
****************************************;

********** Interview surveys;

* Correct mis-coding of variable Q8_9d in Adobe Livecycle;
recode Q8_9d (1=1) (0=2)
   
*list country Q8_9j_spec;
*Two countries have data for "group of places" (that is actually a group of places).  We can't include here because not enumerated individually;
*Mongolia:  "Restaurants, cafes" and "Canteens in schools, works canteens";
*Ghana:     "Hotels, cafes and restaurants"  Canteens (workers/universities and schools canteen);

recode Q8_9a-Q8_9i (2=0)
egen numplaces_i=rsum(Q8_9a-Q8_9i) if int_diarya==1 & fafh_g==1
tab numplaces_i if int_diarya==1 & fafh_g==1, missing
sum numplaces_i if fafh_g==1
gen numplaces_gt1_i=0 if int_diarya==1 & fafh_g==1
replace numplaces_gt1_i=1 if numplaces_i>1 & numplaces_i~=. & int_diarya==1 & fafh_g==1
tab numplaces_gt1_i if int_diarya==1 & fafh_g==1, missing

recode Q8_9a-Q8_9i (0=2)

gen i_rest=0 if int_diarya==1 & fafh_g==1
replace i_rest=1 if Q8_9a==1 & int_diarya==1 & fafh_g==1
gen i_ff_outlet=0 if int_diarya==1 & fafh_g==1
replace i_ff_outlet=1 if Q8_9b==1 & int_diarya==1 & fafh_g==1
gen i_bar=0 if int_diarya==1 & fafh_g==1
replace i_bar=1 if Q8_9c==1 & int_diarya==1 & fafh_g==1
gen i_hotel=0 if int_diarya==1 & fafh_g==1
replace i_hotel=1 if Q8_9d==1 & int_diarya==1 & fafh_g==1
gen i_sstall=0 if int_diarya==1 & fafh_g==1
replace i_sstall=1 if Q8_9e==1 & int_diarya==1 & fafh_g==1
gen i_hhold=0 if int_diarya==1 & fafh_g==1
replace i_hhold=1 if Q8_9f==1 & int_diarya==1 & fafh_g==1
gen i_educ_inst=0 if int_diarya==1 & fafh_g==1
replace i_educ_inst=1 if Q8_9g==1 & int_diarya==1 & fafh_g==1
gen i_workplace=0 if int_diarya==1 & fafh_g==1
replace i_workplace=1 if Q8_9h==1 & int_diarya==1 & fafh_g==1
gen i_other=0 if int_diarya==1 & fafh_g==1
replace i_other=1 if Q8_9i==1& int_diarya==1 & fafh_g==1

la var i_rest "Interview method, restaurant is place of consumption of food consumed away from home"
la var i_ff_outlet "Interview method, fast-food outlet is place of consumption of food consumed away from home"
la var i_bar "Interview method, bar is place of consumption of food consumed away from home"
la var i_hotel "Interview method, hotel is place of consumption of food consumed away from home"
la var i_sstall "Interview method, street stall or mobile vendor is place of consumption of food consumed away from home"
la var i_hhold "Interview method, another household is place of consumption of food consumed away from home"
la var i_educ_inst "Interview method, educational institution is place of consumption of food consumed away from home"
la var i_workplace "Interview method, work place is place of consumption of food consumed away from home"
la var i_other "Interview method, other places not mentioned above is place of consumption of food consumed away from home"

tab i_rest if int_diarya==1 & fafh_g==1, m
tab i_ff_outlet if int_diarya==1 & fafh_g==1, m
tab i_bar if int_diarya==1 & fafh_g==1, m
tab i_hotel if int_diarya==1 & fafh_g==1, m
tab i_sstall if int_diarya==1 & fafh_g==1, m
tab i_hhold if int_diarya==1 & fafh_g==1, m
tab i_educ_inst if int_diarya==1 & fafh_g==1, m
tab i_workplace if int_diarya==1 & fafh_g==1, m
tab i_other if int_diarya==1 & fafh_g==1, m

*list country Q8_9i_spec if i_other==1;

********** Diary surveys ;

* Correct mis-coding of variable Q8_9d in Adobe Livecycle;
recode Q8_18d (1=1) (0=2)

*Check on "other" categories;
list country Q8_18i_spec if Q8_18i==1 & fafh_g==1

*Check on "group of places" categories;
list country Q8_18j_spec if int_diarya==2 & fafh_g==1

*Three countries have data for "group of places".  We can't include here because not enumerated individually;
*Cameroon:  "Htels, bars, restaurants et cafs"; 
*Armenia:  "Canteen or buffet at the workplace or educational institution"
*Azerbaijan: 1. "Cafe, bar"  2.  "cafeteria, buffet at work or school"; 
*Ukraine:  "Cafe, cafeteria, snack bar, etc."_x000D_2.  "Canteen, buffet at work or school";

recode Q8_18a-Q8_18i (2=0)
egen numplaces_d=rsum(Q8_18a-Q8_18i) if int_diarya==2 & fafh_g==1
sum numplaces_d if fafh_g==1  & fafh_g==1
gen numplaces_gt1_d=0 if int_diarya==2 & fafh_g==1
replace numplaces_gt1_d=1 if numplaces_d>1 & numplaces_d~=. & int_diarya==2 & fafh_g==1
tab numplaces_gt1_d if int_diarya==2 & fafh_g==1, missing

recode Q8_18a-Q8_18i (0=2)

gen d_rest=0 if int_diarya==2 & fafh_g==1    
replace d_rest=1 if Q8_18a==1 & int_diarya==2 & fafh_g==1
gen d_ff_outlet=0 if int_diarya==2 & fafh_g==1
replace d_ff_outlet=1 if Q8_18b==1 & int_diarya==2 & fafh_g==1
gen d_bar=0 if int_diarya==2 & fafh_g==1
replace d_bar=1 if Q8_18c==1 & int_diarya==2 & fafh_g==1
gen d_hotel=0 if int_diarya==2 & fafh_g==1
replace d_hotel=1 if Q8_18d==1 & int_diarya==2 & fafh_g==1
gen d_sstall=0 if int_diarya==2 & fafh_g==1
replace d_sstall=1 if Q8_18e==1 & int_diarya==2 & fafh_g==1
gen d_hhold=0 if int_diarya==2 & fafh_g==1
replace d_hhold=1 if Q8_18f==1 & int_diarya==2 & fafh_g==1
gen d_educ_inst=0 if int_diarya==2 & fafh_g==1
replace d_educ_inst=1 if Q8_18g==1 & int_diarya==2 & fafh_g==1
gen d_workplace=0 if int_diarya==2 & fafh_g==1
replace d_workplace=1 if Q8_18h==1 & int_diarya==2 & fafh_g==1
gen d_other=0 if int_diarya==2 & fafh_g==1
replace d_other=1 if Q8_18i==1 & int_diarya==2 & fafh_g==1

la var d_rest "Diary method, restaurant is place of consumption of food consumed away from home"
la var d_ff_outlet "Diary method, fast-food outlet is place of consumption of food consumed away from home"
la var d_bar "Diary method, bar is place of consumption of food consumed away from home"
la var d_hotel "Diary method, hotel is place of consumption of food consumed away from home"
la var d_sstall "Diary method, street stall or mobile vendor is place of consumption of food consumed away from home"
la var d_hhold "Diary method, another household is place of consumption of food consumed away from home"
la var d_educ_inst "Diary method, educational institution is place of consumption of food consumed away from home"
la var d_workplace "Diary method, work place is place of consumption of food consumed away from home"
la var d_other "Diary method, other places not mentioned above is place of consumption of food consumed away from home"

tab d_rest if int_diarya==2 & fafh_g==1, m
tab d_ff_outlet if int_diarya==2 & fafh_g==1 , m
tab d_bar if int_diarya==2 & fafh_g==1, m
tab d_hotel if int_diarya==2 & fafh_g==1, m
tab d_sstall if int_diarya==2 & fafh_g==1, m
tab d_hhold if int_diarya==2 & fafh_g==1, m
tab d_educ_inst if int_diarya==2 & fafh_g==1, m
tab d_workplace if int_diarya==2 & fafh_g==1, m
tab d_other if int_diarya==2 & fafh_g==1, m

********** All surveys;

gen numplaces_gt1=0 if (numplaces_gt1_i==0 | numplaces_gt1_d==0) & fafh_g==1
replace numplaces_gt1=1 if (numplaces_gt1_i==1|numplaces_gt1_d==1) & fafh_g==1
list numplaces_gt1 numplaces_gt1_i numplaces_gt1_d if fafh_g==1
tab numplaces_gt1 if fafh_g==1

gen rest=0      if (i_rest==0|d_rest==0) & fafh_g==1
gen ff_outlet=0 if (i_ff_outlet==0|d_ff_outlet==0) & fafh_g==1
gen bar=0       if (i_bar==0|d_bar==0) & fafh_g==1
gen hotel=0     if (i_hotel==0|d_hotel==0) & fafh_g==1
gen sstall=0    if (i_sstall==0|d_sstall==0) & fafh_g==1
gen hhold=0     if (i_hhold==0|d_hhold==0) & fafh_g==1
gen educ_inst=0 if (i_educ_inst==0|d_educ_inst==0) & fafh_g==1
gen workplace=0 if (i_workplace==0|d_workplace==0) & fafh_g==1
gen other=0     if (i_other==0|d_other==0) & fafh_g==1

replace rest=1      if (i_rest==1|d_rest==1) & fafh_g==1
replace ff_outlet=1 if (i_ff_outlet==1|d_ff_outlet==1) & fafh_g==1
replace bar=1       if (i_bar==1|d_bar==1) & fafh_g==1
replace hotel=1     if (i_hotel==1|d_hotel==1) & fafh_g==1
replace sstall=1    if (i_sstall==1|d_sstall==1) & fafh_g==1
replace hhold=1     if (i_hhold==1|d_hhold==1) & fafh_g==1
replace educ_inst=1 if (i_educ_inst==1|d_educ_inst==1) & fafh_g==1
replace workplace=1 if (i_workplace==1|d_workplace==1) & fafh_g==1
replace other=1     if (i_other==1|d_other==1)  & fafh_g==1

la var rest "Restaurant is place of consumption of food consumed away from home"
la var ff_outlet "Fast-food outlet is place of consumption of food consumed away from home"
la var bar "Bar is place of consumption of food consumed away from home"
la var hotel "Hotel is place of consumption of food consumed away from home"
la var sstall "Street stall or mobile vendor is place of consumption of food consumed away from home"
la var hhold "Another household is place of consumption of food consumed away from home"
la var educ_inst "Educational institution is place of consumption of food consumed away from home"
la var workplace "Work place is place of consumption of food consumed away from home"
la var other "Other places not mentioned above is place of consumption of food consumed away from home"

tab rest if fafh_g==1
tab ff_outlet if fafh_g==1
tab bar if fafh_g==1
tab hotel if fafh_g==1
tab sstall if fafh_g==1
tab hhold if fafh_g==1
tab educ_inst if fafh_g==1
tab workplace if fafh_g==1
tab other if fafh_g==1

tab numplaces_gt1 if int_diarya==1  & fafh_g==1
tab numplaces_gt1 if int_diarya==2 & fafh_g==1
tab numplaces_gt1 if fafh_g==1


****************************************
* Modes of acquisition for which FCAFH data are enumerated individually
****************************************;

*Note:  We did not collect information on this properly because other categories were
*enumerated individually than those listed here so people were not able to clearly decide
*how to fill in the form.  For example, if a survey collected data for "purchases" and "received
*in-kind", then it was not clear how to fill in the form;

*This section will just give an idea of how common it was to mention specific sources of interest;


***** Interview surveys;
recode Q8_10a-Q8_10g (2=0)

*Look at specify box for "other";
list country Q8_10g_spec if Q8_10g==1 & fafh_g==1

*Look at specify box for "Group of sources";
list country Q8_10h_spec
*One case (Mongolia): "canteens in schools, works canteens";
*Can't consider as enumerated individually;

*list Q8_10a-Q8_10g if int_diarya==1;
*No missings;
tab Q8_10a if int_diarya==1 & fafh_g==1

egen numsources_i=rsum(Q8_10a-Q8_10g) if int_diarya==1 & fafh_g==1
sum numsources_i if fafh_g==1
gen numsources_gt1_i=0 if int_diarya==1 & fafh_g==1
replace numsources_gt1_i=1 if numsources_i>1 & numsources_i~=. & int_diarya==1 & fafh_g==1
tab numsources_gt1_i if int_diarya==1 & fafh_g==1, missing

gen i_com=0 if int_diarya==1 & fafh_g==1
replace i_com=1 if Q8_10a==1 & int_diarya==1 & fafh_g==1
gen i_p_educ=0 if int_diarya==1  & fafh_g==1
replace i_p_educ=1 if Q8_10b==1 & int_diarya==1 & fafh_g==1
gen i_f_educ=0 if int_diarya==1 & fafh_g==1
replace i_f_educ=1 if Q8_10c==1 & int_diarya==1 & fafh_g==1
gen i_f_emp=0 if int_diarya==1 & fafh_g==1 
replace i_f_emp=1 if Q8_10d==1 & int_diarya==1 & fafh_g==1
gen i_f_assist=0 if int_diarya==1 & fafh_g==1
replace i_f_assist=1 if Q8_10e==1 & int_diarya==1 & fafh_g==1
gen i_f_guest=0 if int_diarya==1 & fafh_g==1
replace i_f_guest=1 if Q8_10f==1 & int_diarya==1 & fafh_g==1
gen i_oth=0 if int_diarya==1 & fafh_g==1
replace i_oth=1 if Q8_10g==1 & int_diarya==1 & fafh_g==1

la var i_com "Interview method, purchased in commercial eating establishments"
la var i_p_educ "Interview method, purchased at an educational institution"
la var i_f_educ "Interview method, provided free by an educational institution"
la var i_f_emp "Interview method, provided free by an employer"
la var i_f_assist "Interview method, provided as food assistance from an aid organization"
la var i_f_guest "Interview method, received as a guest in another household"
la var i_oth "Interview method, other (sources of food consumed away from home)"

tab i_com if int_diarya==1 & fafh_g==1, m
tab i_p_educ if int_diarya==1 & fafh_g==1, m
tab i_f_educ if int_diarya==1 & fafh_g==1, m
tab i_f_emp if int_diarya==1 & fafh_g==1, m
tab i_f_assist if int_diarya==1 & fafh_g==1, m
tab i_f_guest if int_diarya==1 & fafh_g==1, m
tab i_oth if int_diarya==1 & fafh_g==1, m
recode Q8_10a-Q8_10g (2=0)
*Note: For Maldives "other (spec)" is "As gifts";

***** Diary surveys;
recode Q8_19a-Q8_19g (2=0)

*Look at specify box for "other";
*Other;
list country Q8_19g Q8_19g_spec if Q8_19g==1 & int_diarya==2 & fafh_g==1

**Note: For Yemen "other (spec)" is "Received as a gift, payment in-kind";

*Look at specify box for "Group of sources";
list country Q8_19h_spec if int_diarya==2 & fafh_g==1
*Armenia: "Canteen or buffet at the workplace or educational institution";

egen numsources_d=rsum(Q8_19a-Q8_19g) if int_diarya==2 & fafh_g==1
sum numsources_d if fafh_g==1
gen numsources_gt1_d=0 if int_diarya==2 & fafh_g==1
replace numsources_gt1_d=1 if numsources_d>1 & numsources_d~=. & int_diarya==2 & fafh_g==1
tab numsources_gt1_d if int_diarya==2 & fafh_g==1, missing

gen d_com=0 if int_diarya==2 & fafh_g==1
replace d_com=1 if Q8_19a==1 & int_diarya==2 & fafh_g==1
gen d_p_educ=0 if int_diarya==2 & fafh_g==1
replace d_p_educ=1 if Q8_19b==1 & int_diarya==2 & fafh_g==1
gen d_f_educ=0 if int_diarya==2 & fafh_g==1
replace d_f_educ=1 if Q8_19c==1 & int_diarya==2 & fafh_g==1
gen d_f_emp=0 if int_diarya==2 & fafh_g==1
replace d_f_emp=1 if Q8_19d==1 & int_diarya==2 & fafh_g==1
gen d_f_assist=0 if int_diarya==2 & fafh_g==1
replace d_f_assist=1 if Q8_19e==1 & int_diarya==2 & fafh_g==1
gen d_f_guest=0 if int_diarya==2 & fafh_g==1
replace d_f_guest=1 if Q8_19f==1 & int_diarya==2 & fafh_g==1
gen d_oth=0 if int_diarya==2 & fafh_g==1
replace d_oth=1 if Q8_19g==1 & int_diarya==2 & fafh_g==1

la var d_com "Diary method, purchased in commercial eating establishments"
la var d_p_educ "Diary method, purchased at an educational institution"
la var d_f_educ "Diary method, provided free by an educational institution"
la var d_f_emp "Diary method, provided free by an employer"
la var d_f_assist "Diary method, provided as food assistance from an aid organization"
la var d_f_guest "Diary method, received as a guest in another household"
la var d_oth "Diary method, other (sources of food consumed away from home)"

tab d_com if int_diarya==2 & fafh_g==1, m
tab d_p_educ if int_diarya==2 & fafh_g==1, m
tab d_f_educ if int_diarya==2 & fafh_g==1, m
tab d_f_emp if int_diarya==2 & fafh_g==1, m
tab d_f_assist if int_diarya==2 & fafh_g==1, m
tab d_f_guest if int_diarya==2 & fafh_g==1, m
tab d_oth if int_diarya==2 & fafh_g==1, m

*All surveys;
gen numsources_gt1=0 if (numsources_gt1_i==0 | numsources_gt1_d==0) & fafh_g==1
replace numsources_gt1=1 if (numsources_gt1_i==1|numsources_gt1_d==1) & fafh_g==1
list numsources_gt1 numsources_gt1_i numsources_gt1_d
tab numsources_gt1_i if fafh_g==1
tab numsources_gt1_d if fafh_g==1
tab numsources_gt1 if fafh_g==1

gen com=0 if      (i_com==0      | d_com==0) & fafh_g==1
gen p_educ=0 if   (i_p_educ==0   | d_p_educ==0) & fafh_g==1
gen f_educ=0 if   (i_f_educ==0   | d_f_educ==0) & fafh_g==1
gen f_emp=0 if    (i_f_emp==0    | d_f_emp==0) & fafh_g==1
gen f_assist=0 if (i_f_assist==0 | d_f_assist==0) & fafh_g==1
gen f_guest=0 if  (i_f_guest==0  | d_f_guest==0) & fafh_g==1
gen oth_source=0 if      (i_oth==0      | d_oth==0) & fafh_g==1

la var com "Purchased in commercial eating establishments"
la var p_educ "Purchased at an educational institution"
la var f_educ "Provided free by an educational institution"
la var f_emp "Provided free by an employer"
la var f_assist "Provided as food assistance from an aid organization"
la var f_guest "Received as a guest in another household"
la var oth_source "Other (sources of food consumed away from home)"

replace com=1 if      (i_com==1      | d_com==1) & fafh_g==1
replace p_educ=1 if   (i_p_educ==1   | d_p_educ==1) & fafh_g==1
replace f_educ=1 if   (i_f_educ==1   | d_f_educ==1) & fafh_g==1
replace f_emp=1 if    (i_f_emp==1    | d_f_emp==1) & fafh_g==1
replace f_assist=1 if (i_f_assist==1 | d_f_assist==1) & fafh_g==1
replace f_guest=1 if  (i_f_guest==1  | d_f_guest==1) & fafh_g==1
replace oth_source=1 if      (i_oth==1      | d_oth==1) & fafh_g==1

tab com if fafh_g==1
tab p_educ if fafh_g==1
tab f_educ if fafh_g==1
tab f_emp if fafh_g==1
tab f_assist if fafh_g==1
tab f_guest if fafh_g==1
tab oth_source if fafh_g==1

*Save for later use;
*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_sources.dta", replace;


****************************************
* Data collected on multiple specific types of food (more than one type of food or dish) or, in the
* case of diaries, respondents are instructed to identify specific foods, dishes and beverages
****************************************;

********** Interview;

* Look at interview surveys with greater than one food item (if only 1 then the question of specific types of food items is not asked;
tab Q8_11 if int_diarya==1 & Q6_2a>1 & Q6_2a~=. & fafh_g==1, missing
*14 countries;

*Use this for calculation (since even ones with a single food item will be counted);
tab Q8_11 if int_diarya==1 & fafh_g==1, missing

sum Q8_12 if Q8_11==1 & fafh_g==1
/*
    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       Q8_12 |        15    7.133333    8.149204          2         34
*/

*list Q8_13a Q8_13b Q8_13c Q8_13d Q8_13d_spec if Q8_11==1;

gen mult_fi_i=0 if int_diarya==1 & fafh_g==1
la var mult_fi_i "Interview method, data collected for more than one specific type of food consumed away from home"
replace mult_fi_i=1 if int_diarya==1 & Q8_11==1 & fafh_g==1
tab mult_fi_i if int_diarya==1 & fafh_g==1, missing

********** Diary;
tab Q8_20 if int_diarya==2 & Q8_20~=3 & fafh_g==1, missing

gen mult_fi_d=0 if int_diarya==2 & Q8_20~=3 & fafh_g==1
la var mult_fi_d "Diary method, data collected for more than one specific type of food consumed away from home"
replace mult_fi_d=1 if int_diarya==2 & Q8_20==1 & fafh_g==1
tab mult_fi_d if int_diarya==2 & fafh_g==1, missing
tab mult_fi_d if int_diarya==2 & fafh_g==1

********** Both;
gen mult_fi_b=0 if (mult_fi_i==0 | mult_fi_d==0) & fafh_g==1
la var mult_fi_b "Both method, data collected for more than one specific type of food consumed away from home"
replace mult_fi_b=1 if (mult_fi_i==1 | mult_fi_d==1) & fafh_g==1
tab mult_fi_b if fafh_g==1,missing

tab mult_fi_b if fafh_g==1


********** Whether alcoholic beverages explicitly referred to;
tab Q8_24 if fafh_g==1, missing
recode Q8_24 (99=.) (2=0)
*tab Q8_24 if int_diarya==1, missing;
*tab Q8_24 if int_diarya==2, missing;
*tab Q8_24, missing;

tab Q8_24 if int_diarya==1 & fafh_g==1
tab Q8_24 if int_diarya==2 & fafh_g==1
tab Q8_24 if fafh_g==1

********** Whether snacks explicitly referred to;
tab Q8_25 if fafh_g==1, missing
recode Q8_25 (99=.) (2=0)
*tab Q8_25 if int_diarya==1, missing;
*tab Q8_25 if int_diarya==2, missing;
*tab Q8_25, missing;

tab Q8_25 if int_diarya==1  & fafh_g==1
tab Q8_25 if int_diarya==2 & fafh_g==1
tab Q8_25 if  fafh_g==1


**************************************************
**************************************************
*  (E) Whether data collected on in-kind food received as well as purchases
**************************************************
**************************************************;

*#delim;
*use "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\HCES Assessment 2012__100-country dataset.dta", clear;
*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_yesno.dta";
*drop _merge
*Note:  As noted above we did not get good information on sources of acquisition on the assessment
*forms.  Thus for this section much of the information is from looking at each country's questionnaire;

gen fafh_inkind=11111
la var fafh_inkind "Data collected on both purchases and inkind receipts for food consumed away from home" /* figure 3.7 */

***** If no data collected on FCAFH, the answer is no;
tab fafh_g, missing

replace fafh_inkind=0 if fafh_g==2 | fafh_g==3

***** If no data are collected on in-kind receipts for at-home food, then we can safely assume none collected 
*     for food FCAFH;      
*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\sources.dta";
*drop _merge;

*tab m_ik, missing;

replace fafh_inkind=0 if m_ik==0
*11 of the 14 countries with m_ik=0 (others must be fafh_g=2 or 3);

tab fafh_inkind, missing

list country if fafh_inkind==0

***** Determined answer by looking at individual assessment forms and survey questionniares for the rest of the countries;
*     (See excel file titled: "Whether data are collected on food consumed away from home received inkind.xls");
replace fafh_inkind=0 if inlist(country,"Afghanistan","Armenia","Azerbaijan","Bolivia","Bulgaria","Burundi","Cambodia")
replace fafh_inkind=0 if inlist(country,"Ecuador","Egypt","Guatemala","Iraq","Jamaica","Kazakhstan","Latvia","Liberia")
replace fafh_inkind=0 if inlist(country,"Lithuania","Madagascar","Mali","Mongolia","Niger","Panama","Peru","Romania")
replace fafh_inkind=0 if inlist(country,"Russia","Sudan","Tajikistan","Turkmenistan","Uganda","Ukraine","Yemen")

replace fafh_inkind=1 if inlist(country,"Angola","Bangladesh","Belarus","Bhutan","Bosnia and Herzegovina","Brazil","Burkina Faso")
replace fafh_inkind=1 if inlist(country,"Cameroun","Cape Verde","Chad","Colombia","Congo, Dem. Rep.","Cte d'Ivoire","Dominica")
replace fafh_inkind=1 if inlist(country,"Ethiopia","Fiji","Gambia","Georgia","Guinea","Guinea-Bissau","Kenya","Kosovo")
replace fafh_inkind=1 if inlist(country,"Lao PDR","Lesotho","Malawi","Maldives","Mexico","Montenegro","Morocco","Mozambique")
replace fafh_inkind=1 if inlist(country,"Nepal","Nicaragua","Nigeria","Pakistan","Papua New Guinea","Paraguay","Philippines")
replace fafh_inkind=1 if inlist(country,"Republic of Congo","Republic of the Marshall Islands","Sao Tome e Principe","Seychelles")
replace fafh_inkind=1 if inlist(country,"South Africa","Swaziland","Tanzania","Thailand","Tunisia","Uzbekistan","Vanuatu","Vietnam")

tab fafh_inkind, missing

*Calculate only for countries with any FCAFH data;
tab fafh_inkind if int_diarya==1 & fafh_g==1
tab fafh_inkind if int_diarya==2 & fafh_g==1
tab fafh_inkind if fafh_g==1

*keep country fafh_inkind
*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_inkind", replace


**************************************************
**************************************************
*  (F) Reliability criteria
**************************************************
**************************************************;

**********  Either quantity or expenditure data are collected on food away from home;
*use "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_yesno.dta", clear

tab fafh_g, missing
tab fafh_g

gen fafh_yes=0 if fafh_g~=.
la var fafh_yes "Either quantity or expenditure data collected on food consumed away from home"
replace fafh_yes=1 if fafh_g==1

tab fafh_yes, missing

**********  Recall period for away from home food data collection less than or equal to two weeks; 
*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_recallp.dta"
*tab _merge

*For countries with no FCAFH data or undefined recall periods, make recall period very high;
*replace recallpa=1000 if _merge==1 | country=="Maldives" | country=="Nicaragua"
replace recallpa=1000 if country=="Maldives" | country=="Nicaragua"

tab recallpa, missing
gen recallpa_le_2w=0 if recallpa~=.
la var recallpa_le_2w "Recall period two weeks or less"
replace recallpa_le_2w=1 if recallpa<=15 & recallpa~=.
tab recallpa_le_2w, missing
*drop _merge

********** Data collected on in-kind food consumed away from home as well as purchases;
*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fafh_inkind";
*tab _merge;

tab fafh_inkind, missing
replace fafh_inkind=0 if fafh_inkind==11111
********** All three criteria (This is the minimum reliablity criterion);

gen rc_6_fcafh=0
la var rc_6_fcafh "All three criteria - minimum reliablity criterion on FCAFH"
*Note:  No missing data for the three variables;
replace rc_6_fcafh=1 if fafh_yes==1 & recallpa_le_2w==1 & fafh_inkind==1
tab rc_6_fcafh, missing /* figure 3.7 */
tab rc_6_fcafh

*sort fafh_yes recallpa_le_2w fafh_inkind;
*list country fafh_yes recallpa_le_2w fafh_inkind rc_6_fcafh;

*keep country  int_diarya fafh_g fafh_yes recallpa recallpa_g recallpa_le_2w fafh_inkind rc_6_fcafh;
*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fcafh.dta", replace;}

drop flag_norecallpa numrecallpa flag_1 numplaces_i numplaces_d numplaces_gt1 numplaces_gt1_i numplaces_gt1_d numsources_i numsources_gt1_i numsources_d numsources_gt1_d numsources_gt1

save "$outputdata\HCES_food_assessment_edited.dta", replace

*********************************************************************
*********************************************************************
**     DATE:       October 2012
**     PROGRAM:    HCES Assessment_Relevance_Measuring food security_Dietary diversity
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    
**     PURPOSE:    Analyze relevance for various users of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Measuring food security (dietary diversity)
*********************************************************************
*********************************************************************;

*************************************************************
*************************************************************
*  (1) Non-prepared foods items in at-home food list fall into one and only one BFL food group
*************************************************************
*************************************************************;

sort country
*We already determined this in the specificity analysis;
merge 1:1 country using "$outputdata\specfl.dta"
tab _merge
drop _merge

*First-best;
gen dd_fb_1=0 if perc_span~=.
replace dd_fb_1=1 if perc_span==0
tab dd_fb_1, missing
tab dd_fb_1

*Second-best;
gen dd_sb_1=0 if perc_span~=.
replace dd_sb_1=1 if perc_span<5 & perc_span~=.
tab dd_sb_1, missing
tab dd_sb_1

*************************************************************
*************************************************************
*  (2) Data are collected on the specific foods, dishes and beverages consumed away from home
*************************************************************
*************************************************************;

*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fcafh.dta";
*tab _merge; drop _merge;

*The condition is not met if no data are collected on food consumed away from home;
gen dd_2=0 if fafh_yes==0

********** Interview surveys;
tab Q8_11 if int_diary==1 & Q6_2a>0 & Q6_2a~=., missing
replace dd_2=0 if int_diary==1 & Q8_11==2

*If there is only one food item, then the condition is not met;
replace dd_2=0 if int_diary==1 & Q6_2a==1

/*
keep if int_diary==1 & Q6_2a>0 & Q6_2a~=. & Q8_11==1;
keep country Q8_12 Q8_13* Q8_14 Q8_15;

Bangladesh: Good list of specified prepared foods and beverages, but one of items is "Meals(rice/biriani)".   Not possible to identify
foods in these dishes.

Bolivia:  Food categories contain some specific dishes in descriptions, but they are not broken down by food or individual dish.
Bulgaria:  Broken down by meals, not specific dishes.
Ecuador:  Broken down by meals and then same pattern as Bolivia.
Ghana:  Only three specific types of meals.
Jamaica:  A few food groupings, but not specific enough to identify foods (e.g., "Sandwiches", "Burgers", "Patties").
Nigeria:  Like Bolivia.
Rwanda:  A few specific dishes then "Aliments consommes dans un bar", "Repas pris au restaurant", etc.
Sudan:  Mix of six specific and un-specific items.
Tajikistan:  Two items:  Meals consumed outside the home and Non-alcoholic drinks consumed outside the home.
Tanzania: Somewhat like Bolivia.
Turkemenistan:  By meal and then some specific beverages.

Uganda:  Lots of specific food items, but some important ones left out, especially plantain bananans, the main staple.
Also, data collected on such things as margarine or other single food items that are most likely consumed in dishes, not alone.
So, hard to see how data could be collected individually on these things for foods eaten outside of the home.

Myanmar (comes the closest):  Twelve presumably commonly consumed dishes consumed outside of the home plus last category: "Other foods".
If these twelve dishes make up a large proportion of the food consumed outside of the home then this survey can be considered to satisfy 
the criteron.  We will assume so;
*/
replace dd_2=0 if inlist(country,"Bangladesh","Bolivia","Bulgaria","Ecuador","Ghana","Jamaica","Nigeria")
replace dd_2=0 if inlist(country,"Rwanda","Sudan","Tajikistan","Tanzania","Turkmenistan","Uganda")

replace dd_2=1 if country=="Myanmar"
la var dd_2 "Data are collected on the specific foods, dishes and beverages consumed away from home"
tab dd_2 if int_diary==1, missing

********** Diary surveys;
tab Q8_20 if int_diary==2, missing

list country Q6_2a if int_diary==2 & Q8_20==1

/*
We will assume the diary surveys where there are explicit instructions to identify specific foods, dishes and beverages consumed
actually do contain food items with these (even if the way foods were aggregated for analysis does not contain many of these 
types of food items
*/

replace dd_2=1 if int_diary==2 & Q8_20==1

list country Q6_2a if int_diary==2 & Q8_20==2
*Note:  The surveys where there are no instructions to include specific food items indeed tend to have very few total items
*for FCAFH in their food list.  The one exception is Republic of Congo, and here the food list contains very un-specific items
*like "Breakfast taken out (in a restaurant)";

replace dd_2=0 if int_diary==2 & Q8_20==2

tab dd_2 if int_diary==2, missing
tab dd_2 if int_diary==2

list country Q8_20 Q8_21 Q8_22 if int_diary==2 & dd_2==.
*The remaining 9 cases will be missing (presumably the information is not available to answer the question);

tab dd_2, missing
tab dd_2

save "$outputdata\HCES_food_assessment_edited.dta", replace

*************************************************************
*************************************************************
*  (3)  The individual foods contained in prepared dishes is known
*************************************************************
*************************************************************;

*Note: We were not able to collect adequate information on this topic;
*Here we look only at availability of information for surveys in which data were
*collected on specific types of food consumed away from home;

********** Interview surveys;

*What percent of surveys collected data on specific food items consumed away from home?;
tab Q8_11 if int_diary==1, missing

*Among these, what percent had data on ingredients?;
tab Q8_14 if int_diary==1 & Q8_11==1


********** Diary surveys;

*What percent of surveys collected data on specific food items consumed away from home?;
tab Q8_20 if int_diary==2, missing

*Among these, what percent had data on ingredients?;
tab Q8_21 if int_diary==2 & Q8_20==1, missing


*************************************************************
*************************************************************
*  Summary of whether conditions are met
*************************************************************
*************************************************************;

tab dd_fb_1
tab dd_sb_1
tab dd_2

*First-best;
gen dd_fb=0 if dd_fb_1~=. & dd_2~=.
la var dd_fb "First-best method, dietary diversity"
replace dd_fb=1 if dd_fb_1==1 & dd_2==1
tab dd_fb

*Second-best;
gen dd_sb=0 if dd_sb_1~=. & dd_2~=.
la var dd_sb "Second-best method, dietary diversity"
replace dd_sb=1 if dd_sb_1==1 & dd_2==1
tab dd_sb

save "$outputdata\HCES_food_assessment_edited.dta", replace

*********************************************************************
*********************************************************************
**     DATE:       September 2012
**     PROGRAM:    HCES Assessment_Reliability_Seasonality
**     AUTHOR:     LSmith
**     INFILE:     HCES Assessment 2012_100 country dataset
**     OUTFILE:    None 
**     PURPOSE:    Analyze reliability of the food data in Household Consumption 
**			       and expenditure surveys:  Seasonality taken into account
*********************************************************************;

tab Q3_1, missing

*Data are missing for four countries, so N=96;
*list country Q3_1 if Q3_1==. | Q3_1==99;

gen seasonality=1 if Q3_1==1
la var seasonality "Seasonality in food consumption patterns"
replace seasonality=2 if Q3_1==2
replace seasonality=3 if Q3_1==3
tab seasonality, missing

*list country Q3_1 Q3_1a Q3_1b if seasonality==2;

label def seasonality 1 "Not taken into account" 2 "From two to four rounds during a year" 3 "Spread fully throughout the year"
label val seasonality seasonality
tab seasonality, missing
tab seasonality /* figure 3.8 seasonality taken into account */

*Make variable for minimum reliabilty criterion
gen rc_7_season=0 if seasonality~=.
la var rc_7_season "Minimum reliability criteria for seasonality"
replace rc_7_season=1 if seasonality==2 | seasonality==3
tab rc_7_season, missing
tab rc_7_season /* figure 3.8 seasonality taken into account */

save "$outputdata\HCES_food_assessment_edited.dta", replace

*********************************************************************
*********************************************************************
**     DATE:       October 2012
**     PROGRAM:    HCES Assessment_Relevance_Measuring food security_Metric quantities
**     AUTHOR:     LSmith, partially based on initial SPSS program of Nathalie Troubat
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    outfiles\metric conversion.dta
**     PURPOSE:    Analyze relevance for various users of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Measuring food security (metric quantities)
*********************************************************************
*********************************************************************;

*NOTE:  The conversion methods are not numbered here in the same order they are given in the report table;
*They are re-ordered to match the order in the report table at the end of this syntax file;

/*
(1) Make some corrections to survey forms --- DONE in cleaning 
(2) Method 0:  Interviewer or respondent converts non-metric quantities to metric in the field
(3) Method 1:  Respondents are required to report in a metric unit of measure specified for each food item
(4) Method 2:  Respondents are required to report in either a metric unit of measure or "unities"
(5) Method 3:  Expenditure divided by metric price can be used
(6) Method 4:  Quantity data collected, choice of unit of measure, LUCFs available for conversion
(7) Look for additional Method 3 surveys from those for which no other conversion method is available
(8) Summary of methods used
(9) Re-number methods so they are consistent with table in report
(10) Assess whether FAFH data can be converted to metric quantities
(11) Calculate overall percent of surveys for which metric quantities can be calculated
*/

*************************************************************
*************************************************************
* (2) Method 0:  Interviewer or respondent converts non-metric quantities to metric in the field
*************************************************************
*************************************************************;

*When respondents report in non-metric units of measure interviewers or respondents are instructed 
*to convert to metric before recording final quantity;

*Find and check all cases where interviewers are instructed to convert non-metric units;

********* Purchases;
tab Q7_5d
tab Q7_10d
tab Q7_15d
*keep if Q7_5d==1 | Q7_10d==1 | Q7_15d==1;
*keep country Q7_5d Q7_10d Q7_15d;
*Note:  Malawi, Nicaragua and Togo not really these kinds of cases;

*Also did for HP and IK;

/*
Cape Verde:  All are metric but one:  "specify (Other)"  But interviewers are instructed to convert to a metric weight if a non-metric unit
of measure is used;

Honduras:  Respondent reports quantity and the unit of measure.  Then the interviewer writes in the code of that unit of measure.  It is not
clear who but then someone estimates the standard-unit weight of the quantity in the unit of measure and the interviewer records what the 
standard unit of measure is;

Morocco: Enumerators were asked to convert whenever possible quantities or volumes collected into kg or liters using either the scale that was 
provided to the enumerator or volumetric equivalents.

Niger:  "...section 18 collects information on the weight in gram of the food  and composition of meal prepared in-house.
Further, the enumerator is asked to weight all food products acquired by the household whenever is possible, but not sure how this is reported".

Rwanda:  For HP used a graduated bucket with 10 marks on it;

Russia:  For purchases respondents are to report in a metric unit but if not, they can report in unities and then the interviewer translates
into metric units;

Mozambique:  Respondent writes in unit of measure used and interviewer writes in the weight in a standard unit;
From comment box:
"Column (8) "Standard Unit" - The interviewers will have at their disposal a list indicating which standard unit to use for each food.   
Column (9) "Quantity in Standard Units" - this column is for the conversion of the local unit to the standard unit.  For example, if the 
household bought a cup of sugar, column 3 has "cup" and column 4 has "1".  The product list tells the interviewer that the standard unit 
for sugar is kg. The interviewer should use the scale to measure how much sugar in kg is in the glass. 
If he finds that the cup has 200 grams, he should write 0.200 in column 9." (p. 66).

Mexico: Respondent writes down the quantity and unit of measure by hand and then someone (the interviewer?) writes down the equialent in KG or LT.

Guatemala:  Equivalent in a standard unit is written directly on the questionnaire;

Ethiopia: If data collected the same as for the 1999 data set (questionnaire looks similar), enumerators weighed food at the household level;

Angola:  Interviewer inserts the metric quantity and the standard unit of measure for each food item recored in the dairy;

Bolivia (hard to classify):  There are equivalences for the non-standard units printed right on the questionnaire for the interviewer to use to fill in the
questionnaire.  But still "unities", for which conversion factors would be needed.  Need to note this in a footnote;

Rwanda:  Demonstration methods used for HP;

Cambodia:  From the form:
The following information from the Interviewer Manual (p. 77) suggests that the large majority of units of measure are metric:
"As far as possible all entries in the diary referring to consumption of food should be measured in kilos or grams and all expenditures on beverages and other fluids should be entered in the diary using litres or millilitres (ml).
As an interviewer you have a scale to help you get estimates of the weight of consumption of own-produced and other expenditures.
If the household uses a vague measurement unit, such as palm, the scale can be used to get an estimate of how many grams they mean when they say palm, and then the estimate can be recorded in the diary."

Madagascar is a special case where HP data only are collected such that the conversion to metric takes place in the field--written
in by enumerator;

*/

gen method0_p=0
la var method0_p "Purchase - Interviewer or respondent converts non-metric quantities to metric in the field"
gen method0_hp=0
la var method0_hp "Home produce - Interviewer or respondent converts non-metric quantities to metric in the field"
gen method0_ik=0
la var method0_ik "Inkind - Interviewer or respondent converts non-metric quantities to metric in the field"

replace method0_p=1  if inlist(country,"Cape Verde","Honduras","Morocco","Niger","Russia","Mozambique","Mexico","Guatemala")
replace method0_p=1  if inlist(country,"Ethiopia","Angola","Bolivia","Cambodia")

replace method0_hp=1 if inlist(country,"Cape Verde","Honduras","Morocco","Niger","Mozambique","Mexico","Guatemala","Ethiopia")
replace method0_hp=1 if inlist(country,"Angola","Bolivia","Cambodia","Rwanda","Madagascar")	

replace method0_ik=1 if inlist(country,"Cape Verde","Honduras","Morocco","Niger","Mozambique","Mexico","Guatemala","Ethiopia")
replace method0_ik=1 if inlist(country,"Angola","Bolivia","Cambodia")

tab method0_p
tab method0_hp
tab method0_ik

*************************************************************
*************************************************************
* (3) Method 1:  Respondents are required to report in a metric unit of measure specified for each food item
*************************************************************
*************************************************************;

*Note:  Here we are including the countries with a few food items for which reporting is in unities;

*******************************************
* Purchases
*******************************************;

tab Q7_2, missing
*86 surveys have quantities;

tab Q7_3 if Q7_2==1, missing
*20 surveys have positive values;
tab Q7_3 if Q7_2==2, missing
*None, as expected;

*Check difference between number of food items and number for which asked to report in a pre-determined unit of measure;
*keep if Q7_2==1 & Q7_3>0 & Q7_3~=.;
gen percdif1=(Q7_2a-Q7_3)*100/Q7_3
tab percdif1, missing
*No big differences;
drop percdif1
*Check difference between number of food items for which asked to report in a pre-determined unit of measure and number that are metric;
gen percdif2=(Q7_3-Q7_3a)*100/Q7_3a
tab percdif2, missing

*All of these have zero or very few food items with local units of measure (usually "count"), except:
*Sri Lanka, for whom 46 out of 196 are local units of measure (number, bundle);
*Philippines, for whom 23 out of 155 are local units of measure (pieces, bundle);
*Myanmar, for whom 47 out of 144 are local units of measure (number, packet, tin, loaf, bottle);
*Note: Timor-Leste has only 8 out of 123, so we will count it as a Method 1 survey; 

gen method1_p=0
la var method1_p "Purchase - Respondents are required to report in a metric unit of measure specified for each food item"
replace method1_p=1 if Q7_2==1 & Q7_3>0 & Q7_3~=. & country~="Sri Lanka" & country~="Philippines" & country~="Myanmar"
tab method1_p, missing /* table 3.4 Method 1 - purchase */
drop percdif2

*******************************************
* Home production
*******************************************;

tab Q7_7, missing

tab Q7_8 if Q7_7==1, missing
*16 surveys have positive values;
tab Q7_8 if Q7_7==2, missing
*None, as expected;

*Check difference between number of food items and number for which asked to report in a pre-determined unit of measure;
*keep if Q7_7==1 & Q7_8>0 & Q7_8~=.;
gen percdif1=(Q7_7a-Q7_8)*100/Q7_8
tab percdif1, missing
*No big differences;
*keep country Q7_7a Q7_8 percdif1;
*order country Q7_7a Q7_8 percdif1;

drop percdif1

*Check difference between number of food items for which asked to report in a pre-determined unit of measure and number that are metric;
*keep if Q7_7==1 & Q7_8>0 & Q7_8~=.;
gen percdif2=(Q7_8-Q7_8a)*100/Q7_8a
tab percdif2, missing
*keep country Q7_8 Q7_8a percdif2;
*order country Q7_8 Q7_8a percdif2;

*All of these have zero or very few local units of measure, usually "count", except;
*St. Lucia, for which there are a significant number of food items measures in count and one which is "head/bundle";
*Myanmar, for whom there are a signficant number (47 out of 144) of local units of measure (number, packet, tin, loaf, bottle);

*Others with some local units, but which we will count as Method 1 surveys:
*Pakistan (12/92), all counts or "blanks"--see above;
*Note: Timor-Leste has only 8 out of 123, so we will count it as a Method 1 survey; 
*Note:  India has only 7 out of 97, so we will count it as a Method 1 survey;
*Note:  Mongolia 12/114, and they are counts;

gen method1_hp=0
la var method1_hp "Home produce - Respondents are required to report in a metric unit of measure specified for each food item"
replace method1_hp=1 if Q7_7==1 & Q7_8>0 & Q7_8~=. & country~="St. Lucia" & country~="Myanmar"

*Russia;
replace method1_hp=1 if country=="Russia"

tab method1_hp, missing /* table 3.4 Method 1 - home produce */

drop percdif2

*******************************************
* In Kind
*******************************************;

tab Q7_12, missing

tab Q7_13 if Q7_12==1, missing
*16 surveys have positive values;
tab Q7_13 if Q7_12==2, missing
*None, as expected;

*Check difference between number of food items and number for which asked to report in a pre-determined unit of measure;
*keep if Q7_12==1 & Q7_13>0 & Q7_13~=.;
gen percdif1=(Q7_12a-Q7_13)*100/Q7_13
tab percdif1, missing
*No big differences;
*keep country Q7_12a Q7_13 percdif1;
*order country Q7_12a Q7_13 percdif1;

drop percdif1

*Check difference between number of food items for which asked to report in a pre-determined unit of measure and number that are metric;
*keep if Q7_12==1 & Q7_13>0 & Q7_13~=.;
gen percdif2=(Q7_13-Q7_13a)*100/Q7_13a
tab percdif2, missing
*keep country Q7_13 Q7_13a percdif2;

*India and Pakistan are OK;

*Not OK:
*Philippines, for whom there are a significant number (23 out of 155) of local units of measure (pieces, bundle);
*Myanmar, for whom there are a signficant number (47 out of 144) of local units of measure (number, packet, tin, loaf, bottle);

gen method1_ik=0
la var method1_ik "Inkind - Respondents are required to report in a metric unit of measure specified for each food item"
replace method1_ik=1 if Q7_12==1 & Q7_13>0 & Q7_13~=. & country~="Philippines" & country~="Myanmar"

*Russia;
replace method1_ik=1 if country=="Russia"

tab method1_ik, missing /* table 3.4 Method 1 - received in kind */

drop percdif2

*************************************************************
*************************************************************
* (4) Method 2:  Respondents are required to report in either a metric unit of measure or "unities"
*************************************************************
*************************************************************;

*This was determined by looking at the questionnaires for those surveys for which Q7_5==1, Q7_5a>0 and Q7_5b=1;
*and then finding out what the one unit of measure is for Q5_7b;
*keep if Q7_5==1 & Q7_5a>0 & Q7_5a~=. & Q7_5b==1;
*Same for the other sources;

*Nigeria:  Respondents can chose either a metric unit, unities or "other specify";
*So this method does not apply;
*Look for all cases that might be like this;
*keep if Q7_5==1 & Q7_5a>0 & Q7_5a~=. & Q7_5b==1 & Q7_5c==1;
*Just Nigeria;


*******************************************
* Purchases
*******************************************;

gen method2_p=0
la var method2_p "Purchase - Respondents are required to report in either a metric unit of measure or 'unities'"
replace method2_p=1 if inlist(country,"Georgia","Azerbaijan","Lithuania","Kazakhstan","Guinea-Bissau","Ukraine")
replace method2_p=1 if inlist(country,"Tanzania","Belarus","Uzbekistan","Latvia","Armenia","Albania")
tab method2_p, missing


*******************************************
* Home production
*******************************************;

gen method2_hp=0
la var method2_hp "Home produce - Respondents are required to report in either a metric unit of measure or 'unities'"
replace method2_hp=1 if inlist(country,"Georgia","Azerbaijan","Lithuania","Kazakhstan","Guinea-Bissau","Ukraine")
replace method2_hp=1 if inlist(country,"Tanzania","Belarus","Uzbekistan","Latvia","Armenia","Albania")
tab method2_hp, missing

*******************************************
* In Kind
*******************************************;

gen method2_ik=0
la var method2_ik "Inkind - Respondents are required to report in either a metric unit of measure or 'unities'"
replace method2_ik=1 if inlist(country,"Georgia","Azerbaijan","Lithuania","Kazakhstan","Guinea-Bissau","Ukraine")
replace method2_ik=1 if inlist(country,"Tanzania","Belarus","Uzbekistan","Latvia","Armenia")
tab method2_ik, missing

*Albania: No data collected on inkind;
replace method2_ik=. if country=="Albania"

tab method2_p
tab method2_hp
tab method2_ik


*************************************************************
*************************************************************
* (5) Method 3:  Expenditure divided by metric price can be used
*************************************************************
*************************************************************;

/*
Note:  In this section we are only considering this a possibility for surveys for which only
expenditures data (not quantity) were collected.  Below we look for additional surveys
from among those for which other methods could not be used
*/


*******************************************
* Purchases
*******************************************;
gen onlyexp_p=0
replace onlyexp_p=1 if Q7_1==1 & Q7_2==2
tab onlyexp_p, missing

*Make sure rest of questions in Section A weren't answered (flags errors in Q7_1 and Q7_2);
*keep if onlyexp_p==1;
*keep country Q7*;
*OK;

*Look at number of food items for which expenditures data collected compared to total;
/*
keep if onlyexp_p==1;
gen numitems=Q6_1-Q6_2a;
gen percdif=(numitems-Q7_1a)/Q7_1a;
keep country numitems Q7_1 Q7_1a percdif;
order country Q7_1 numitems Q7_1a percdif;
*Ghana has a difference here because some of items in the home produced list are not included
*in the purchases list, so it's OK;
*Same with Sierra Leone;
*/

*Look at price availability information;
/*
keep if onlyexp_p==1;
keep country Q7_1a Q7_22* Q7_23*;
order country Q7_1a Q7_22* Q7_23*;
sort Q7_22;
*/

/*
Sierra Leone (OK):  Detailed price collected at community level;
Djibouti (OK):  Price data only collected in capital, but it's mostly a "city state";
Rwanda (not OK):  No price data collected a part of survey (previous study used CPI data but for this study we consider that 
     not reliable enough for proper matching with survey foods and locations);
Zambia (not OK): Unit values can be calculated from the HP and IK data collected, but won't be usefull if the items were not home produced
    or received in kind in the locations were they were purchased (previous study used CPI data as for Rwanda);
Ghana (OK): Community and household level price data collected (latter for HP), which are probably sufficient for calculating metric Qs;  
Mauritania (not OK):  Not enough prices to cover all of the purchased food items;
Senegal (not OK):  No prices;
Jamaica (OK):  Monthly CPI price data can be used because they are based on the same foods conducted in a previous HCES (2003/04);

The countries for which Q7_22=3 or 4:  The survey documentation does not indicate that any prices were collected as part of the survey;

*/

gen method3_p=0
la var method3_p "Purchase - Respondents choose the unit of measure; conversion factors collected separately"
replace method3_p=1 if onlyexp_p==1 & inlist(country,"Sierra Leone","Ghana","Jamaica","Djibouti")

tab method3_p,m 

*******************************************
* Home production
*******************************************;

gen onlyexp_hp=0
replace onlyexp_hp=1 if Q7_6==1 & Q7_7==2
tab onlyexp_hp, missing

*Make sure rest of questions in Section A weren't answered (flags errors in Q7_6 and Q7_7);
*keep if onlyexp_hp==1;
*keep country Q7*;
*OK;

*Look at number of food items for which expenditures data collected compared to total (for HP it can be significantly less);
/*
keep if onlyexp_hp==1;
gen numitems=Q6_1-Q6_2a;
gen percdif=(numitems-Q7_6a)/Q7_6a;
keep country numitems Q7_6 Q7_6a percdif;
order country Q7_6 numitems Q7_6a percdif;
*/

*Look at price availability information;
/*
keep if onlyexp_hp==1;
keep country Q7_6a Q7_22* Q7_23*;
order country Q7_6a Q7_22* Q7_23*;
sort Q7_22;
*/

*Jamaica (OK):  Monthly CPI price data can be used because they are based on the same foods conducted in a previous HCES (2003/04);
*For the rest prices are not available;

gen method3_hp=0
la var method3_hp "Home produce - Respondents choose the unit of measure; conversion factors collected separately"
replace method3_hp=1 if country=="Jamaica"
tab method3_hp,m

******************************************
* In Kind
*******************************************;

gen onlyexp_ik=0
replace onlyexp_ik=1 if Q7_11==1 & Q7_12==2
tab onlyexp_ik, missing

*Make sure rest of questions in Section A weren't answered (flags errors in Q7_11 and Q7_12);

*Look at number of food items for which expenditures data collected compared to total; 

*Look at price availability information;

*Jamaica (OK):  Monthly CPI price data can be used because they are based on the same foods conducted in a previous HCES (2003/04);
*Kosovo (not OK):  Prices available from a concurrent survey but we don't know if they match the food items in the survey;
*Bosnia & H and Bulgaria (OK):  Purchases and HP have metric unit values that can be used to estimate;
*Bulgaria (OK):  
*Rest:  No prices;

gen method3_ik=0
la var method3_ik "Inkind - Respondents choose the unit of measure; conversion factors collected separately"
replace method3_ik=1 if country=="Jamaica" | country=="Bosnia and Herzegovina" | country=="Bulgaria"
tab method3_ik,m

*************************************************************
*************************************************************
* (6) Method 4:  Quantity data collected, choice of unit of measure, LUCFs available for conversion
*************************************************************
*************************************************************;

*Nigeria:  Respondents can chose either a metric unit, unities or "other specify";
*So need to see if Method 4 will work for it;

*Paraguay: They tried to estimate metric weights using observations from households that reported in 
*metric units of measure.  We will not consider that legitimate;

*******************************************
* Purchases
*******************************************;

*Are there any surveys for which respondents choose the unit of measure and all the units of choice are metric?;
*keep if Q7_5==1 & Q7_5a>0 & Q7_5a~=. & method0_p==0 & method2_p==0;
*keep country Q7_5 Q7_5a Q7_5b;
*No;

gen method4_p=0
la var method4_p "Purchase - Respondents choose the unit of measure, interviewers convert to metric in the field"

********** Flag surveys where quantity data are collected but where other methods not to be used;
gen qty_p=0
la var qty_p "Purchase - flag surveys where quantity data are collected but where other methods not to be used"
replace qty_p=1 if Q7_2==1 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1
tab qty_p
*46 surveys;

************************************** Cases where units are recorded in "plain text";

***** Flag cases where units are recorded in plain text only;

*****  Cases where local unit conversion factors were collected for a sufficient number of food items as part of the survey;
replace method4_p=1 if Q7_4==1 & Q7_5==2 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 & Q7_18==1 & Q7_18a>0.5*Q7_2a & Q7_18a~=.

*****  Cases where local unit conversion factors were collected for a sufficient number of food items as part of a separate survey;
replace method4_p=1 if country=="Bhutan"
*See comment box Q7_21;
replace method4_p=1 if country=="Ecuador"
*See comment box Q7_21;

*****  Cases where recording could take place in local units of measure but no local unit conversion factors were collected;
*replace method4_p=8888 if Q7_4==1 & Q7_5==2 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 &    Q7_18==4;
					
			   					   																																																																																																																																																								    
*****  Cases where we don't know if local unit conversion factors were collected;
*replace method4_p=9999 if Q7_4==1 & Q7_5==2 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 & Q7_18==5;
					   
					   
************************************** Cases where there is a pre-defined list of units of measure;
*keep if Q7_5==1 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 & method4_p==0;
*keep country Q7_5* Q6_1 Q6_2a Q7_18* Q7_19*;
*sort Q7_18;

**********  Cases where local unit conversion factors were collected for a sufficient number of food items as part of the survey or a separate survey;
replace method4_p=1 if Q7_5==1 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 & method4_p==0 & Q7_18==1 & Q7_18a>0.5*Q7_2a & Q7_18a~=.
*Uganda, Liberia, Union de Comores;				   
				   
replace method4_p=1 if Q7_5==1 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 & method4_p==0 & Q7_18==2
*Malawi;

**Nicaragua is probably OK, but still checking;
replace method4_p=1 if country=="Nicaragua"

*Kenya is OK, although we don't have the info on the exact number of food items and units of measure;
replace method4_p=1 if country=="Kenya"

*****  Cases where recording could take place in local units of measure but no local unit conversion factors were collected;
*replace method4_p=8888 if Q7_5==1 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 & Q7_18==4;
				   
**********  Cases where we don't know if local unit conversion factors were collected;
*replace method4_p=9999 if Q7_5==1 & method0_p~=1 & method1_p~=1 & method2_p~=1 & method3_p~=1 & Q7_18==5;
tab method4_p, missing


*******************************************
* Home production 
*******************************************;

gen method4_hp=0
la var method4_hp "Home produce - Respondents choose the unit of measure, interviewers convert to metric in the field"
*Are there any surveys for which respondents choose the unit of measure and all the units of choice are metric?;

********** Flag surveys where quantity data are collected but where other methods not to be used;
gen qty_hp=0
la var qty_hp "Home produce - flag surveys where quantity data are collected but where other methods not to be used"
replace qty_hp=1 if Q7_7==1 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1
tab qty_hp
*49 surveys;

************************************** Cases where units are recorded in "plain text";

***** Flag cases where units are recorded in plain text only;

*****  Cases where local unit conversion factors were collected for a sufficient number of food items as part of the survey;
replace method4_hp=1 if Q7_9==1 & Q7_10==2 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1 & Q7_18==1 & Q7_18a>0.5*Q7_7a & Q7_18a~=.
*Burundi;

*****  Cases where local unit conversion factors were collected for a sufficient number of food items as part of a separate survey;
replace method4_hp=1 if country=="Bhutan"
*See comment box Q7_21;
replace method4_hp=1 if country=="Ecuador"
*See comment box Q7_21;

*****  Cases where recording could take place in local units of measure but no local unit conversion factors were collected;
*replace method4_hp=8888 if Q7_9==1 & Q7_10==2 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1  & Q7_18==4;
					   					   																																																																																																																																																								    
*****  Cases where we don't know if local unit conversion factors were collected;
*replace method4_hp=9999 if Q7_9==1 & Q7_10==2 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1 & Q7_18==5;
					   

************************************** Cases where there is a pre-defined list of units of measure;
*keep if Q7_10==1 & method1_hp~=1 & method0_hp~=1 & method2_hp~=1 & method3_hp~=1 & method4_hp==0;
*keep country Q7_7a Q7_10* Q7_18* Q7_19*;
*sort Q7_18;

**********  Cases where local unit conversion factors were collected for a sufficient number of food items as part of the survey or a separate survey;
replace method4_hp=1 if Q7_10==1 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1 & method4_hp==0 & Q7_18==1 & Q7_18a>0.5*Q7_7a & Q7_18a~=.
*Uganda, Liberia, Togo, Mauritania, Union de Comores;				   
				   
replace method4_hp=1 if Q7_10==1 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1 & method4_hp==0 & Q7_18==2
*Malawi;

**Nicaragua is probably OK, but still checking;
replace method4_hp=1 if country=="Nicaragua"

*Kenya is OK, but we don't have the info on the exact number of food items and units of measure;
replace method4_p=1 if country=="Kenya"

*****  Cases where recording could take place in local units of measure but no local unit conversion factors were collected;
*replace method4_hp=8888 if Q7_10==1 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1 & method4_hp==0 & Q7_18==4;
				   
**********  Cases where we don't know if local unit conversion factors were not collected;
*replace method4_hp=9999 if Q7_10==1 & method0_hp~=1 & method1_hp~=1 & method2_hp~=1 & method3_hp~=1 & method4_hp==0 & Q7_18==5;

tab method4_hp, missing


*******************************************
* In kind
*******************************************;

gen method4_ik=0
la var method4_ik "Inkind - Respondents choose the unit of measure, interviewers convert to metric in the field"
*Are there any surveys for which respondents choose the unit of measure and all the units of choice are metric?;

********** Flag surveys where quantity data are collected but where other methods not to be used;
gen qty_ik=0
la var qty_ik "Inkind - flag surveys where quantity data are collected but where other methods not to be used"
replace qty_ik=1 if Q7_7==1 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1
tab qty_ik
*49 surveys;

************************************** Cases where units are recorded in "plain text";

***** Flag cases where units are recorded in plain text only;

*****  Cases where local unit conversion factors were collected for a sufficient number of food items as part of the survey;
replace method4_ik=1 if Q7_14==1 & Q7_15==2 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & Q7_18==1 & Q7_18a>0.5*Q7_12a & Q7_18a~=.
*Burundi;

*****  Cases where local unit conversion factors were collected for a sufficient number of food items as part of a separate survey;
replace method4_ik=1 if country=="Ecuador"
*Ecuador is OK:  See comment box Q7_17;

*****  Cases where recording could take place in local units of measure but no local unit conversion factors were collected;
*replace method4_ik=8888 if Q7_14==1 & Q7_15==2 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & Q7_18==4;
					   					   																																																																																																																																																								    
*****  Cases where we don't know if local unit conversion factors were collected;
*replace method4_ik=9999 if Q7_14==1 & Q7_15==2 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & Q7_18==5;
					   
************************************** Cases where there is a pre-defined list of units of measure;
*keep if Q7_15==1 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & method4_ik==0;

**********  Cases where local unit conversion factors were collected for a sufficient number of food items as part of the survey or a separate survey;
replace method4_ik=1 if Q7_15==1 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & method4_ik==0 & Q7_18==1 & Q7_18a>0.5*Q7_12a & Q7_18a~=.
*Uganda, Liberia;				   
				   
replace method4_ik=1 if Q7_15==1 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & method4_ik==0 & Q7_18==2
*Malawi;

**Nicaragua is probably OK, but still checking;
replace method4_ik=1 if country=="Nicaragua"

*Kenya is OK, but we don't have the info on the exact number of food items and units of measure;
replace method4_p=1 if country=="Kenya"

*****  Cases where recording could take place in local units of measure but no local unit conversion factors were collected;
*replace method4_ik=8888 if Q7_15==1 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & method4_ik==0 & Q7_18==4;
				   
**********  Cases where we don't know if local unit conversion factors were not collected;
*replace method4_ik=9999 if Q7_15==1 & method0_ik~=1 & method1_ik~=1 & method2_ik~=1 & method3_ik~=1 & method4_ik==0 & Q7_18==5;

tab method4_ik, missing


*************************************************************
*************************************************************
* (7) Look for additional Method 3 surveys from those for which no other conversion method is available
*************************************************************
*************************************************************;

/*
Note:  We are looking for surveys for whom expenditures and quantity data are collected but we can't 
convert using the other methods.  Collected prices would need to be available (not unit values from households
who happen to report in metric units).

Since in this case the information could be used to calculate local unit conversion factors as well, distinction 
between methods is not completely clear;
*/

*Ghana and Sierra Leone HP:  Can be added here because data were collected on metric quantities but also on the price per unit.  This
*can be used to compute expenditures and then the community prices can be used to convert;
replace method3_hp=1 if country=="Ghana" | country=="Sierra Leone"


*******************************
* Make variables indicating if any of the other methods are available for conversion (so far)
*******************************;

*Need to take into account fact that data for either HP or IK might not be collected at all;

*The code for "data not collected" is 7777;

**@@+ merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\sources.dta";
**@@+ tab _merge; drop _merge;

tab rc_2_3modes, missing
*16 surveys have at least one missing source;

tab m_purch
*All have purchases;

tab m_hp
*Three surveys do not have HP;
replace method0_hp=7777 if m_hp==0
replace method1_hp=7777 if m_hp==0
replace method2_hp=7777 if m_hp==0
replace method3_hp=7777 if m_hp==0
replace method4_hp=7777 if m_hp==0

tab m_ik
*Fourteen surveys do not have IK;
replace method0_ik=7777 if m_ik==0
replace method1_ik=7777 if m_ik==0
replace method2_ik=7777 if m_ik==0
replace method3_ik=7777 if m_ik==0
replace method4_ik=7777 if m_ik==0

gen num_sources=3
la var num_sources "Number of food data collection sources (purchase/home produce/inkind)"
replace num_sources=1 if m_hp==0 & m_ik==0
replace num_sources=2 if (m_hp==0 & m_ik==1) | (m_hp==1 & m_ik==0)
tab num_sources

********** Purchases;
gen p_convert=0
replace p_convert=1 if method0_p==1|method1_p==1|method2_p==1|method3_p==1|method4_p==1

********** HP;
gen hp_convert=0 if method1_hp~=7777
replace hp_convert=1 if method0_hp==1|method1_hp==1|method2_hp==1|method3_hp==1|method4_hp==1

********** IK;
gen ik_convert=0 if method1_ik~=7777
replace ik_convert=1 if method0_ik==1|method1_ik==1|method2_ik==1|method3_ik==1|method4_ik==1

*Percent of surveys for which can convert purchases data so far;
tab p_convert

*Percent of surveys with HP data for which can convert so far;
tab hp_convert

*Percent of surveys with IK data for which can convert IK data so far;
tab ik_convert


*******************************
* Purchases
*******************************;

/*
keep if p_convert==0;
keep if Q7_1==1 & Q7_2==1;
keep country p_convert Q7_1a Q7_22* Q7_23*;
order country p_convert Q7_1a Q7_22* Q7_23*;
sort Q7_22;
keep if Q7_22==1 | Q7_22==2;
*/

/*
Lao:  124 food items but only 73 prices;
Republic of Congo.  Prices collected but we don't have access to price questionniare, so can't tell;
Gabon:  Prices not collected for enough foods;
Sudan:  Prices only collected for HP and IK and in the unit of measure specified so can't use only metric for conversion;
Nigeria:  Many of units of measure for price data collection are non-metric, so can't use for this method;
Cameroon:  Metric prices collected and used for calculating metric weights of foods in non-standard units (which is the same
            as dividing expenditures by metric prices), so OK; 
Philippines:  Yes, sufficient data (as long as prices were collected in metric units);
Kosovo:  Can't tell if prices collected for CPI would be sufficient for use of this  method;
Swaziland:  Price data were collected but we can't tell if it would be sufficient for use of this method;
*/

replace method3_p=1 if country=="Cameroun" | country=="Philippines"


*******************************
* Home produced
*******************************;

/*
keep if hp_convert==0;
keep if Q7_6==1 & Q7_7==1;
keep country p_convert Q7_6a Q7_22* Q7_23*;
order country p_convert Q7_6a Q7_22* Q7_23*;
sort Q7_22;
keep if Q7_22==1 | Q7_22==2;
*/

/*
Cameroon:  Metric prices collected and used for calculating metric weights of foods in non-standard units (which is the same
            as dividing expenditures by metric prices), so OK; 
Gabon:  Prices not collected for enough foods;
*Lao:  We don't know if we can match the food items to the available prices;
Republic of Congo.  Prices collected but we don't have access to price questionniare, so can't tell;
Swaziland:  Price data were collected but we can't tell if it would be sufficient for use of this method;
Kosovo:  Can't tell if prices collected for CPI would be sufficient for use of this  method;
*/

replace method3_hp=1 if country=="Cameroun"

*******************************
* Inkind
*******************************;

/*
keep if ik_convert==0;
keep if Q7_11==1 & Q7_12==1;
keep country ik_convert Q7_11a Q7_22* Q7_23*;
order country ik_convert Q7_11a Q7_22* Q7_23*;
sort Q7_22;
keep if Q7_22==1 | Q7_22==2;
*/

/*
Cameroon:  Metric prices collected and used for calculating metric weights of foods in non-standard units (which is the same
            as dividing expenditures by metric prices), so OK; 
Republic of Congo.  Prices collected but we don't have access to price questionniare, so can't tell;
Swaziland:  Price data were collected but we can't tell if it would be sufficient for use of this method;
Lao:  We don't know if we can match the food items to the available prices;
Philippines:  Yes, sufficient data (as long as prices were collected in metric units)
*/

replace method3_ik=1 if country=="Cameroun" | country=="Philippines"


*************************************************************
*************************************************************
* (8) Summary of methods used
*************************************************************
*************************************************************;

*******************************
* Check to see if there is any survey for which more than one method is available
*******************************;

gen sum_p=method0_p + method1_p + method2_p + method3_p + method4_p if method0_p~=7777
la var sum_p "Purchase - any survey for which more than one metric conversion method is available"
tab sum_p, missing
*No;

gen sum_hp=method0_hp + method1_hp + method2_hp + method3_hp + method4_hp if method0_hp~=7777
la var sum_hp "Home produce - any survey for which more than one metric conversion method is available"
tab sum_hp, missing
*No;

gen sum_ik=method0_ik + method1_ik + method2_ik + method3_ik + method4_ik if method0_ik~=7777
la var sum_ik "Inkind - any survey for which more than one metric conversion method is available"
tab sum_ik, missing
*No;

*******************************
* Calculate percent of surveys for which each method is possible, by source
*******************************;

tab method0_p
tab method0_hp if method0_hp~=7777   
tab method0_ik if method0_ik~=7777

tab method1_p 
tab method1_hp if method1_hp~=7777  
tab method1_ik if method1_ik~=7777

tab method2_p 
tab method2_hp if method2_hp~=7777  
tab method2_ik if method2_ik~=7777

tab method3_p
tab method3_hp if method3_hp~=7777  
tab method3_ik if method3_ik~=7777

tab method4_p
tab method4_hp if method4_hp~=7777  
tab method4_ik if method4_ik~=7777

*******************************
* Calculate percent for which all can be calculated (taking into account only the sources for which data collected)
*******************************;

*Delete variable calculated above before final count was in;
drop p_convert hp_convert ik_convert

gen p_convert=0
la var p_convert "Purchase - Metric quantities can be calculated"
replace p_convert=1 if method0_p==1|method1_p==1|method2_p==1|method3_p==1|method4_p==1

gen hp_convert=0 if method0_hp~=7777
la var hp_convert "Home produce - Metric quantities can be calculated"
replace hp_convert=1 if method0_hp==1|method1_hp==1|method2_hp==1|method3_hp==1|method4_hp==1

gen ik_convert=0 if method0_ik~=7777
la var ik_convert "Inkind - Metric quantities can be calculated"
replace ik_convert=1 if method0_ik==1|method1_ik==1|method2_ik==1|method3_ik==1|method4_ik==1

*Surveys for which all three sources collected;
gen all_convert=0
la var all_convert "All three sources - Metric quantities can be calculated"
replace all_convert=1 if p_convert==1 & hp_convert==1 & ik_convert==1 & (m_p==1 & m_hp==1 & m_ik==1)

*Surveys for which only purchases were collected;
replace all_convert=1 if p_convert==1 & (m_p==1 & m_hp==0 & m_ik==0)

*Surveys for which only purchases and hp were collected;
replace all_convert=1 if p_convert==1 & hp_convert==1 & (m_p==1 & m_hp==1 & m_ik==0)

*Surveys for which only purchases and ik were collected;
replace all_convert=1 if p_convert==1 & ik_convert==1 & (m_p==1 & m_hp==0 & m_ik==1)

tab p_convert
tab hp_convert
tab ik_convert
tab all_convert

*******************************
* Calculate percent of surveys for which each method is used for all sources for which data collected
*******************************;

gen all_m0=0
gen all_m1=0
gen all_m2=0
gen all_m3=0
gen all_m4=0
la var all_m0 "Interviewer or respondent converts non-metric quantities to metric in the field"
la var all_m1 "Respondents are required to report in a metric unit of measure specified for each food item"
la var all_m2 "Respondents are required to report in either a metric unit of measure or 'unities'"
la var all_m3 "Respondents choose the unit of measure; conversion factors collected separately"
la var all_m4 "Respondents choose the unit of measure, interviewers convert to metric in the field"

*Surveys for which all three sources collected;
replace all_m0=1 if method0_p==1 & method0_hp==1 & method0_ik==1 & (m_p==1 & m_hp==1 & m_ik==1)
replace all_m1=1 if method1_p==1 & method1_hp==1 & method1_ik==1 & (m_p==1 & m_hp==1 & m_ik==1)
replace all_m2=1 if method2_p==1 & method2_hp==1 & method2_ik==1 & (m_p==1 & m_hp==1 & m_ik==1)
replace all_m3=1 if method3_p==1 & method3_hp==1 & method3_ik==1 & (m_p==1 & m_hp==1 & m_ik==1)
replace all_m4=1 if method4_p==1 & method4_hp==1 & method4_ik==1 & (m_p==1 & m_hp==1 & m_ik==1)

*Surveys for which only purchases and hp were collected;
replace all_m0=1 if method0_p==1 & method0_hp==1 & (m_p==1 & m_hp==1 & m_ik==0)
replace all_m1=1 if method1_p==1 & method1_hp==1 & (m_p==1 & m_hp==1 & m_ik==0)
replace all_m2=1 if method2_p==1 & method2_hp==1 & (m_p==1 & m_hp==1 & m_ik==0)
replace all_m3=1 if method3_p==1 & method3_hp==1 & (m_p==1 & m_hp==1 & m_ik==0)
replace all_m4=1 if method4_p==1 & method4_hp==1 & (m_p==1 & m_hp==1 & m_ik==0)

*Surveys for which only purchases and ik were collected;
replace all_m0=1 if method0_p==1 & method0_ik==1 & (m_p==1 & m_hp==0 & m_ik==1)
replace all_m1=1 if method1_p==1 & method1_ik==1 & (m_p==1 & m_hp==0 & m_ik==1)
replace all_m2=1 if method2_p==1 & method2_ik==1 & (m_p==1 & m_hp==0 & m_ik==1)
replace all_m3=1 if method3_p==1 & method3_ik==1 & (m_p==1 & m_hp==0 & m_ik==1)
replace all_m4=1 if method4_p==1 & method4_ik==1 & (m_p==1 & m_hp==0 & m_ik==1)

*Surveys for which only purchases were collected;
replace all_m0=1 if method0_p==1 & (m_p==1 & m_hp==0 & m_ik==0)
replace all_m1=1 if method1_p==1 & (m_p==1 & m_hp==0 & m_ik==0)
replace all_m2=1 if method2_p==1 & (m_p==1 & m_hp==0 & m_ik==0)
replace all_m3=1 if method3_p==1 & (m_p==1 & m_hp==0 & m_ik==0)
replace all_m4=1 if method4_p==1 & (m_p==1 & m_hp==0 & m_ik==0)

tab all_m0
tab all_m1
tab all_m2
tab all_m3
tab all_m4
tab all_convert

*************************************************************
*************************************************************
* (9) Re-number methods so they are consistent with table in report
*************************************************************
*************************************************************;

rename method3_p method5_p
rename method3_hp method5_hp
rename method3_ik method5_ik
rename all_m3 all_m5

rename method4_p method3_p
rename method4_hp method3_hp
rename method4_ik method3_ik
rename all_m4 all_m3

rename method0_p method4_p
rename method0_hp method4_hp
rename method0_ik method4_ik
rename all_m0 all_m4

**Recheck report table percentages;
/* table 3.4 */
tab method1_p
tab method1_hp if method1_hp~=7777  
tab method1_ik if method1_ik~=7777

tab method2_p
tab method2_hp if method2_hp~=7777   
tab method2_ik if method2_ik~=7777

tab method3_p  
tab method3_hp if method3_hp~=7777   
tab method3_ik if method3_ik~=7777

tab method4_p  
tab method4_hp if method4_hp~=7777   
tab method4_ik if method4_ik~=7777

tab method5_p
tab method5_hp if method5_hp~=7777 
tab method5_ik if method5_ik~=7777

tab all_m1
tab all_m2
tab all_m3
tab all_m4
tab all_m5
tab all_convert


*************************************************************
*************************************************************
* (10) Assess whether FAFH data can be converted to metric quantities 
*************************************************************
*************************************************************;

*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\dietary diversity.dta";

*The variable for whether data are collected on the specific foods, dishes and beverages consumed away from home is dd_2;
tab dd_2, missing

*Check each survey for which this variable = 1 to see if can could convert to metric if we knew the individual foods in the dishes;

tab country if dd_2==1
/*
                         country |      Freq.     Percent        Cum.
---------------------------------+-----------------------------------
                          Angola |          1        7.14        7.14
                          Brazil |          1        7.14       14.29
                    Burkina Faso |          1        7.14       21.43
                        Cambodia |          1        7.14       28.57
                        Cameroun |          1        7.14       35.71
                      Cape Verde |          1        7.14       42.86
                Congo, Dem. Rep. |          1        7.14       50.00
                        Ethiopia |          1        7.14       57.14
                            Iraq |          1        7.14       64.29
                          Mexico |          1        7.14       71.43
                         Myanmar |          1        7.14       78.57
                           Niger |          1        7.14       85.71
                    South Africa |          1        7.14       92.86
                      Uzbekistan |          1        7.14      100.00
---------------------------------+-----------------------------------
                           Total |         14      100.00

*/

*We will assume that if it is possible to do it for food at home purchases, it is possible to do for food away;
gen fafh_convert=0 if dd_2~=.
la var fafh_convert "FAFH data can be converted to metric quantities"
replace fafh_convert=1 if dd_2==1 & (method1_p==1|method2_p==1|method3_p==1|method4_p==1|method5_p==1)
tab fafh_convert, missing

tab fafh_convert

*************************************************************
*************************************************************
* (11) Calculate overall percent of surveys for which metric quantities can be calculated
*************************************************************
*************************************************************;

gen metric_convert=0 if all_convert~=. & fafh_convert~=.
la var metric_convert "Surveys for which metric quantities can be calculated for both at-home and away"
replace metric_convert=1 if all_convert==1 & fafh_convert==1

tab metric_convert

drop onlyexp_p onlyexp_hp onlyexp_ik
*keep country method* all* p_convert hp_convert ik_convert fafh_convert metric_convert;
*order country method1* method2* method3* method4* method5* p_convert hp_convert ik_convert all_convert 
*all_m1 all_m2 all_m3 all_m4 all_m5 fafh_convert metric_convert;
*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\metric conversion.dta", replace;

save "$outputdata\HCES_food_assessment_edited.dta", replace
*********************************************************************
*********************************************************************
**     DATE:       October/November 2012
**     PROGRAM:    HCES Assessment_Relevance_Measuring food security_Calorie consumption
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    
**     PURPOSE:    Analyze relevance for various users of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Measuring food security (per-capita calorie consumption)
*********************************************************************
*********************************************************************;

*************************************************************
*************************************************************
* First-best method
*************************************************************
*************************************************************;

/*
1.  At least 95% of food  items in the at-home food list other than prepared dishes fall into one and only one of the BFL food groups; 
2.  Reasonably accurate estimates of metric quantities are calculable from the at-home food data;  
3.  Data are collected on the specific foods and prepared dishes that are consumed away from home, and metric quantities
    can be calculated from them
*/

*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\dietary diversity";
*tab _merge; drop _merge;

gen     cc_fb_1=0 if dd_sb_1~=.
la var cc_fb_1 "First-best method: At least 95% of food items in the at-home food list other than prepared dishes fall into one and only one of the BFL food groups"
replace cc_fb_1=1 if dd_sb_1==1
tab cc_fb_1, missing
tab cc_fb_1

*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\metric conversion";
*tab _merge; drop _merge;

gen cc_fb_2=0 if all_convert~=.
la var cc_fb_2 "First-best method: Reasonably accurate estimates of metric quantities are calculable from at-home food data"
replace cc_fb_2=1 if all_convert==1
tab cc_fb_2, missing
tab cc_fb_2

gen     cc_fb_3=0 if fafh_convert~=.
la var cc_fb_3 "First-best method: Data are collected on the specific foods and prepared dishes that are consumed away from home, and metric quantities"
replace cc_fb_3=1 if fafh_convert==1
tab cc_fb_3, missing
tab cc_fb_3

********** Determine whether all three criteria are met;
gen cc_fb=0 if cc_fb_1~=. & cc_fb_2~=. & cc_fb_3~=.
la var cc_fb "All criteria, first-best method: Calculate calorie consumption"
replace cc_fb=1 if cc_fb_1==1 & cc_fb_2==1 & cc_fb_3==1
tab cc_fb, missing
tab cc_fb
notes cc_fb_1: First-best method: Metric quantities are available for foods consumed at home and away from home
notes cc_fb_2: First-best method: Metric quantities are available for foods consumed at home and away from home
notes cc_fb_3: First-best method: Metric quantities are available for foods consumed at home and away from home
notes cc_fb: First-best method: Metric quantities are available for foods consumed at home and away from home
*************************************************************
*************************************************************
* Second-best method
*************************************************************
*************************************************************;

/*
1.  At least 95% of food  items in the at-home food list other than prepared dishes fall into one and only one of the BFL food groups; 
2.  Reasonably accurate estimates of metric quantities are calculable from the at-home food data;  
3.  Total expenditures on food consumed away from home can be calculated. 
	
Note:  If (1) and (2) are satisfied then it is possible to calculate the price-per-calories of food consumed at home because
we know we can calculate calories, and total expenditures data are always calculable for at-home foods
*/

***********************************
* (1) At least 95% of food items in the at-home food list other than prepared dishes fall into one and only one of the BFL food groups; 
***********************************;

gen     cc_sb_1=0 if dd_sb_1~=.
la var cc_sb_1 "Second-best method: At least 95% of food items in the at-home food list other than prepared dishes fall into one and only one of the BFL food groups"
replace cc_sb_1=1 if dd_sb_1==1
tab cc_sb_1, missing
tab cc_sb_1

***********************************
* (2) Reasonably accurate estimates of metric quantities are available for food consumed at home 
***********************************;

gen     cc_sb_2=0 if all_convert~=.
la var cc_sb_2 "Second-best method: Reasonably accurate estimates of metric quantities are calculable from at-home food data"
replace cc_sb_2=1 if all_convert==1
tab cc_sb_2, missing
tab cc_sb_2

***********************************
* (3)  Total expenditures on food consumed away from home can be calculated 
***********************************;
	  
*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\fcafh";
*tab _merge;  drop _merge;

*The answer is yes if data are collected on food consumed away from home at all because in this case expenditures data
*are always collected or can be calculated;
tab fafh_yes, missing

gen cc_sb_3=0
la var cc_sb_3 "Second-best method: Total expenditures on food consumed away from home can be calculcated"
replace cc_sb_3=1 if fafh_yes==1
tab cc_sb_3, missing
tab cc_sb_3


*For info;
*Check question on expenditures/quantities for interview surveys;
tab Q8_7 if int_diary==1, missing

*For Liberia and Mali only quantities are collected, but prices are collected for each food item too, so expenditures can be calculated;

***********************************
* Determine whether all three criteria are met
***********************************;

gen cc_sb=0 if cc_sb_1~=. & cc_sb_2~=. & cc_sb_3~=.
la var cc_sb "All criteria, second-best method: Calculate calorie consumption"
replace cc_sb=1 if cc_sb_1==1 & cc_sb_2==1 & cc_sb_3==1
tab cc_sb, missing
tab cc_sb

notes cc_sb_1: Second-best method: Metric quantities are available for foods consumed at home but not away from home
notes cc_sb_2: Second-best method: Metric quantities are available for foods consumed at home but not away from home
notes cc_sb_3: Second-best method: Metric quantities are available for foods consumed at home but not away from home
notes cc_sb: Second-best method, Metric quantities are available for foods consumed at home but not away from home
*************************************************************
*************************************************************
* Third-best method
*************************************************************
*************************************************************;

/*
1.  Reasonably accurate estimates of metric quantities are calculable from the at-home food data;
2.  Expenditures on unidentified food at home can be calculated (and they are less than 20 percent of foods)
3.  Total expenditures on food consumed away from home can be calculated. 
*/

gen cc_tb_1=0 if all_convert~=.
la var cc_tb_1 "Third-best method: Expenditure on unidentified foods consumed at home can be calculated"
replace cc_tb_1=1 if perc_span <20 & perc_span~=.


*tab perc_span, missing;
gen cc_tb_2=0 if perc_span~=.
la var cc_tb_2 "Third-best method: Reasonably accurate estimates of metric quantities are calculable from at-home food data"
replace cc_tb_2=1 if all_convert==1

gen cc_tb_3=cc_sb_3
la var cc_tb_3 "Third-best method: Total expenditures on food consumed away from home can be calculated"

***********************************
* Determine whether all three criteria are met
***********************************;

tab cc_tb_1
tab cc_tb_2
tab cc_tb_3

gen     cc_tb=0 if cc_tb_1~=. & cc_tb_2~=. & cc_tb_3~=.
la var cc_tb "All criteria, third-best method: Calculate calorie consumption"
replace cc_tb=1 if cc_tb_1==1 & cc_tb_2==1 & cc_tb_3==1
tab cc_tb, missing
tab cc_tb
notes cc_tb_1: Third-best method: Metric quantities are available for most, but not aall, at-home foods and not available for foods consumed away
notes cc_tb_2: Third-best method: Metric quantities are available for most, but not aall, at-home foods and not available for foods consumed away
notes cc_tb_3: Third-best method: Metric quantities are available for most, but not aall, at-home foods and not available for foods consumed away
notes cc_tb: Third-best method: Metric quantities are available for most, but not aall, at-home foods and not available for foods consumed away

*************************************************************
*************************************************************
* Calculate percent for which at least third-best is available
*************************************************************
*************************************************************;
tab cc_fb
tab cc_sb
tab cc_tb

*keep country cc_fb* cc_sb* cc_tb*;
*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\calorie consumption", replace;
save "$outputdata\HCES_food_assessment_edited.dta", replace

*********************************************************************
*********************************************************************
**     DATE:       October 2012
**     PROGRAM:    HCES Assessment_Relevance_Measuring food security_Protein_Micronutrient consumption
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    
**     PURPOSE:    Analyze relevance for various users of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Measuring food security (per-capita protein and micronutrient consumption)
*********************************************************************
*********************************************************************;

*use "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\HCES Assessment 2012__100-country dataset", clear;

*Because micronutrients are so food-specific, we can't assume we can predict the micronutrient content of 
*unidentified foods or of foods consumed away from home;

*The only viable method is equivalent to the first-best method for calorie consumption measurement;

/*
1.  At least 95% of food  items in the at-home food list other than prepared dishes fall into one and only one of the BFL food groups; 
2.  Reasonably accurate estimates of metric quantities are calculable from the at-home food data;  
3.  Data are collected on the specific foods and prepared dishes that are consumed away from home (and thus estimates of metric quantities
    of foods consumed away from home can be calculated)
*/

*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\calorie consumption";
*tab _merge; drop _merge;

tab cc_fb

***If drop unidentified at-home foods and foods consumed away from home, then only need #2 above
tab cc_tb_1
*save "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\micronutrient consumption", replace;


*********************************************************************
*********************************************************************
**     DATE:       December 2012
**     PROGRAM:    HCES Assessment_Relevance_Data collected on food to non-hh members
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    
**     PURPOSE:    Analyze relevance for various users of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Food given to non-household members
*********************************************************************
*********************************************************************;

*use "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\HCES Assessment 2012__100-country dataset", clear;

*Note:  We really need information on whether data were collected on food given to others;
*We didn't include a question on this in the assessment form, only on meal participation;


tab Q9_8, missing
recode Q9_9-Q9_14 (99=.)

tab Q9_9,  m
tab Q9_10, m
tab Q9_11, m
tab Q9_12, m
tab Q9_13, m
tab Q9_14, m
recode Q9_9-Q9_14 (.=99)

save "$outputdata\HCES_food_assessment_edited.dta", replace
*********************************************************************
*********************************************************************
**     DATE:       December 2012
**     PROGRAM:    HCES Assessment_Relevance_Informing food balance sheets
**     AUTHOR:     Nathalie Troubat and LSmith
**     INFILE:     HCES Assessment 2012__100-country dataset.dta 
**                 (altered version of above: Data\outfiles\Corrections to MFL)
**     OUTFILE:    None 
**     PURPOSE:    Analyze relevance of the food data in Household Consumption 
**                 and Expenditure Surveys:  Informing the compilation of Food Balance Sheets
*********************************************************************;

/*
 (A) Check Master Food List and make corrections
 (B) Add foods that were classified into Q6_116 but could actually be classified in some FBS groups 
 (C) Add foods that could not be classified into specific food groups in the Master Food List but can be 
     for the FBS list to the FBS food group counts 
 (D) Classify into the Basic Food List:  Foods classified under 6 other major headings" (in tan on the assessment form) 
     that should be under a specific BFL food group but are not
 (E) Determine:  Are all of the FBS food groups represented? 
 (F) What percent of food items span the food groups (apart from prepared foods)? 
 (G) Specificity:  Minimum number of food items in each group
 (H) The last three combined
 (I) Calculate the percent of surveys that can be used to estimate subsistence production
*/


**************************************************
**************************************************
* (A) Check Master Food List and make corrections
**************************************************
**************************************************;

*Note:  This is the same code as used for the reliability (comprehensiveness) analysis;

use "$outputdata\Corrections to MFL", clear

**************************************************
**************************************************
*  (B) Add foods that were classified into Q6_116 but could actually 
*      be classified in some FBS groups 
**************************************************
**************************************************;

*tab Q6_116,missing;
recode Q6_94-Q6_112 (.=0)

** Changes mainly consist of recategorizing oils into "Vegetable oils and fats" or "Animal oils and fats"; 
** All cooking oils have been considered as vegetable oils and fats; 

replace Q6_101=1+Q6_101 if country=="Guatemala"
replace Q6_106=1+Q6_106 if country=="Guatemala"
replace Q6_108=1+Q6_108 if country=="Guatemala"
replace Q6_109=1+Q6_109 if country=="Guatemala"
replace Q6_97=1+Q6_97 if country=="Guatemala"
replace Q6_110=1+Q6_110 if country=="Guatemala"
replace Q6_109=1+Q6_109 if country=="El Salvador"
replace Q6_109=1+Q6_109 if country=="El Salvador"
replace Q6_109=1+Q6_109 if country=="Burkina Faso"
replace Q6_110=1+Q6_110 if country=="Burkina Faso"
replace Q6_110=1+Q6_110 if country=="Burkina Faso"
replace Q6_109=1+Q6_109 if country=="Sierra Leone"
replace Q6_109=1+Q6_109 if country=="Sierra Leone"
replace Q6_110=1+Q6_110 if country=="Sierra Leone"
replace Q6_103=1+Q6_103 if country=="Sri Lanka"
replace Q6_110=1+Q6_110 if country=="Belarus"
replace Q6_109=1+Q6_109 if country=="Iraq"
replace Q6_109=1+Q6_109 if country=="Iraq"
replace Q6_109=1+Q6_109 if country=="Cambodia"
replace Q6_109=1+Q6_109 if country=="Cambodia"
replace Q6_110=1+Q6_110 if country=="Paraguay"
replace Q6_110=1+Q6_110 if country=="Paraguay"
replace Q6_109=1+Q6_109 if country=="Paraguay"
replace Q6_109=1+Q6_109 if country=="Mexico"
replace Q6_110=1+Q6_110 if country=="Mexico"
replace Q6_109=1+Q6_109 if country=="Peru"
replace Q6_109=1+Q6_109 if country=="Peru"
replace Q6_110=1+Q6_110 if country=="Honduras"
replace Q6_109=1+Q6_109 if country=="Honduras"
replace Q6_109=1+Q6_109 if country=="Indonesia"
replace Q6_110=1+Q6_110 if country=="Ecuador"
replace Q6_109=1+Q6_109 if country=="Ecuador"
replace Q6_110=1+Q6_110 if country=="Nicaragua"
replace Q6_109=1+Q6_109 if country=="Nicaragua"
replace Q6_110=1+Q6_110 if country=="Fiji"
replace Q6_110=1+Q6_110 if country=="Fiji"
replace Q6_109=1+Q6_109 if country=="Latvia"
replace Q6_109=1+Q6_109 if country=="Mauritania"
replace Q6_109=1+Q6_109 if country=="Timor-Leste"
replace Q6_109=1+Q6_109 if country=="Vanuatu"
replace Q6_109=1+Q6_109 if country=="Uganda"
replace Q6_109=1+Q6_109 if country=="Pakistan"
replace Q6_109=1+Q6_109 if country=="Sudan"
replace Q6_109=1+Q6_109 if country=="South Africa"
replace Q6_109=1+Q6_109 if country=="Tunisia"
replace Q6_109=1+Q6_109 if country=="Senegal"
replace Q6_109=1+Q6_109 if country=="Burundi"
replace Q6_110=1+Q6_110 if country=="Republic of Congo"
replace Q6_110=1+Q6_110 if country=="Lesotho"
replace Q6_109=1+Q6_109 if country=="Maldives"
replace Q6_109=1+Q6_109 if country=="Malawi"
replace Q6_109=1+Q6_109 if country=="Philippines"
replace Q6_109=1+Q6_109 if country=="Zambia"
replace Q6_110=1+Q6_110 if country=="Armenia"

**************************************************
**************************************************
*  (C) Add foods that could not be classified into specific food groups in the Master Food List but can be 
*      for the FBS list to the FBS food group counts 
**************************************************
**************************************************;

******************** Foods classified under "Food and beverages" or "Food";
replace Q6_112=Q6_112+2 if country=="Belize"
replace Q6_111=Q6_111+1 if country=="Mozambique"
replace Q6_39= Q6_39+1 if country=="Malawi"
replace Q6_39b=Q6_39b+1 if country=="Malawi"

******************** Foods classified under "Non-specific food products" (Q6_39g);
*list country Q6_53 Q6_54; 

**All food items that are baby food;
replace Q6_112=Q6_112+1 if inlist(country,"Vanuatu","Mongolia","Maldives","Kazakhstan","Lithuania","Sudan","Zambia")
replace Q6_112=Q6_112+1 if inlist(country,"Gabon","Liberia","Dominica","Uganda","Seychelles","Uzbekistan","Ghana")
replace Q6_112=Q6_112+1 if inlist(country,"Fiji","Armenia","Rwanda","Mali","Lesotho","Kosovo","Jamaica")
replace Q6_112=Q6_112+1 if inlist(country,"Bosnia and Herzegovina","Mauritania","Azerbaijan","Togo","India","Cameroun")
replace Q6_112=Q6_112+1 if inlist(country,"Panama","Republic of the Marshall Islands","Republic of Congo","Albania","Kenya","Mexico","Cape Verde","St. Lucia")
*35 changes;

replace Q6_112=Q6_112+2 if country=="Iraq"
replace Q6_112=Q6_112+3 if country=="Morocco"
replace Q6_112=Q6_112+4 if country=="Burkina Faso"
replace Q6_112=Q6_112+5 if country=="South Africa"

**All food items that are prepared foods (mostly soups here);
replace Q6_112=Q6_112+1 if inlist(country,"Egypt","Honduras","Jamaica","Bosnia and Herzegovina","Azerbaijan","Bhutan")
replace Q6_112=Q6_112+1 if inlist(country,"Sri Lanka","India","Panama","Republic of the Marshall Islands","Republic of Congo")
replace Q6_112=Q6_112+2 if inlist(country,"Mozambique","Guatemala","Albania","Kenya","South Africa")
replace Q6_112=Q6_112+3 if country=="Niger" | country=="Mexico"
replace Q6_112=Q6_112+4 if country=="Cape Verde"
replace Q6_112=Q6_112+5 if country=="Belarus"
replace Q6_112=Q6_112+6 if country=="St. Lucia"
replace Q6_112=Q6_112+7 if country=="Tunisia"

**Other;
replace Q6_111=Q6_111+1 if country=="Angola"


/**************************************************
**************************************************
* (D) Classify into the Basic Food List:  Foods classified under 6 other "major headings" (in tan on the assessment form) 
*     that should be under a specific BFL food group but are not
**************************************************
**************************************************/

/*Note:  In some cases these are already classified into the correct FBS food list group, but in others
the people filling in the forms did not correctly classify them.  Correcting for that here */

********** Foods classified under "Milk, cheese and eggs" that are only milk and milk products;
**** and separate those that were in this group while should have gone under eggs;
*keep country Q6_55 Q6_56 Q6_57;
*sort Q6_55;

replace Q6_108=Q6_108+1 if  country=="Togo"
replace Q6_108=Q6_108+1 if  country=="Guatemala"
replace Q6_108=Q6_108+1 if  country=="Nicaragua"
replace Q6_108=Q6_108+1 if  country=="Pakistan"
replace Q6_108=Q6_108+1 if  country=="Chad"
replace Q6_108=Q6_108+1 if  country=="Madagascar"
replace Q6_108=Q6_108+1 if  country=="Angola"
replace Q6_108=Q6_108+1 if  country=="Papua New Guinea"
replace Q6_108=Q6_108+1 if  country=="Benin"
replace Q6_108=Q6_108+1 if  country=="Burundi"
replace Q6_108=Q6_108+1 if  country=="Djibouti"
replace Q6_108=Q6_108+2 if  country=="Honduras"
replace Q6_108=Q6_108+1 if  country=="Senegal"
*12 countries;
replace Q6_106=Q6_106+1 if  country=="Guatemala"
replace Q6_106=Q6_106+1 if  country=="Nicaragua"
replace Q6_106=Q6_106+1 if  country=="Honduras"
replace Q6_106=Q6_106+1 if  country=="Senegal"
*4 countries;

********** Foods classified under "Oils and fats" that can be indeed classified under vegetable or animal oils and fats or milk and cheese;
*keep country Q6_58 Q6_59 Q6_60;
replace Q6_109=Q6_109+1 if  country=="Lesotho"
replace Q6_109=Q6_109+1 if  country=="Honduras"
replace Q6_109=Q6_109+1 if  country=="Mozambique"
replace Q6_109=Q6_109+1 if  country=="Belize"
replace Q6_109=Q6_109+1 if  country=="Sao Tome e Principe"
replace Q6_109=Q6_109+1 if  country=="Cambodia"
replace Q6_109=Q6_109+1 if  country=="Latvia"
replace Q6_108=Q6_108+1 if  country=="Bangladesh"
replace Q6_108=Q6_108+1 if  country=="Sierra Leone"
*7 countries;

********** Foods classified under "Fruits" that are only fruits;
*keep country Q6_61 Q6_62 Q6_63;
*sort Q6_61;
replace Q6_101=Q6_101+9 if country=="Mexico"
replace Q6_101=Q6_101+5 if country=="Honduras"
replace Q6_101=Q6_101+5 if country=="Nicaragua"
replace Q6_101=Q6_101+4 if country=="Iraq"
replace Q6_101=Q6_101+2 if country=="Sri Lanka"
replace Q6_101=Q6_101+2 if country=="Seychelles"
replace Q6_101=Q6_101+1 if country=="Armenia"
replace Q6_101=Q6_101+1 if country=="Bangladesh"
replace Q6_101=Q6_101+1 if country=="Lesotho"
replace Q6_101=Q6_101+1 if country=="Kazakhstan"
replace Q6_101=Q6_101+1 if country=="Ethiopia"
replace Q6_101=Q6_101+1 if country=="Mongolia"
replace Q6_101=Q6_101+1 if country=="Swaziland"
replace Q6_101=Q6_101+1 if country=="Papua New Guinea"
replace Q6_101=Q6_101+1 if country=="Kosovo"
replace Q6_101=Q6_101+1 if country=="Sierra Leone"
replace Q6_101=Q6_101+1 if country=="Cambodia"
replace Q6_101=Q6_101+1 if country=="Latvia"
replace Q6_101=Q6_101+1 if country=="Guatemala"
replace Q6_101=Q6_101+1 if country=="St. Lucia"
replace Q6_101=Q6_101+1 if country=="Malawi"
replace Q6_101=Q6_101+1 if country=="Timor-Leste"
replace Q6_101=Q6_101+1 if country=="Lao PDR"
replace Q6_101=Q6_101+1 if country=="Burundi"
replace Q6_101=Q6_101+1 if country=="Djibouti"
replace Q6_101=Q6_101+1 if country=="South Africa"
replace Q6_101=Q6_101+1 if country=="Cape Verde"
replace Q6_101=Q6_101+1 if country=="Kenya"
replace Q6_101=Q6_101+1 if country=="Azerbaijan"
replace Q6_101=Q6_101+1 if country=="Bosnia and Herzegovina"
replace Q6_101=Q6_101+1 if country=="Dominica"
replace Q6_101=Q6_101+1 if country=="Liberia"
replace Q6_101=Q6_101+1 if country=="Uganda"
replace Q6_101=Q6_101+1 if country=="Ghana"
replace Q6_101=Q6_101+1 if country=="Zambia"
replace Q6_101=Q6_101+1 if country=="Indonesia"
replace Q6_101=Q6_101+1 if country=="Gambia"
replace Q6_101=Q6_101+1 if country=="Vietnam"
replace Q6_101=Q6_101+1 if country=="Bolivia"
replace Q6_101=Q6_101+1 if country=="Afghanistan"
replace Q6_101=Q6_101+1 if country=="Nigeria"
replace Q6_101=Q6_101+1 if country=="Nepal"
replace Q6_101=Q6_101+1 if country=="Niger"
* 44 countries

********** Foods classified under "Vegetables" that are only vegetables;
*keep country Q6_64 Q6_65 Q6_66a Q6_66b Q6_66c;
*sort Q6_64;
replace Q6_100=Q6_100+7 if country=="Honduras"
replace Q6_100=Q6_100+4 if country=="Nicaragua"
replace Q6_100=Q6_100+3 if country=="Cameroun"
replace Q6_100=Q6_100+3 if country=="Seychelles"
replace Q6_100=Q6_100+2 if country=="Armenia"
replace Q6_100=Q6_100+2 if country=="Kazakhstan"
replace Q6_100=Q6_100+1 if country=="Tajikistan"
replace Q6_100=Q6_100+1 if country=="Mexico"
replace Q6_100=Q6_100+1 if country=="Afghanistan"
replace Q6_100=Q6_100+1 if country=="Bolivia"
replace Q6_100=Q6_100+1 if country=="Bosnia and Herzegovina"
replace Q6_100=Q6_100+1 if country=="Bulgaria"
replace Q6_100=Q6_100+1 if country=="Burundi"
replace Q6_100=Q6_100+1 if country=="Ecuador"
replace Q6_100=Q6_100+1 if country=="El Salvador"
replace Q6_100=Q6_100+1 if country=="Ethiopia"
replace Q6_100=Q6_100+1 if country=="Fiji"
replace Q6_100=Q6_100+1 if country=="Gambia"
replace Q6_100=Q6_100+1 if country=="Ghana"
replace Q6_100=Q6_100+1 if country=="India"
replace Q6_100=Q6_100+1 if country=="Indonesia"
replace Q6_100=Q6_100+1 if country=="Kenya"
replace Q6_100=Q6_100+1 if country=="Kosovo"
replace Q6_100=Q6_100+1 if country=="Liberia"
replace Q6_100=Q6_100+1 if country=="Malawi"
replace Q6_100=Q6_100+1 if country=="Maldives"
replace Q6_100=Q6_100+1 if country=="Mongolia"
replace Q6_100=Q6_100+1 if country=="Nepal"
replace Q6_100=Q6_100+1 if country=="Nigeria"
replace Q6_100=Q6_100+1 if country=="Papua New Guinea"
replace Q6_100=Q6_100+1 if country=="Philippines"
replace Q6_100=Q6_100+1 if country=="Sierra Leone"
replace Q6_100=Q6_100+1 if country=="South Africa"
replace Q6_100=Q6_100+1 if country=="Sri Lanka"
replace Q6_100=Q6_100+1 if country=="Swaziland"
replace Q6_100=Q6_100+1 if country=="Timor-Leste"
replace Q6_100=Q6_100+1 if country=="Togo"
replace Q6_100=Q6_100+1 if country=="Uganda"
replace Q6_100=Q6_100+1 if country=="Uzbekistan"
replace Q6_100=Q6_100+1 if country=="Vietnam"
replace Q6_100=Q6_100+1 if country=="Zambia"
* 42 countries

********** Foods classified under "Vegetables" that are only pulses;
replace Q6_97=Q6_97+3 if country=="Sri Lanka"
replace Q6_97=Q6_97+1 if country=="Djibouti"
replace Q6_97=Q6_97+1 if country=="Tajikistan"
replace Q6_97=Q6_97+1 if country=="Ghana"
replace Q6_97=Q6_97+1 if country=="Malawi"
replace Q6_97=Q6_97+1 if country=="Zambia"
replace Q6_97=Q6_97+1 if country=="Azerbaijan"
replace Q6_97=Q6_97+1 if country=="Cambodia"
* 9 countries

********** Foods classified under "Vegetables" that are only roots and tubers;
replace Q6_95=Q6_95+1 if country=="Mexico"
replace Q6_95=Q6_95+1 if country=="Malawi"
replace Q6_95=Q6_95+1 if country=="Bolivia"
replace Q6_95=Q6_95+1 if country=="Liberia"
replace Q6_95=Q6_95+1 if country=="Lesotho"
* 5 countries

********** Foods classified under "Sugar, jam, honey, chocolate and confectionery";
*keep country Q6_67 Q6_68 Q6_69a Q6_69b;
*sort Q6_67;
*In "Sugars and syrups and products";
replace Q6_96  =Q6_96+1 if country=="Republic of the Marshall Islands"
replace Q6_96  =Q6_96+1 if country=="Jamaica"
replace Q6_96  =Q6_96+1 if country=="Sri Lanka"
replace Q6_96  =Q6_96+1 if country=="Thailand"
replace Q6_96  =Q6_96+1 if country=="Bolivia"
replace Q6_96  =Q6_96+1 if country=="Mongolia"
replace Q6_96  =Q6_96+1 if country=="Kenya"
replace Q6_96  =Q6_96+1 if country=="Nicaragua"
replace Q6_96  =Q6_96+2 if country=="Panama"
replace Q6_96  =Q6_96+1 if country=="Malawi"
replace Q6_96  =Q6_96+3 if country=="Guatemala"
replace Q6_96  =Q6_96+3 if country=="Mexico"
replace Q6_96  =Q6_96+1 if country=="Honduras"
replace Q6_96  =Q6_96+1 if country=="Gambia"
* 14 countries;
*In "Miscellaneous and prepared food";
replace Q6_112 =Q6_112+1 if country=="Honduras"
replace Q6_112 =Q6_112+1 if country=="Seychelles"
replace Q6_112 =Q6_112+1 if country=="Tunisia"
 
********** Foods classified under "Alcoholic beverages" that are only alcoholic beverages (not stimulants);
*keep country Q6_72 Q6_73 Q6_74;
*sort Q6_72;
replace Q6_104=Q6_104+1 if inlist(country,"Colombia","Papua New Guinea","Bolivia","Egypt","Sierra Leone","Madagascar","Uzbekistan")
replace Q6_104=Q6_104+1 if inlist(country,"Mongolia","Vietnam","Guinea","Sri Lanka","Lithuania","Zambia","Republic of the Marshall Islands")
replace Q6_104=Q6_104+1 if inlist(country,"Senegal","Tajikistan","Nepal","Panama","Jamaica","Chad","Brazil","Togo")
replace Q6_104=Q6_104+1 if inlist(country,"Cape Verde","Armenia","Vanuatu","Lao PDR","Iraq","Guatemala","Ghana")
replace Q6_104=Q6_104+1 if inlist(country,"Mozambique","Niger","Indonesia","Timor-Leste","Burundi","Morocco","Honduras")
replace Q6_104=Q6_104+1 if inlist(country,"Swaziland","Malawi","Albania","Benin","Nigeria","Uganda","Seychelles","Tunisia")

replace Q6_104=Q6_104+2 if inlist(country,"Thailand","Mali","Kazakhstan","Gabon","Cte d'Ivoire","India","Angola","Fiji")
replace Q6_104=Q6_104+3 if country=="Mexico" | country=="Liberia"

/**************************************************
**************************************************
* (E) Determine:  Are all of the FBS food groups represented? 
**************************************************
**************************************************/

*There are three countries for which the food list information is missing because it was;
*not available at the time of the assessment.  Drop these countries from the analysis; 
*Also drop Brazil, which had too many foods to fill in some variables;
drop if country=="Georgia"| country=="Montenegro"| country=="Russia" | country=="Brazil"

*Check for missings
tab Q6_94, missing
tab Q6_95, missing
tab Q6_96, missing
tab Q6_97, missing
tab Q6_98, missing
tab Q6_99, missing
tab Q6_100, missing
tab Q6_101, missing
tab Q6_102, missing
tab Q6_103, missing
tab Q6_104, missing
tab Q6_105, missing
tab Q6_106, missing
tab Q6_107, missing
tab Q6_108, missing
tab Q6_109, missing
tab Q6_110, missing
tab Q6_111, missing
tab Q6_112, missing
*No missings;

gen fg1=0
replace fg1=1 if Q6_94>0
gen fg2=0
replace fg2=1 if Q6_95>0
gen fg3=0
replace fg3=1 if Q6_96>0
gen fg4=0
replace fg4=1 if Q6_97>0
gen fg5=0
replace fg5=1 if Q6_98>0
gen fg6=0
replace fg6=1 if Q6_99>0
gen fg7=0
replace fg7=1 if Q6_100>0
gen fg8=0  
replace fg8=1 if Q6_101>0
gen fg9=0
replace fg9=1 if Q6_102>0
gen fg10=0
replace fg10=1 if Q6_103>0
gen fg11=0
replace fg11=1 if Q6_104>0
gen fg12=0
replace fg12=1 if Q6_105>0
gen fg13=0
replace fg13=1 if Q6_106>0
gen fg14=0
replace fg14=1 if Q6_107>0
gen fg15=0 
replace fg15=1 if Q6_108>0
gen fg16=0
replace fg16=1 if Q6_109>0
gen fg17=0
replace fg17=1 if Q6_110>0
gen fg18=0
replace fg18=1 if Q6_111>0
gen fg19=0
replace fg19=1 if Q6_112>0

*recode fg1-fg19 (1=100)
la var fg1 "Cereals and product"
la var fg2 "Roots and tubers and products"
la var fg3 "Sugars and syrups and products"
la var fg4 "Pulses"
la var fg5 "Tree nuts"
la var fg6 "Oil crops"
la var fg7 "Vegetables and products"
la var fg8 "Fruits and products"
la var fg9 "Stimulants"
la var fg10 "Spices and additives"
la var fg11 "Alcoholic beverages"
la var fg12 "Meat"
la var fg13 "Eggs"
la var fg14 "Fish and fish products"
la var fg15 "Milk and cheese"
la var fg16 "Vegetable oils and fats"
la var fg17 "Animal oils and fats"
la var fg18 "Non-alcoholic beverages"
la var fg19 "Miscellaneous and prepared food"
sum fg1-fg19

*recode fg1-fg19 (100=1)
egen numfg=rsum(fg1-fg19)
tab numfg, missing

gen all_fg=0
la var all_fg "All food groups in FBS"
replace all_fg=1 if numfg==19

tab all_fg, missing
*tab all_fg if int_diary==1;
*tab all_fg if int_diary==2;


/**************************************************
**************************************************
* (F) What pecent of food items span the food groups? 
**************************************************
**************************************************/

*Note:  ".. apart from prepared foods" is not included in the question above because FBS food group 19 contains these;
 
*This includes those that don't fall into any particular food group and those that span more than one food group;

recode Q6_57 Q6_60 Q6_63 Q6_66* Q6_69a Q6_69b Q6_74 (.=0)

*See excel file "Spreadsheet for analyzing specificity of FBS food list" for lists of foods and their classifications;

******************** Calculate total number of at-home food items;
gen num_items=Q6_1-Q6_2a
tab num_items

******************** Spanning food items in Q6_116; 
gen span_g_1=1	if inlist(country,"Afghanistan","Bangladesh","Cape Verde","Gambia","India","Jamaica","Lao PDR")
replace span_g_1=1	if inlist(country,"St. Lucia","Madagascar","Mali","Niger","Panama","Republic of the Marshall Islands","Rwanda")
replace span_g_1=1	if inlist(country,"Swaziland","Thailand","Togo","Tanzania","Uzbekistan","Vietnam","Armenia")
replace span_g_1=1	if inlist(country,"Pakistan","Sudan","Uganda","Vanuatu","Guatemala","Iraq","Cambodia","Burkina Faso")

replace span_g_1=2	if inlist(country,"Bolivia","Ghana","Kazakhstan","Morocco","Nigeria","Chad","Indonesia","Timor-Leste")

******************** Spanning food items in "Food and beverages" (Q6_3 & Q6_4); 
gen span_g_2=1	if inlist(country,"Ghana","Rwanda","Burundi","Myanmar","Niger","Burkina Faso","Mongolia")
replace span_g_2=1 if inlist(country,"Paraguay","Bosnia and Herzegovina","Sudan","Zambia","Egypt","Guinea","Lesotho")
replace span_g_2=1 if inlist(country,"Cambodia","Vanuatu","Nicaragua","Yemen","Honduras","Thailand","Swaziland")
replace span_g_2=1 if inlist(country,"Bangladesh","Mozambique","Gambia","Cape Verde")

replace span_g_2=2	if inlist(country,"Armenia","Afghanistan","Benin","Union des Comores","Bulgaria","Cameroun","Lao PDR")
replace span_g_2=2	if inlist(country,"Uganda","Kosovo","Papua New Guinea","Panama","Uzbekistan","Belarus","South Africa")
replace span_g_2=2	if inlist(country,"Seychelles","Timor-Leste","India","Tunisia")

replace span_g_2=3	if inlist(country,"Togo","Bolivia","Philippines","Liberia","Dominica","Gabon","Pakistan")
replace span_g_2=3	if inlist(country,"Fiji","Lithuania","Sierra Leone")

replace span_g_2=4	if inlist(country,"Jamaica","Mali","Republic of the Marshall Islands")

replace span_g_2=5	if inlist(country,"Mexico","Azerbaijan","Sao Tome e Principe","Vietnam","Chad","Mauritania")
replace span_g_2=5	if inlist(country,"Colombia","Malawi","Sri Lanka")

replace span_g_2=13 if country=="Kazakhstan"

tab span_g_2, missing

******************** Q6_39g foods; 

gen span_g_3=1 if inlist(country,"Ethiopia","Romania","Angola","Bhutan","Cameroun","Myanmar")
replace span_g_3=1 if inlist(country,"Sri Lanka","Togo","Cape Verde","Tunisia")

******************** Food items in the Milk, cheese and eggs category that are not only dairy products;
*keep country Q6_55 Q6_56 Q6_57;
*sort Q6_55;

gen span_g_4=1 if inlist(country,"Swaziland","Bulgaria","St. Lucia","Kazakhstan","Mongolia","Lao PDR")
replace span_g_4=1 if inlist(country,"Ethiopia","Timor-Leste","Thailand","Nicaragua","Guatemala","Honduras")

******************** Oils and fats;
*keep country Q6_58 Q6_59;
*sort Q6_58;

gen span_g_5=1 if inlist(country,"Kazakhstan","Colombia","Thailand","Mongolia","Yemen","Papua New Guinea","Togo")
replace span_g_5=1 if inlist(country,"Fiji","Swaziland","Maldives","Paraguay","Ethiopia","Kosovo","Guinea-Bissau","Mexico")

replace span_g_5=2 if country=="Lithuania"

******************** Fruits;
*keep country Q6_61 Q6_62;
*sort Q6_612;

*Not really a problem since plantain bananas are considered fruits in the FBS;

******************** Vegetables;
*keep country Q6_64 Q6_65;
*sort Q6_64;

gen span_g_6=1 if inlist(country,"Senegal","Cambodia","Lesotho","Ghana","Morocco","Bolivia","El Salvador")
replace span_g_6=1 if inlist(country,"Liberia","Pakistan","Zambia","Tajikistan")

replace span_g_6=2 if inlist(country,"Djibouti","Malawi","Sri Lanka")

******************** "Sugar, jam, honey, chocolate and confectionary";
*keep country Q6_67 Q6_68;

gen span_g_7=1 if inlist(country,"Cameroun","Kazakhstan","Malawi")

******************** Alcoholic beverages, tobacco and narcotics;
*keep country Q6_70 Q6_71;

gen span_g_8=1 if inlist(country,"Kazakhstan","Dominica")

******************** Alcoholic beverages that are not only alcoholic beverages;
*keep country Q6_72 Q6_73;
*sort Q6_72;
*No problem here;

******************** Calculate the total number of food items that span the food groups;
recode span_g_1-span_g_8 (.=0)
sum span*
*N=96, no missings for any of these variables;

egen sum_all_nspec=rsum(span_g_1-span_g_8)
tab sum_all_nspec, missing
sum sum_all_nspec

gen perc_span=sum_all*100/num_items
tab perc_span, missing
sum perc_span

*** Percent of surveys for which less than 5% of foods items span food groups;
gen perc_span_lt5pc=0
la var perc_span_lt5pc "Less than 5% of foods items span in FBS food groups"
replace perc_span_lt5pc=1 if perc_span<5.0
*replace perc_span_lt5pc=100 if perc_span<5.0
tab    perc_span_lt5pc, missing


/**************************************************
**************************************************
* (G) Specificity:  Minimum number of food items in each group
**************************************************
**************************************************/

*Cereals and products;
gen num_group1=Q6_94
*Roots, tubers and products;
gen num_group2=Q6_95
*Sugars and syrups and products;
gen num_group3=Q6_96
*Pulses;
gen num_group4=Q6_97
*Tree nuts;
gen num_group5=Q6_98
*Oil crops;
gen num_group6=Q6_99
*Vegetables and products;
gen num_group7=Q6_100
*Fruits and products;
gen num_group8=Q6_101
*Stimulants;
gen num_group9=Q6_102
*Spices and additives;
gen num_group10=Q6_103
*Alcoholic beverages;
gen num_group11=Q6_104
*Meat;
gen num_group12=Q6_105
*Eggs;
gen num_group13=Q6_106
*Fish and fish products;
gen num_group14=Q6_107
*Milk and cheese;
gen num_group15=Q6_108
*Vegetable oils and fats; 
gen num_group16=Q6_109
*Animal oils and fats;
gen num_group17=Q6_110
*Non-alcoholic beverages; 
gen num_group18=Q6_111
*Miscellaneous and prepared food; 
gen num_group19=Q6_112

sum num_group*
*No missings;

/********** Make variables identifying whether minimum number of food items is reached
*          for each food group. Note that treshold is arbitrary, need to revise it
*          based on comments from nutritionists */
gen min_g1=0
la var min_g1 "Cereals and product (5) - Minimum no of food items in FBS food groups"
*replace min_g1=100 if num_group1>=5
replace min_g1=1 if num_group1>=5
gen min_g2=0
la var min_g2 "Roots and tubers and products (5) - Minimum no of food items in FBS food groups"
replace min_g2=1 if num_group2>=5
gen min_g3=0
la var min_g3 "Sugars and syrups and products (5) - Minimum no of food items in FBS food groups"
replace min_g3=1 if num_group3>=5
gen min_g4=0
la var min_g4 "Pulses (3) - Minimum no of food items in FBS food groups"
replace min_g4=1 if num_group4>=3
gen min_g5=0
la var min_g5 "Tree nuts (3) - Minimum no of food items in FBS food groups"
replace min_g5=1 if num_group5>=3
gen min_g6=0
la var min_g6 "Oil crops (3) - Minimum no of food items in FBS food groups"
replace min_g6=1 if num_group6>=3
gen min_g7=0
la var min_g7 "Vegetables and products (10) - Minimum no of food items in FBS food groups"
replace min_g7=1 if num_group7>=10
gen min_g8=0
la var min_g8 "Fruits and products (10) - Minimum no of food items in FBS food groups"
replace min_g8=1 if num_group8>=10
gen min_g9=0
la var min_g9 "Stimulants (3) - Minimum no of food items in FBS food groups"
replace min_g9=1 if num_group9>=3
gen min_g10=0
la var min_g10 "Spices and additives (5) - Minimum no of food items in FBS food groups"
replace min_g10=1 if num_group10>=5
gen min_g11=0
la var min_g11 "Alcoholic beverages (5) - Minimum no of food items in FBS food groups"
replace min_g11=1 if num_group11>=5
gen min_g12=0
la var min_g12 "Meat (5) - Minimum no of food items in FBS food groups"
replace min_g12=1 if num_group12>=5
gen min_g13=0
la var min_g13 "Eggs (1) - Minimum no of food items in FBS food groups"
replace min_g13=1 if num_group13>=1
gen min_g14=0
la var min_g14 "Fish and fish products (5) - Minimum no of food items in FBS food groups"
replace min_g14=1 if num_group14>=5
gen min_g15=0
la var min_g15 "Milk and cheese (5) - Minimum no of food items in FBS food groups"
replace min_g15=1 if num_group15>=5
gen min_g16=0
la var min_g16 "Vegetable oils and fats (2) - Minimum no of food items in FBS food groups"
replace min_g16=1 if num_group16>=2
gen min_g17=0
la var min_g17 "Animal oils and fats (2) - Minimum no of food items in FBS food groups"
replace min_g17=1 if num_group17>=2
gen min_g18=0
la var min_g18 "Non-alcoholic beverages (5) - Minimum no of food items in FBS food groups"
replace min_g18=1 if num_group18>=5
gen min_g19=0
la var min_g19 "Miscellaneous and prepared food (5) - Minimum no of food items in FBS food groups"
replace min_g19=1 if num_group19>=5
*sum min_g*

********** Make variable identifying whether minimum number of food items is reached for
*          at least 15, 16, 17, 18 and 19 (all) food groups and basic groups are represented;

*recode min_g1-min_g19 (100=1)
egen num_fg_min=rsum(min_g1-min_g19)
tab num_fg_min
*No missings;

gen min_numfg15=0
la var min_numfg15 "Minimum number of food items in at least 15 FBS food groups"
replace min_numfg15=1 if num_fg_min>=15
gen min_numfg16=0 
la var min_numfg16 "Minimum number of food items in at least 16 FBS food groups"
replace min_numfg16=1 if num_fg_min>=16
gen min_numfg17=0
la var min_numfg17 "Minimum number of food items in at least 17 FBS food groups"
replace min_numfg17=1 if num_fg_min>=17
gen min_numfg18=0 
la var min_numfg18 "Minimum number of food items in at least 18 FBS food groups"
replace min_numfg18=1 if num_fg_min>=18
gen min_numfg19=0 
la var min_numfg19 "Minimum number of food items in at least 19 FBS food groups"
replace min_numfg19=1 if num_fg_min>=19
sum min_numfg15-min_numfg19


**************************************************
**************************************************
* (G) The last three conditions combined
**************************************************
**************************************************;

tab all_fg, missing
tab perc_span_lt5pc, missing
tab min_numfg15, missing

gen      all_three=0 if all_fg~=. & perc_span_lt5pc~=. & min_numfg15~=.
la var all_three "All three conditions combined, all FBS, minimum number (15FBS) and less than 5% span FBS fg"
replace  all_three=1 if all_fg==1 & perc_span_lt5pc==1 & min_numfg15==1

tab all_three, missing
tab all_three

**************************************************
**************************************************
* (I) Calculate the percent of surveys that can be used to estimate subsistence production
**************************************************
**************************************************;

*The criteria are that at-home quantities of food can be estimated and home produced food
*consumed is enumerated individually;
/*
#delim;
use "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\hp_indiv.dta", clear;
merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\metric conversion.dta";
tab _merge; drop _merge;

tab mi_hp, missing;
tab all_convert, missing;

gen both=0 if mi_hp~=. & all_convert~=.;
replace both=1 if mi_hp==1 & all_convert==1;

tab both, missing;
tab both;

*/
forvalues i = 1(1)19 {
	ren fg`i' fg`i'_FBS 
	ren min_g`i' min_g`i'_FBS
}

saveold "$outputdata\Corrections to MFL_FBS", replace
sort country
keep country fg* all_fg min_g* min_numfg* perc_span_lt5pc all_three
tempfile FBSfg
save `FBSfg'

*********************************************************************
*********************************************************************
**     DATE:       October/November 2012
**     PROGRAM:    HCES Assessment_Relevance_Measuring poverty
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    
**     PURPOSE:    Analyze relevance for various users of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Measuring poverty
*********************************************************************
*********************************************************************;
*  We only need to calculate the percent of surveys for which the first and second criteria for
*  the second-best method apply;

use "$outputdata\HCES_food_assessment_edited.dta", clear

tab cc_sb_1
tab cc_sb_2

gen poverty_sb=0 if cc_sb_1~=. & cc_sb_2~=.
la var poverty_sb "Survey can be used to measure poverty"
replace poverty_sb=1 if cc_sb_1==1 & cc_sb_2==1
tab poverty_sb, missing
tab poverty_sb
save "$outputdata\HCES_food_assessment_edited.dta", replace
*********************************************************************
*********************************************************************
**     DATE:       October 2012
**     PROGRAM:    HCES Assessment_Relevance_Informing food based nutritional interventions
**     AUTHOR:     LSmith
**     INFILE:     HCES assessment 2012__100-country dataset.dta 
**     OUTFILE:    
**     PURPOSE:    Analyze relevance for various users of the food data collected in Household Consumption 
**			       and Expenditure surveys:  Informing food-based nutritional interventions
*********************************************************************
*********************************************************************;

*use "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\HCES Assessment 2012__100-country dataset", clear;

/*
 (A) Collection of data on potentially fortifiable (PF) foods
 (B) Quantities consumed of PF foods per capita
 (C) Quantities consumed of PF foods by age and sex group
 (D) Household micronutrient consumption per capita
 (E) Percent of households purchasing PF foods over recall period
 (F) Percent of households usually purchasing PF foods 
 (G) Percent of households consuming PF foods over recall period
 (H) Percent of households usually consuming PF foods  -- Done in in analysis of "Assessment of the reliability of the food data"
*/

**************************************************
**************************************************
*  (A) Collection of data on potentially fortifiable (PF) foods
**************************************************
**************************************************;

*Note:  We will not include this analysis in the conditions for whether a data set can be used 
*since the particular foods that could be fortified are so country-specific;

*Info here used "For information" in text;

recode Q6_118-Q6_133d (2=0)

*Sugar;
tab Q6_118, missing

*Margarine;
tab Q6_119, missing

*Soy sauce;
tab Q6_120, missing

*Dehydrated noodle soup;
tab Q6_121, missing

*Crackers;
tab Q6_122, missing

*Vegetable oil;
tab Q6_123, missing

*Salt;
tab Q6_124, missing

*Fish sauce;
tab Q6_125, missing

*Bouillon cube;
tab Q6_126, missing

*Pasta;
tab Q6_127, missing

*Cereal flour or meal;
tab Q6_129, missing

*Bread;
tab Q6_128, missing

*Porridge;
tab Q6_130, missing

*Biscuits, pastries, cakes and/or cookies;
tab Q6_131, missing

*Tortillas;
tab Q6_132, missing

*Breakfast cereals;
tab Q6_133, missing

****** Breakfast cereals or porridge;
gen bfc_porr=0 if Q6_130~=. & Q6_133~=.
la var bfc_porr "Breakfast cereals or porridge"
replace bfc_porr=1 if Q6_130==1 | Q6_133==1
tab bfc_porr, missing

recode Q6_118-Q6_133d (0=2)

**************************************************
**************************************************
*  (B)  Quantities consumed of PF foods per capita
**************************************************
**************************************************;

*merge 1:1 country using "C:\AA_LISACAT\aa_TANGO\IHSN project\Analysis\Data\outfiles\metric conversion";
*tab _merge; drop _merge;


**************************************************
**************************************************
*  (C) Quantities consumed of PF foods by age and sex group
**************************************************
**************************************************;

*HCESs per se do not collect data at the individual level.  Thus consumption by age and sex group needs to be
*estimated using assumptions or modelling techniques;

*The technique of assigning food consumption based on relative caloric requirements is not acceptable;

*Research needed on how/whether possible to use demographic modelling to infer consumption of individuals;

*Conclusion: Theoretically possible to use a  modeling technique, but more research is needed;


**************************************************
*  (D) Household micronutrient consumption per capita
**************************************************

*The first-best method for calorie consumption per capita is the only possibility here;

tab cc_fb
   
**************************************************
*  (E) Micronutrient consumption of various age and sex groups
**************************************************

*See (C) above;

**************************************************
*  (F) Percent of households purchasing PF foods over recall period
**************************************************
/*
We need to know how much of the food is purchased, whether as a "final consumer product" or contained within processed foods,
eaten at home or away from home
*/

* (1) Data must be collected individually on food purchases;
recode Q5_1 (2=0) (99=.)
tab Q5_1, missing
recode Q5_1 (0=2) (.=99)

**************************************************
*  (G) Percent of households usually purchasing PF foods 
**************************************************

*Need repeat surveys;

**************************************************
**************************************************
*  (H) Percent of households consuming PF foods over recall period
**************************************************
**************************************************

*Note:  Home produced food is (almost) always collected for consumption;

gen consumption=0 if acqu_cons==1 | (((purch_acqu_cons==2 & ik_acqu_cons==1) | (purch_acqu_cons==1 & ik_acqu_cons==2)) & ik_acqu_cons~=99999)
la var consumption "Households consuming PF foods over recall period"
replace consumption=1 if acqu_cons==2 | ((purch_acqu_cons==3 | ik_acqu_cons==3) & ik_acqu_cons~=999 & ik_acqu_cons~=99999)

tab consumption, missing


**************************************************
**************************************************
*  (I) Percent of households usually consuming PF foods 
**************************************************
**************************************************
* not available


* Estimating subsistance production, requires that data collected on consumption of home-produce and 
* metric quantities of at-home foods can be calculated
gen est_prd=0
replace est_prd=1 if cc_fb_2==1 & Q5_2==1
la var est_prd "Estimating subsistance production"
/*
sort country
merge 1:1 country using `FBSfg'
drop _merge
*/
drop dd_fb_1 dd_sb_1

*********************************************************************
*********************************************************************
**     DATE:       June-November 2012
**     PROGRAM:    HCES Assessment_Reliability_sum
**     AUTHOR:     LSmith
**     INFILE:     Sixty-six country data set_ordered.dta 
**     OUTFILE:    None 
**     PURPOSE:    Analyze reliability of the food data in Household Consumption 
**			       and expenditure surveys
*********************************************************************;

gen all_rc=0 if rc_1_recallp~=. & rc_2_3modes~=. & rc_3_cenum~=. & rc_4_compfl~=. & rc_5_specfl~=. & rc_6_fcafh~=. & rc_7_season~=.
tab all_rc
*96 countries with no missing data on reliability criteria;

replace all_rc=1 if rc_1_recallp==1 & rc_2_3modes==1 & rc_3_cenum==1 & rc_4_compfl==1 & rc_5_specfl==1 & rc_6_fcafh==1 & rc_7_season==1

tab all_rc, missing
tab all_rc

gen flag=1 if rc_1_recallp~=. & rc_2_3modes~=. & rc_3_cenum~=. & rc_4_compfl~=. & rc_5_specfl~=. & rc_6_fcafh~=. & rc_7_season~=.
tab flag, missing
*96 surveys;

*keep country rc_1 rc_2 rc_3 rc_4 rc_5 rc_6 rc_7 flag;
egen num_rec=rsum(rc_1_recallp rc_2_3modes rc_3_cenum rc_4_compfl rc_5_specfl rc_6_fcafh rc_7_season) if flag==1
tab num_rec

gen all_7=0 if flag==1
la var all_7 "Assessment surveys meeting minimum reliability criteria"
replace all_7=1 if num_rec==7
tab all_7, missing
tab all_7

drop all_rc flag num_rec 
saveold "$outputdata\HCES_food_assessment_edited.dta", replace

log close
